@@ -1,8 +1,7 @@
 import logging
 
-from ._version_info import __version__
-
-from .fit import *
+__version__ = "2.11.0"
+from .fit import *  # noqa: F401, F403
 
 logger = logging.getLogger(__name__)
 logging.basicConfig()
