@@ -3,16 +3,16 @@ Classes for handling of uncertainties in kafe2 fits.
 """
 
 import abc
-import numpy as np
-import six
+import logging
 import warnings
 
-import logging
+import numpy as np
+import six
 
 logger = logging.getLogger(__name__)
 logging.basicConfig()
 
-__all__ = ['CovMat', 'SimpleGaussianError', 'MatrixGaussianError']
+__all__ = ["CovMat", "SimpleGaussianError", "MatrixGaussianError"]
 
 
 def cov_mat_from_float(value, size, correlation=0.0):
@@ -52,8 +52,7 @@ class CovMat(object):
         return _new
 
     def __eq__(self, other):
-        return np.all(self._mat == other.mat) if isinstance(other, CovMat) \
-            else np.all(self._mat == other)
+        return np.all(self._mat == other.mat) if isinstance(other, CovMat) else np.all(self._mat == other)
 
     def __len__(self):
         return self._size
@@ -95,8 +94,7 @@ class CovMat(object):
 
         self._mat = np.array(matrix)
         if self._mat.ndim != 2 or self._mat.shape[0] != self._mat.shape[1]:
-            raise ValueError(
-                "Covariance matrix must be square matrix, shape %r given." % (self._mat.shape,))
+            raise ValueError("Covariance matrix must be square matrix, shape %r given." % (self._mat.shape,))
         self._size = self._mat.shape[0]
         self._cond = None
 
@@ -115,7 +113,7 @@ class CovMat(object):
         return self._cor_mat
 
     @property
-    def I(self):
+    def I(self):  # noqa: E743 (ambiguous function name)
         """
         Inverse of the covariance matrix. Returns ``None`` if matrix is singular.
         """
@@ -167,7 +165,7 @@ class CovMat(object):
         _l = [_m0]
         _u, _v, _w = np.linalg.svd(self.chol)
         for _sv, _sc in zip(_v, _u.T):
-            _l.append(np.outer(_sc, _sc) * _sv ** 2)
+            _l.append(np.outer(_sc, _sc) * _sv**2)
         return _l
 
 
@@ -177,6 +175,7 @@ class GaussianErrorBase(object):
     """
     Purely abstract class. Defines the minimal interface required by all specializations.
     """
+
     @property
     @abc.abstractmethod
     def error(self):
@@ -198,7 +197,7 @@ class GaussianErrorBase(object):
     @reference.setter
     def reference(self, reference):
         if reference is None:
-            ##self._reference = np.ones_like(self._err_val)
+            # self._reference = np.ones_like(self._err_val)
             self._reference = None
         elif callable(reference):
             self._reference = reference
@@ -206,10 +205,7 @@ class GaussianErrorBase(object):
             _ref = np.asarray(reference, dtype=float)
             # check for zero-valued references if error is marked 'relative'
             if self.relative and np.any(_ref == 0):
-                warnings.warn(
-                    "Relative error has a reference that contains values equal to zero: %s"
-                    % _ref
-                )
+                warnings.warn("Relative error has a reference that contains values equal to zero: %s" % _ref)
             self._reference = _ref
 
         # invalidate error_structures opposite declared relativity type
@@ -304,13 +300,13 @@ class SimpleGaussianError(GaussianErrorBase):
     used to convert 'absolute' ('relative') error arrays or covariance matrices to 'relative' ('absolute') ones.
 
     """
+
     def __init__(self, err_val, corr_coeff, relative=False, reference=None, fit_indices=None):
         if not (0.0 <= corr_coeff <= 1.0):
             raise ValueError("Correlation must be between 0 and 1, %g given," % (corr_coeff,))
         err_val = np.asarray(err_val)
         if err_val.ndim != 1:
-            raise ValueError(
-                f"Error must be one-dimensional but received array with {err_val.ndim} dimensions.")
+            raise ValueError(f"Error must be one-dimensional but received array with {err_val.ndim} dimensions.")
         self._corr_coeff = float(corr_coeff)
         self._is_relative = relative
         self.reference = reference
@@ -326,10 +322,10 @@ class SimpleGaussianError(GaussianErrorBase):
     def _calculate_cov_mat_generic(error_array, corr_coeff):
         """Calculate a covariance matrix from an array of error values and a global correlation coefficient."""
         if corr_coeff > 0:
-            cov_mat_uncor_part = np.diag(error_array ** 2 * (1.0 - corr_coeff))
+            cov_mat_uncor_part = np.diag(error_array**2 * (1.0 - corr_coeff))
             cov_mat_cor_part = np.outer(error_array, error_array) * corr_coeff
         else:
-            cov_mat_uncor_part = np.diag(error_array ** 2)
+            cov_mat_uncor_part = np.diag(error_array**2)
             cov_mat_cor_part = np.zeros_like(cov_mat_uncor_part)
 
         cov_mat = CovMat(cov_mat_uncor_part + cov_mat_cor_part)
@@ -347,13 +343,20 @@ class SimpleGaussianError(GaussianErrorBase):
         else:
             _abs_err = self.error
 
-        self._cov_mat, self._cov_mat_uncor_part, self._cov_mat_cor_part = self._calculate_cov_mat_generic(_abs_err, self._corr_coeff)
+        (
+            self._cov_mat,
+            self._cov_mat_uncor_part,
+            self._cov_mat_cor_part,
+        ) = self._calculate_cov_mat_generic(_abs_err, self._corr_coeff)
 
     def _calculate_cov_mat_rel(self):
         """Calculate relative covariance matrix for error object."""
         _rel_err = self.error_rel
-        self._cov_mat_rel, self._cov_mat_rel_uncor_part, self._cov_mat_rel_cor_part \
-            = self._calculate_cov_mat_generic(_rel_err, self._corr_coeff)
+        (
+            self._cov_mat_rel,
+            self._cov_mat_rel_uncor_part,
+            self._cov_mat_rel_cor_part,
+        ) = self._calculate_cov_mat_generic(_rel_err, self._corr_coeff)
 
     # -- public methods
 
@@ -372,8 +375,7 @@ class SimpleGaussianError(GaussianErrorBase):
         # calculate relative error from absolute error (if 'reference' is set)
         if self.relative:
             if self.reference is None:
-                raise AttributeError(
-                    "Requested 'absolute' errors for error object declared 'relative', but 'reference' not set!")
+                raise AttributeError("Requested 'absolute' errors for error object declared 'relative', but 'reference' not set!")
             self._err = self._err_rel * np.abs(self.reference)
         return self._err
 
@@ -384,8 +386,7 @@ class SimpleGaussianError(GaussianErrorBase):
             raise ValueError("Error values must be >= 0. Received: %s" % err_val)
         if self.relative:
             if self.reference is None:
-                raise AttributeError(
-                    "Setting 'absolute' errors for error object declared 'relative', but 'reference' not set!")
+                raise AttributeError("Setting 'absolute' errors for error object declared 'relative', but 'reference' not set!")
 
             self._err = err_val
             self._err_rel = err_val / np.abs(self.reference)
@@ -422,8 +423,7 @@ class SimpleGaussianError(GaussianErrorBase):
         # calculate relative error from absolute error (if 'reference' is set)
         if not self.relative:
             if self.reference is None:
-                raise AttributeError(
-                    "Requested 'relative' errors for error object declared 'absolute', but 'reference' not set!")
+                raise AttributeError("Requested 'relative' errors for error object declared 'absolute', but 'reference' not set!")
             self._err_rel = self._err / np.abs(self.reference)
         return self._err_rel
 
@@ -437,8 +437,7 @@ class SimpleGaussianError(GaussianErrorBase):
             self._err_rel = err_val
         else:
             if self.reference is None:
-                raise AttributeError(
-                    "Setting 'absolute' errors for error object declared 'relative', but 'reference' not set!")
+                raise AttributeError("Setting 'absolute' errors for error object declared 'relative', but 'reference' not set!")
             self._err = err_val * self.reference
             self._err_rel = err_val
 
@@ -526,18 +525,22 @@ class MatrixGaussianError(GaussianErrorBase):
     used to convert 'absolute' ('relative') error arrays or covariance matrices to 'relative' ('absolute') ones.
 
     """
-    def __init__(self, err_matrix, matrix_type, err_val=None, relative=False,
-                 reference=None, fit_indices=None):
+
+    def __init__(
+        self,
+        err_matrix,
+        matrix_type,
+        err_val=None,
+        relative=False,
+        reference=None,
+        fit_indices=None,
+    ):
         err_matrix = np.asarray(err_matrix)
         err_val = err_val if err_val is None else np.asarray(err_val)
         if err_matrix.ndim != 2:
-            raise ValueError(
-                "Error matrix must be two-dimensional but received "
-                f"array with {err_matrix.ndim} dimensions.")
+            raise ValueError("Error matrix must be two-dimensional but received " f"array with {err_matrix.ndim} dimensions.")
         if err_val is not None and err_val.ndim > 1:
-            raise ValueError(
-                "Error array must be scalar or one-dimensional but received "
-                f"array with {err_val.ndim} dimensions.")
+            raise ValueError("Error array must be scalar or one-dimensional but received " f"array with {err_val.ndim} dimensions.")
         self._is_relative = relative
         self.reference = reference
         self._fit_indices = fit_indices
@@ -548,27 +551,25 @@ class MatrixGaussianError(GaussianErrorBase):
         self._cov_mat_rel = None
 
         # set the main matrix
-        if matrix_type.lower() in ('covariance', 'cov'):
+        if matrix_type.lower() in ("covariance", "cov"):
             if err_val is not None:
                 raise ValueError("Cannot provide err_val when constructing a covariance matrix!")
-            self._matrix_type_at_construction = 'covariance'
+            self._matrix_type_at_construction = "covariance"
             if self.relative:
                 self.cov_mat_rel = err_matrix
             else:
                 self.cov_mat = err_matrix
-        elif matrix_type.lower() in ('correlation', 'correlations', 'cor', 'corr'):
-            self._matrix_type_at_construction = 'correlation'
+        elif matrix_type.lower() in ("correlation", "correlations", "cor", "corr"):
+            self._matrix_type_at_construction = "correlation"
             if err_val is None:
-                raise ValueError(
-                    "Cannot construct matrix-type error from correlation matrix "
-                    "without an array of error values!")
+                raise ValueError("Cannot construct matrix-type error from correlation matrix " "without an array of error values!")
             _cm = self._calculate_cov_mat_from_cor_mat_and_error_array(err_val, err_matrix)
             if self.relative:
                 self.cov_mat_rel = _cm
             else:
                 self.cov_mat = _cm
         else:
-            raise ValueError("Unknown matrix type '%s'. Expected one of: %r" % (matrix_type, ('cov', 'cor')))
+            raise ValueError("Unknown matrix type '%s'. Expected one of: %r" % (matrix_type, ("cov", "cor")))
 
     # -- static methods
 
@@ -581,8 +582,8 @@ class MatrixGaussianError(GaussianErrorBase):
         # TODO: check if corr_mat is symmetric and positive definite (?)
         if error_array.ndim > 0 and error_array.shape[0] != corr_mat.shape[0]:
             raise ValueError(
-                f"Error array has size {error_array.shape[0]} but "
-                f"correlation matrix has size {corr_mat.shape[0]}, must be the same.")
+                f"Error array has size {error_array.shape[0]} but " f"correlation matrix has size {corr_mat.shape[0]}, must be the same."
+            )
         cov_mat = np.asarray(np.outer(error_array, error_array)) * np.asarray(corr_mat)
         return CovMat(cov_mat)
 
@@ -612,9 +613,7 @@ class MatrixGaussianError(GaussianErrorBase):
         """"""
         if self.relative:
             if self.reference is None:
-                raise AttributeError(
-                    "Requested 'absolute' covariance matrix for error object declared 'relative', "
-                    "but 'reference' not set!")
+                raise AttributeError("Requested 'absolute' covariance matrix for error object declared 'relative', " "but 'reference' not set!")
             self._cov_mat = self._calculate_cov_mat_from_cov_rel(self.cov_mat_rel, self.reference)
         return self._cov_mat.mat
 
@@ -629,8 +628,7 @@ class MatrixGaussianError(GaussianErrorBase):
         """"""
         if not self.relative:
             if self.reference is None:
-                raise AttributeError(
-                    "Requested 'relative' covariance matrix for error object declared 'absolute', but 'reference' not set!")
+                raise AttributeError("Requested 'relative' covariance matrix for error object declared 'absolute', but 'reference' not set!")
             self._cov_mat_rel = self._calculate_cov_mat_rel_from_cov(self.cov_mat, self.reference)
         return self._cov_mat_rel.mat
 
@@ -651,8 +649,7 @@ class MatrixGaussianError(GaussianErrorBase):
         if self._err is None:
             if self.relative:
                 if self.reference is None:
-                    raise AttributeError(
-                        "Requested 'absolute' error array for error object declared 'relative', but 'reference' not set!")
+                    raise AttributeError("Requested 'absolute' error array for error object declared 'relative', but 'reference' not set!")
             self._err = np.sqrt(np.diag(self.cov_mat))
         return self._err
 
@@ -662,8 +659,7 @@ class MatrixGaussianError(GaussianErrorBase):
         if self._err_rel is None:
             if not self.relative:
                 if self.reference is None:
-                    raise AttributeError(
-                        "Requested 'relative' error array for error object declared 'absolute', but 'reference' not set!")
+                    raise AttributeError("Requested 'relative' error array for error object declared 'absolute', but 'reference' not set!")
             self._err_rel = np.sqrt(np.diag(self.cov_mat_rel))
         return self._err_rel
 
@@ -713,4 +709,3 @@ class MatrixGaussianError(GaussianErrorBase):
         _mat = self.cov_mat
         if np.any(_mat != _mat.T):
             warnings.warn("Covariance matrix is not symmetrical: %s" % _mat)
-
