@@ -1,12 +1,14 @@
 import abc
+
 import six
-from .nexus import Nexus
-from .nexus_fitter import NexusFitter, NexusFitterException
+
 from ...config import kc
+from .nexus import Nexus
+from .nexus_fitter import NexusFitter
 
-__all__ = ['get_fitter', 'Nexus', 'NexusFitter', 'NexusFitterException']
+__all__ = ["get_fitter", "Nexus", "NexusFitter"]
 
-AVAILABLE_FITTERS = {'nexus_fitter': NexusFitter}
+AVAILABLE_FITTERS = {"nexus_fitter": NexusFitter}
 
 
 # try:
@@ -21,11 +23,9 @@ AVAILABLE_FITTERS = {'nexus_fitter': NexusFitter}
 
 
 def get_fitter(fitter_spec):
-    global AVAILABLE_FITTERS
-
     # for 'None', return the default fitter
     if fitter_spec is None:
-        _fitter = AVAILABLE_FITTERS.get(kc['core']['fitters']['default_fitter'], None)
+        _fitter = AVAILABLE_FITTERS.get(kc["core"]["fitters"]["default_fitter"], None)
     else:
         fitter_spec = fitter_spec.lower()
         _fitter = AVAILABLE_FITTERS.get(fitter_spec, None)
