@@ -6,19 +6,17 @@ from copy import copy
 import numpy as np
 import six
 
+from ...core.error import MatrixGaussianError, SimpleGaussianError
+from ...tools import (
+    random_alphanumeric,  # relative import of kafe2.tools not kafe2.fit.tools
+)
 from ..io.file import FileIOMixin
-from ...core.error import SimpleGaussianError, MatrixGaussianError
-from ...tools import random_alphanumeric  # relative import of kafe2.tools not kafe2.fit.tools
 
-__all__ = ["DataContainerBase", "DataContainerException"]
-
-
-class DataContainerException(Exception):
-    pass
+__all__ = ["DataContainerBase"]
 
 
 @six.add_metaclass(abc.ABCMeta)
-class DataContainerBase(FileIOMixin, object):
+class DataContainerBase(FileIOMixin):
     """This is a purely abstract class implementing the minimal interface required by all types of data containers.
 
     It stores measurement data and uncertainties.
@@ -40,7 +38,7 @@ class DataContainerBase(FileIOMixin, object):
 
     @classmethod
     def _get_object_type_name(cls):
-        return 'container'
+        return "container"
 
     @abc.abstractmethod
     def _calculate_total_error(self):
@@ -54,17 +52,17 @@ class DataContainerBase(FileIOMixin, object):
         """create a new entry <name> under self._error_dicts,
         with keys err=<ErrorObject> and arbitrary additional keys"""
         if error_object.error.shape[0] != self.size:
-            raise ValueError(f"Error must have size {self.size} but"
-                             f"received error with size {error_object.error.shape[0]}")
+            raise ValueError(f"Error must have size {self.size} but" f"received error with size {error_object.error.shape[0]}")
         _name = name
         if _name is not None and _name in self._error_dicts:
-            raise DataContainerException("Cannot create error source with name '{}': "
-                                         "there is already an error source registered under that name!".format(_name))
+            raise ValueError(
+                "Cannot create error source with name '{}': there is already an error " "source registered under that name!".format(_name)
+            )
         # be paranoid about name collisions
         while _name is None or _name in self._error_dicts:
             _name = random_alphanumeric(size=8)
 
-        additional_error_dict_keys.setdefault('enabled', True)  # enable error source, unless explicitly disabled
+        additional_error_dict_keys.setdefault("enabled", True)  # enable error source, unless explicitly disabled
 
         axis = additional_error_dict_keys.get("axis", None)
         if axis is not None:
@@ -82,7 +80,7 @@ class DataContainerBase(FileIOMixin, object):
         """return a dictionary containing the error object for error 'name' and additional information"""
         _err_dict = self._error_dicts.get(error_name, None)
         if _err_dict is None:
-            raise DataContainerException("No error with name '{}'!".format(error_name))
+            raise ValueError("No error with name '{}'!".format(error_name))
         return _err_dict
 
     def _on_error_change(self):
@@ -221,14 +219,12 @@ class DataContainerBase(FileIOMixin, object):
         if err_val.ndim == 0:  # if dimensionless numpy array (i.e. float64), add a dimension
             err_val = np.ones(self.size) * err_val
 
-        _err = SimpleGaussianError(err_val=err_val, corr_coeff=correlation,
-                                   relative=relative, reference=reference)
+        _err = SimpleGaussianError(err_val=err_val, corr_coeff=correlation, relative=relative, reference=reference)
 
         _name = self._add_error_object(name=name, error_object=_err)
         return _name
 
-    def add_matrix_error(self, err_matrix, matrix_type,
-                         name=None, err_val=None, relative=False, reference=None):
+    def add_matrix_error(self, err_matrix, matrix_type, name=None, err_val=None, relative=False, reference=None):
         """Add a matrix uncertainty source to the data container.
 
         :param err_matrix: Covariance or correlation matrix.
@@ -247,8 +243,13 @@ class DataContainerBase(FileIOMixin, object):
         :return: An error id which uniquely identifies the created error source.
         :rtype: str
         """
-        _err = MatrixGaussianError(err_matrix=err_matrix, matrix_type=matrix_type, err_val=err_val,
-                                   relative=relative, reference=reference)
+        _err = MatrixGaussianError(
+            err_matrix=err_matrix,
+            matrix_type=matrix_type,
+            err_val=err_val,
+            relative=relative,
+            reference=reference,
+        )
         _err.check_cov_mat_symmetry()
 
         _name = self._add_error_object(name=name, error_object=_err)
@@ -261,7 +262,7 @@ class DataContainerBase(FileIOMixin, object):
         :type error_name: str
         """
         _err_dict = self._get_error_by_name_raise(error_name)
-        _err_dict['enabled'] = False
+        _err_dict["enabled"] = False
         self._on_error_change()
 
     def enable_error(self, error_name):
@@ -271,10 +272,10 @@ class DataContainerBase(FileIOMixin, object):
         :type error_name: str
         """
         _err_dict = self._get_error_by_name_raise(error_name)
-        _err_dict['enabled'] = True
+        _err_dict["enabled"] = True
         self._on_error_change()
 
-    def get_matching_errors(self, matching_criteria=None, matching_type='equal'):
+    def get_matching_errors(self, matching_criteria=None, matching_type="equal"):
         """Return a list of uncertainty objects fulfilling the specified matching criteria.
 
         Valid keys for **matching_criteria**:
@@ -308,32 +309,32 @@ class DataContainerBase(FileIOMixin, object):
         if matching_criteria is None:
             matching_criteria = dict()
 
-        if matching_type == 'regex':
+        if matching_type == "regex":
             raise NotImplementedError("Matching type 'regex' not yet implemented!")
-        if matching_type != 'equal':
-            raise NotImplementedError("Unknown matching type: '{}'! "
-                                      "Available: ['equals']".format(matching_type))
+        if matching_type != "equal":
+            raise NotImplementedError("Unknown matching type: '{}'! " "Available: ['equals']".format(matching_type))
 
         for _crit_key, _crit_value in six.iteritems(matching_criteria):
             # go through all errors, removing those that don't match
             for _error_name, _error_dict in list(_result.items()):  # do not use an iterator!
-                if _crit_key == 'name' and _error_name == _crit_value:
+                if _crit_key == "name" and _error_name == _crit_value:
                     continue
-                elif _crit_key == 'type':
+                elif _crit_key == "type":
                     # type 'simple'
-                    _err_obj = _error_dict['err']
-                    if ((_crit_value == 'simple' and isinstance(_err_obj, SimpleGaussianError)) or
-                            (_crit_value == 'matrix' and isinstance(_err_obj, MatrixGaussianError))):
+                    _err_obj = _error_dict["err"]
+                    if (_crit_value == "simple" and isinstance(_err_obj, SimpleGaussianError)) or (
+                        _crit_value == "matrix" and isinstance(_err_obj, MatrixGaussianError)
+                    ):
                         continue
-                elif _crit_key == 'correlated':
-                    _err_obj = _error_dict['err']
+                elif _crit_key == "correlated":
+                    _err_obj = _error_dict["err"]
                     try:
                         if _crit_value == bool(_err_obj.corr_coeff != 0):
                             continue
                     except AttributeError:
                         pass  # error is a MatrixGaussianError and will not be matched
-                elif _crit_key == 'relative':
-                    _err_obj = _error_dict['err']
+                elif _crit_key == "relative":
+                    _err_obj = _error_dict["err"]
                     if _err_obj.relative == _crit_value:
                         continue
                 else:
@@ -353,7 +354,7 @@ class DataContainerBase(FileIOMixin, object):
             if not _result:
                 break
 
-        return {_name: _entry['err'] for _name, _entry in six.iteritems(_result)}
+        return {_name: _entry["err"] for _name, _entry in six.iteritems(_result)}
 
     def get_error(self, error_name):
         """Return the uncertainty object holding the uncertainty.
