@@ -1,12 +1,18 @@
-import numpy as np
-import six
 import warnings
 
-from scipy.stats import poisson, norm, chi2
+import numpy as np
+import six
 from scipy.linalg import solve_triangular
+from scipy.stats import chi2, norm, poisson
+
 from ..io.file import FileIOMixin
-from .format import ParameterFormatter, CostFunctionFormatter
-from ..util import cholesky_decomposition, log_determinant
+from ..util import (
+    cholesky_decomposition,
+    log_determinant_cholesky,
+    log_determinant_qr,
+    qr_decomposition,
+)
+from .format import CostFunctionFormatter, ParameterFormatter
 
 if six.PY2:
     from funcsigs import signature
@@ -14,15 +20,12 @@ else:
     from inspect import signature
 
 
-__all__ = ["CostFunction",
-           "CostFunction_Chi2",
-           "CostFunction_NegLogLikelihood",
-           "CostFunction_GaussApproximation",
-           "CostFunctionException"]
-
-
-class CostFunctionException(Exception):
-    pass
+__all__ = [
+    "CostFunction",
+    "CostFunction_Chi2",
+    "CostFunction_NegLogLikelihood",
+    "CostFunction_GaussApproximation",
+]
 
 
 class CostFunction(FileIOMixin, object):
@@ -44,15 +47,13 @@ class CostFunction(FileIOMixin, object):
     cost function and to ensure the function can be used as a cost function (validation).
     """
 
-    EXCEPTION_TYPE = CostFunctionException
     _DATA_NAME = "data"
     _MODEL_NAME = "model"
     _COV_MAT_CHOLESKY_NAME = "total_cov_mat_cholesky"
+    _COV_MAT_QR_NAME = "total_cov_mat_qr"
     _ERROR_NAME = "total_error"
 
-    def __init__(
-            self, cost_function, arg_names=None, add_constraint_cost=True,
-            add_determinant_cost=False):
+    def __init__(self, cost_function, arg_names=None, add_constraint_cost=True, add_determinant_cost=False, fast_math=False):
         """
         Construct :py:class:`CostFunction` object (a wrapper for a native Python function):
 
@@ -64,6 +65,7 @@ class CostFunction(FileIOMixin, object):
         :param bool add_determinant_cost: If :py:obj:`True`, automatically increase the cost
             function value by the logarithm of the determinant of the covariance matrix to reduce
             bias.
+        :param bool fast_math: If :py:obj:`True`, prefer speed over numerical stability.
         """
         self._cost_function_handle = cost_function
         _signature = signature(self._cost_function_handle)
@@ -71,27 +73,28 @@ class CostFunction(FileIOMixin, object):
             self._arg_names = list(_signature.parameters.keys())
             for _par in _signature.parameters.values():
                 if _par.kind == _par.VAR_POSITIONAL:
-                    raise self.__class__.EXCEPTION_TYPE(
+                    raise ValueError(
                         "Cost function '{}' with variable number of positional arguments "
-                        "(*{}) needs explicit argument names.".format(
-                            self._cost_function_handle.__name__, _par.name))
+                        "(*{}) needs explicit argument names.".format(self._cost_function_handle.__name__, _par.name)
+                    )
         else:
             self._arg_names = list(arg_names)
         if "cost" in self._arg_names:
-            raise self.__class__.EXCEPTION_TYPE(
-                "The alias 'cost' for the cost function value cannot be used as a name for one of"
-                "the cost function arguments!")
+            raise ValueError("The alias 'cost' for the cost function value cannot be used as a name for one of" "the cost function arguments!")
         for _par in _signature.parameters.values():
             if _par.kind == _par.VAR_KEYWORD:
-                raise self.__class__.EXCEPTION_TYPE(
+                raise ValueError(
                     "Cost function '{}' with variable number of keyword arguments "
                     "(**{}) is not supported.".format(
-                        self._cost_function_handle.__name__, _par.name, ))
+                        self._cost_function_handle.__name__,
+                        _par.name,
+                    )
+                )
         self._arg_count = len(self._arg_names)
         self._formatter = CostFunctionFormatter(
             name=self.name,
-            arg_formatters=[ParameterFormatter(_arg_name, value=0, error=None)
-                            for _arg_name in self._arg_names])
+            arg_formatters=[ParameterFormatter(_arg_name, value=0, error=None) for _arg_name in self._arg_names],
+        )
 
         self._add_constraint_cost = add_constraint_cost
         if self._add_constraint_cost:
@@ -104,6 +107,7 @@ class CostFunction(FileIOMixin, object):
             else:
                 self._arg_names += ["total_cov_mat_log_determinant"]
             self._arg_count += 1
+        self._fast_math = fast_math
 
         self._errors_valid = True
         self._needs_errors = True
@@ -118,7 +122,7 @@ class CostFunction(FileIOMixin, object):
 
     @classmethod
     def _get_object_type_name(cls):
-        return 'cost_function'
+        return "cost_function"
 
     def __call__(self, *args):
         additional_cost = 0.0
@@ -200,6 +204,11 @@ class CostFunction(FileIOMixin, object):
     def errors_valid(self):
         return self._errors_valid
 
+    @property
+    def fast_math(self):
+        """Prefer speed over numerical stability."""
+        return self._fast_math
+
     def goodness_of_fit(self, *args):
         """How well the model agrees with the data."""
         try:
@@ -252,8 +261,13 @@ class CostFunction(FileIOMixin, object):
 
 class CostFunction_Chi2(CostFunction):
     def __init__(
-            self, errors_to_use='covariance', fallback_on_singular=True, add_constraint_cost=True,
-            add_determinant_cost=True):
+        self,
+        errors_to_use="covariance",
+        fallback_on_singular=True,
+        add_constraint_cost=True,
+        add_determinant_cost=True,
+        fast_math=False,
+    ):
         """Base class for built-in least-squares cost function.
 
         :param errors_to_use: Which errors to use when calculating :math:`\\chi^2`.
@@ -266,6 +280,7 @@ class CostFunction_Chi2(CostFunction):
         :param bool add_determinant_cost: If :py:obj:`True`, automatically increase the cost
             function value by the logarithm of the determinant of the covariance matrix to reduce
             bias.
+        :param bool fast_math: If :py:obj:`True`, prefer speed over numerical stability.
         """
 
         _cost_function_description = "chi-square"
@@ -275,28 +290,27 @@ class CostFunction_Chi2(CostFunction):
             self._fail_on_no_matrix = False
             self._fail_on_no_errors = False
             _cost_function_description += " (no uncertainties)"
-        elif errors_to_use.lower() == 'covariance':
-            _chi2_func = self.chi2_covariance
-            _arg_names = [self._DATA_NAME, self._MODEL_NAME, self._COV_MAT_CHOLESKY_NAME]
+        elif errors_to_use.lower() == "covariance":
+            _chi2_func = self.chi2_covariance_fast if fast_math else self.chi2_covariance
+            _arg_names = [self._DATA_NAME, self._MODEL_NAME, self._COV_MAT_CHOLESKY_NAME if fast_math else self._COV_MAT_QR_NAME]
             self._fail_on_no_matrix = not fallback_on_singular
             self._fail_on_no_errors = True
             _cost_function_description += " (with covariance matrix)"
-        elif errors_to_use.lower() == 'pointwise':
+        elif errors_to_use.lower() == "pointwise":
             _chi2_func = self.chi2_pointwise_errors
             _arg_names = [self._DATA_NAME, self._MODEL_NAME, self._ERROR_NAME]
             self._fail_on_no_matrix = False
             self._fail_on_no_errors = not fallback_on_singular
             _cost_function_description += " (with pointwise errors)"
         else:
-            raise ValueError(
-                "Unknown value '%s' for 'errors_to_use': must be one of "
-                "('covariance', 'pointwise', None)")
+            raise ValueError("Unknown value '%s' for 'errors_to_use': must be one of " "('covariance', 'pointwise', None)")
 
         super(CostFunction_Chi2, self).__init__(
             cost_function=_chi2_func,
             arg_names=_arg_names,
             add_constraint_cost=add_constraint_cost,
-            add_determinant_cost=add_determinant_cost
+            add_determinant_cost=add_determinant_cost,
+            fast_math=fast_math,
         )
 
         self._formatter.latex_name = "\\chi^2"
@@ -307,18 +321,22 @@ class CostFunction_Chi2(CostFunction):
         self._saturated = True
         self._kafe2go_identifier = self.name
 
-    def _chi2(self, data, model, cov_mat_cholesky=None, err=None):
+    def _chi2(self, data, model, cov_mat_qr=None, cov_mat_cholesky=None, err=None):
         data = np.asarray(data)
         model = np.asarray(model)
 
         if model.shape != data.shape:
-            raise ValueError(
-                "'data' and 'model' must have the same shape! Got %r and %r..."
-                % (data.shape, model.shape))
+            raise ValueError("'data' and 'model' must have the same shape! Got %r and %r..." % (data.shape, model.shape))
 
-        _res = (data - model)
+        _res = data - model
 
-        # if a covariance matrix inverse is given, use it
+        # if a covariance matrix decomposition is given, use it
+        if cov_mat_qr is not None:
+            try:
+                _x = solve_triangular(cov_mat_qr[1], _res, lower=False, trans="T")
+            except ValueError:
+                return np.inf
+            return _res.dot(cov_mat_qr[0]).dot(_x)
         if cov_mat_cholesky is not None:
             try:
                 _x = solve_triangular(cov_mat_cholesky, _res, lower=True)
@@ -327,13 +345,13 @@ class CostFunction_Chi2(CostFunction):
             return np.inner(_x, _x)
 
         if self._fail_on_no_matrix:
-            raise CostFunctionException("Covariance matrix is singular!")
+            raise ValueError("Covariance matrix is singular!")
 
         # otherwise, if an array of point-wise errors is given, use that
         if err is not None:
             if np.any(err == 0.0):
                 if self._fail_on_no_errors:
-                    raise CostFunctionException("'err' must not contain any zero values!")
+                    raise ValueError("'err' must not contain any zero values!")
                 if self.needs_errors:
                     # There are other warnings that notify the user about singular cov mat, etc.
                     warnings.warn("Setting all data errors to 1 as a fallback.")
@@ -367,7 +385,7 @@ class CostFunction_Chi2(CostFunction):
         """
         return self._chi2(data=data, model=model)
 
-    def chi2_covariance(self, data, model, total_cov_mat_cholesky):
+    def chi2_covariance(self, data, model, total_cov_mat_qr):
         r"""A least-squares cost function calculated from (`y`) data and model values,
         considering the covariance matrix of the (`y`) measurements.
         The cost function value can be calculated as follows:
@@ -388,6 +406,18 @@ class CostFunction_Chi2(CostFunction):
         and :math:`C_{\rm det}({\bf V}) = \ln \det({\bf V})` is the additional cost to compensate
         for a non-constant covariance matrix.
 
+        :param data: measurement data :math:`{\bf d}`
+        :param model: model predictions :math:`{\bf m}`
+        :param total_cov_mat_qr: QR decomposition of the total covariance matrix
+            :math:`{\bf QR} = {\bf V}`
+
+        :return: cost function value
+        """
+        return self._chi2(data=data, model=model, cov_mat_qr=total_cov_mat_qr)
+
+    def chi2_covariance_fast(self, data, model, total_cov_mat_cholesky):
+        r"""Same as :py:meth:`chi2_covariance` but faster at the cost of numerical stability.
+
         :param data: measurement data :math:`{\bf d}`
         :param model: model predictions :math:`{\bf m}`
         :param total_cov_mat_cholesky: Cholesky decomposition  of the total covariance matrix
@@ -435,14 +465,14 @@ class CostFunction_Chi2(CostFunction):
                 errors_to_use="pointwise",
                 fallback_on_singular=not self._fail_on_no_matrix,
                 add_constraint_cost=self._add_constraint_cost,
-                add_determinant_cost=self._add_determinant_cost
+                add_determinant_cost=self._add_determinant_cost,
             )
         else:
             return None
 
 
 class CostFunction_NegLogLikelihood(CostFunction):
-    def __init__(self, data_point_distribution='poisson', ratio=False):
+    def __init__(self, data_point_distribution="poisson", ratio=False):
         r"""
         Base class for built-in negative log-likelihood cost function.
 
@@ -483,14 +513,9 @@ class CostFunction_NegLogLikelihood(CostFunction):
             _cost_function_description += " (Poisson uncertainties)"
             _arg_names = [self._DATA_NAME, self._MODEL_NAME]
         else:
-            raise ValueError("Unknown value '%s' for 'data_point_distribution': "
-                             "must be one of ('gaussian', 'poisson')!")
+            raise ValueError("Unknown value '%s' for 'data_point_distribution': " "must be one of ('gaussian', 'poisson')!")
 
-        super(CostFunction_NegLogLikelihood, self).__init__(
-            cost_function=_nll_func,
-            arg_names=_arg_names,
-            add_determinant_cost=False
-        )
+        super(CostFunction_NegLogLikelihood, self).__init__(cost_function=_nll_func, arg_names=_arg_names, add_determinant_cost=False)
 
         if ratio:
             self._formatter.latex_name = r"-2\ln\mathcal{L}_{\rm R}"
@@ -596,8 +621,7 @@ class CostFunction_NegLogLikelihood(CostFunction):
         return -2.0 * _log_likelihood_ratio
 
     def is_data_compatible(self, data):
-        if self._cost_function_handle in [self.nll_poisson, self.nllr_poisson] \
-                and (np.count_nonzero(data % 1) > 0 or np.any(data < 0)):
+        if self._cost_function_handle in [self.nll_poisson, self.nllr_poisson] and (np.count_nonzero(data % 1) > 0 or np.any(data < 0)):
             return False, "poisson distribution can only have non-negative integers as y data."
         return True, None
 
@@ -608,8 +632,7 @@ class CostFunction_NegLogLikelihood(CostFunction):
 
 
 class CostFunction_GaussApproximation(CostFunction):
-    def __init__(
-            self, errors_to_use='covariance', add_constraint_cost=True, add_determinant_cost=True):
+    def __init__(self, errors_to_use="covariance", add_constraint_cost=True, add_determinant_cost=True, fast_math=False):
         """
         Base class for built-in Gaussian approximation of the Poisson negative log-likelihood cost
         function.
@@ -622,27 +645,27 @@ class CostFunction_GaussApproximation(CostFunction):
         :param bool add_determinant_cost: If :py:obj:`True`, automatically increase the cost
             function value by the logarithm of the determinant of the covariance matrix to reduce
             bias.
+        :param bool fast_math: If :py:obj:`True`, prefer speed over numerical stability.
         """
 
         _cost_function_description = "Gaussian approximation of Poisson NLL"
-        if errors_to_use.lower() == 'covariance':
+        if errors_to_use.lower() == "covariance":
             _cost_function = self.gaussian_approximation_covariance
-            _arg_names = [self._DATA_NAME, self._MODEL_NAME, self._COV_MAT_CHOLESKY_NAME]
+            _arg_names = [self._DATA_NAME, self._MODEL_NAME, self._COV_MAT_CHOLESKY_NAME if fast_math else self._COV_MAT_QR_NAME]
             _cost_function_description += " (with covariance matrix)"
-        elif errors_to_use.lower() == 'pointwise':
+        elif errors_to_use.lower() == "pointwise":
             _cost_function = self.gaussian_approximation_pointwise_errors
             _arg_names = [self._DATA_NAME, self._MODEL_NAME, self._ERROR_NAME]
             _cost_function_description += " (with pointwise errors)"
         else:
-            raise ValueError(
-                "Unknown value '%s' for 'errors_to_use': must be one of "
-                "('covariance', 'pointwise')")
+            raise ValueError("Unknown value '%s' for 'errors_to_use': must be one of " "('covariance', 'pointwise')")
 
         super().__init__(
             cost_function=_cost_function,
             arg_names=_arg_names,
             add_constraint_cost=add_constraint_cost,
-            add_determinant_cost=False
+            add_determinant_cost=False,
+            fast_math=fast_math,
         )
         self._add_determinant_cost_ga = add_determinant_cost
 
@@ -682,15 +705,25 @@ class CostFunction_GaussApproximation(CostFunction):
 
         :return: cost function value
         """
-        _cholesky = cholesky_decomposition(total_cov_mat + np.diag(model))
         _residuals = model - data
-        try:
-            _x = solve_triangular(_cholesky, _residuals, lower=True)
-        except ValueError:
-            return np.inf
-        _cost = np.sum(np.square(_x))
-        if self._add_determinant_cost_ga:
-            _cost += log_determinant(_cholesky)
+        if self._fast_math:
+            _cholesky = cholesky_decomposition(total_cov_mat + np.diag(model))
+            try:
+                _x = solve_triangular(_cholesky, _residuals, lower=True)
+            except ValueError:
+                return np.inf
+            _cost = np.sum(np.square(_x))
+            if self._add_determinant_cost_ga:
+                _cost += log_determinant_cholesky(_cholesky)
+        else:
+            _QR = qr_decomposition(total_cov_mat + np.diag(model))
+            try:
+                _x = solve_triangular(_QR[1], _residuals, lower=False, trans="T")
+            except ValueError:
+                return np.inf
+            _cost = _residuals.dot(_QR[0]).dot(_x)
+            if self._add_determinant_cost_ga:
+                _cost += log_determinant_qr(_QR)
         return _cost
 
     def gaussian_approximation_pointwise_errors(self, data, model, total_error):
@@ -721,7 +754,7 @@ class CostFunction_GaussApproximation(CostFunction):
         _residuals = model - data
         if np.all(_residuals == 0):
             return 0
-        _variances = model + total_error ** 2
+        _variances = model + total_error**2
         _cost = np.sum(np.square(_residuals) / _variances)
         if self._add_determinant_cost_ga:
             _cost += np.sum(np.log(_variances))
@@ -739,7 +772,7 @@ class CostFunction_GaussApproximation(CostFunction):
             return type(self)(
                 errors_to_use="pointwise",
                 add_constraint_cost=self._add_constraint_cost,
-                add_determinant_cost=self._add_determinant_cost
+                add_determinant_cost=self._add_determinant_cost,
             )
         else:
             return None
@@ -756,52 +789,93 @@ class CostFunction_GaussApproximation(CostFunction):
 
 
 STRING_TO_COST_FUNCTION = {
-    'chi2': (CostFunction_Chi2, {}),
-    'chi_2': (CostFunction_Chi2, {}),
-    'chisquared': (CostFunction_Chi2, {}),
-    'chi_squared': (CostFunction_Chi2, {}),
-    'chi2_no_errors': (CostFunction_Chi2, {"errors_to_use": None, "add_determinant_cost": False}),
-    'chi2_pointwise': (CostFunction_Chi2, {"errors_to_use": "pointwise"}),
-    'chi2_pointwise_errors': (CostFunction_Chi2, {"errors_to_use": "pointwise"}),
-    'chi2_covariance': (CostFunction_Chi2, {"errors_to_use": "covariance"}),
-    'nll': (CostFunction_NegLogLikelihood, {"ratio": False}),
-    'poisson': (CostFunction_NegLogLikelihood,
-                {"data_point_distribution": "poisson", "ratio": False}),
-    'nll-poisson': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "poisson", "ratio": False}),
-    'nll_poisson': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "poisson", "ratio": False}),
-    'nllpoisson': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "poisson", "ratio": False}),
-    'nll-gaussian': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "gaussian", "ratio": False}),
-    'nll_gaussian': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "gaussian", "ratio": False}),
-    'nllgaussiann': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "gaussian", "ratio": False}),
-    'negloglikelihood': (CostFunction_NegLogLikelihood, {"ratio": False}),
-    'neg_log_likelihood': (CostFunction_NegLogLikelihood, {"ratio": False}),
-    'nllr': (CostFunction_NegLogLikelihood, {"ratio": True}),
-    'nllr-poisson': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "poisson", "ratio": True}),
-    'nllr_poisson': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "poisson", "ratio": True}),
-    'nllrpoisson': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "poisson", "ratio": True}),
-    'nllr-gaussian': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "gaussian", "ratio": True}),
-    'nllr_gaussian': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "gaussian", "ratio": True}),
-    'nllrgaussian': (CostFunction_NegLogLikelihood,
-                    {"data_point_distribution": "gaussian", "ratio": True}),
-    'negloglikelihoodratio': (CostFunction_NegLogLikelihood, {"ratio": True}),
-    'neg_log_likelihood_ratio': (CostFunction_NegLogLikelihood, {"ratio": True}),
-    'gauss-approximation': (CostFunction_GaussApproximation, {}),
-    'gauss_approximation': (CostFunction_GaussApproximation, {}),
-    'gauss_approximation_covariance': (
-        CostFunction_GaussApproximation, {"errors_to_use": "covariance"}),
-    'gauss_approximation_pointwise': (
-        CostFunction_GaussApproximation, {"errors_to_use": "pointwise"}),
-    'gauss_approximation_pointwise_errors': (
-        CostFunction_GaussApproximation, {"errors_to_use": "pointwise"}),
+    "chi2": (CostFunction_Chi2, {}),
+    "chi2_fast": (CostFunction_Chi2, {"fast_math": True}),
+    "chi_2": (CostFunction_Chi2, {}),
+    "chi_2_fast": (CostFunction_Chi2, {"fast_math": True}),
+    "chisquared": (CostFunction_Chi2, {}),
+    "chisquared_fast": (CostFunction_Chi2, {"fast_math": True}),
+    "chi_squared": (CostFunction_Chi2, {}),
+    "chi_squared_fast": (CostFunction_Chi2, {"fast_math": True}),
+    "chi2_no_errors": (CostFunction_Chi2, {"errors_to_use": None, "add_determinant_cost": False}),
+    "chi2_pointwise": (CostFunction_Chi2, {"errors_to_use": "pointwise"}),
+    "chi2_pointwise_errors": (CostFunction_Chi2, {"errors_to_use": "pointwise"}),
+    "chi2_covariance": (CostFunction_Chi2, {"errors_to_use": "covariance"}),
+    "chi2_covariance_fast": (CostFunction_Chi2, {"errors_to_use": "covariance", "fast_math": True}),
+    "nll": (CostFunction_NegLogLikelihood, {"ratio": False}),
+    "poisson": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "poisson", "ratio": False},
+    ),
+    "nll-poisson": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "poisson", "ratio": False},
+    ),
+    "nll_poisson": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "poisson", "ratio": False},
+    ),
+    "nllpoisson": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "poisson", "ratio": False},
+    ),
+    "nll-gaussian": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "gaussian", "ratio": False},
+    ),
+    "nll_gaussian": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "gaussian", "ratio": False},
+    ),
+    "nllgaussiann": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "gaussian", "ratio": False},
+    ),
+    "negloglikelihood": (CostFunction_NegLogLikelihood, {"ratio": False}),
+    "neg_log_likelihood": (CostFunction_NegLogLikelihood, {"ratio": False}),
+    "nllr": (CostFunction_NegLogLikelihood, {"ratio": True}),
+    "nllr-poisson": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "poisson", "ratio": True},
+    ),
+    "nllr_poisson": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "poisson", "ratio": True},
+    ),
+    "nllrpoisson": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "poisson", "ratio": True},
+    ),
+    "nllr-gaussian": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "gaussian", "ratio": True},
+    ),
+    "nllr_gaussian": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "gaussian", "ratio": True},
+    ),
+    "nllrgaussian": (
+        CostFunction_NegLogLikelihood,
+        {"data_point_distribution": "gaussian", "ratio": True},
+    ),
+    "negloglikelihoodratio": (CostFunction_NegLogLikelihood, {"ratio": True}),
+    "neg_log_likelihood_ratio": (CostFunction_NegLogLikelihood, {"ratio": True}),
+    "gauss-approximation": (CostFunction_GaussApproximation, {}),
+    "gauss_approximation": (CostFunction_GaussApproximation, {}),
+    "gauss_approximation_covariance": (
+        CostFunction_GaussApproximation,
+        {"errors_to_use": "covariance"},
+    ),
+    "gauss_approximation_covariance_fast": (
+        CostFunction_GaussApproximation,
+        {"errors_to_use": "covariance", "fast_math": True},
+    ),
+    "gauss_approximation_pointwise": (
+        CostFunction_GaussApproximation,
+        {"errors_to_use": "pointwise"},
+    ),
+    "gauss_approximation_pointwise_errors": (
+        CostFunction_GaussApproximation,
+        {"errors_to_use": "pointwise"},
+    ),
 }
