@@ -1,20 +1,59 @@
 import copy
 import re
+from math import isfinite
 
 import numpy as np
 
 from ..io.file import FileIOMixin
 
-__all__ = ["FormatterException", "ScalarFormatter", "ParameterFormatter", "FunctionFormatter",
-           "ModelFunctionFormatter", "CostFunctionFormatter", "latexify_ascii"]
+__all__ = [
+    "ScalarFormatter",
+    "ParameterFormatter",
+    "FunctionFormatter",
+    "ModelFunctionFormatter",
+    "CostFunctionFormatter",
+    "latexify_ascii",
+]
 
 LATEX_GREEK_LETTERS = [
-    "alpha", "beta", "gamma", "Gamma", "delta", "Delta", "epsilon", "zeta", "eta", "theta", "Theta",
-    "vartheta", "iota", "kappa", "varlambda", "Lambda", "mu", "nu", "omicron", "pi", "Pi", "rho",
-    "sigma", "Sigma", "tau", "upsilon", "Upsilon", "phi", "Phi", "varphi", "chi", "psi", "Psi",
-    "omega", "Omega"
+    "alpha",
+    "beta",
+    "gamma",
+    "Gamma",
+    "delta",
+    "Delta",
+    "epsilon",
+    "zeta",
+    "eta",
+    "theta",
+    "Theta",
+    "vartheta",
+    "iota",
+    "kappa",
+    "varlambda",
+    "Lambda",
+    "mu",
+    "nu",
+    "omicron",
+    "pi",
+    "Pi",
+    "rho",
+    "sigma",
+    "Sigma",
+    "tau",
+    "upsilon",
+    "Upsilon",
+    "phi",
+    "Phi",
+    "varphi",
+    "chi",
+    "psi",
+    "Psi",
+    "omega",
+    "Omega",
 ]
 
+
 # -- formatters for model parameters and model functions
 def latexify_ascii(ascii_string):
     """Create a true type latex string of an standard ascii string.
@@ -27,17 +66,19 @@ def latexify_ascii(ascii_string):
         return None
     if len(ascii_string) == 1:
         return r"{%s}" % ascii_string
-    elif re.compile("^[\d\w]_[\d\w]$").match(ascii_string):
+    if ascii_string.startswith("{") and ascii_string.endswith("}"):
         return ascii_string
+    elif re.compile(r"^[\d\w]_[\d\w]$").match(ascii_string):
+        return r"{%s}" % ascii_string
     _greek_letter_string = None
     for _greek_letter in LATEX_GREEK_LETTERS:
         if ascii_string == _greek_letter:
             _greek_letter_string = r"{\%s}" % _greek_letter
             break
-        if re.compile("^%s_[\d\w]$" % _greek_letter).match(ascii_string):
+        if re.compile(r"^%s_[\d\w]$" % _greek_letter).match(ascii_string):
             _greek_letter_string = r"{\%s}" % ascii_string
             break
-        if re.compile("^[\d\w]_%s$" % _greek_letter).match(ascii_string):
+        if re.compile(r"^[\d\w]_%s$" % _greek_letter).match(ascii_string):
             _greek_letter_string = r"{%s_\%s}" % (ascii_string[:1], _greek_letter)
             break
         if ascii_string.startswith(_greek_letter):
@@ -51,7 +92,7 @@ def latexify_ascii(ascii_string):
     if _greek_letter_string is not None:
         return re.sub("varlambda", "lambda", _greek_letter_string)
 
-    _lpn = ascii_string.replace('_', r"\_")
+    _lpn = ascii_string.replace("_", r"\_")
     return r"{\tt %s}" % _lpn
 
 
@@ -59,10 +100,6 @@ def latexify_ascii(ascii_string):
 # parameters excluding the independent variable(s)
 
 
-class FormatterException(Exception):
-    pass
-
-
 class ScalarFormatter(object):
     def __init__(self, sigma, n_significant_digits=2):
         """Format a scalar to a specified precision, according to the uncertainty.
@@ -82,6 +119,8 @@ class ScalarFormatter(object):
         :param float x: The value to format.
         :rtype: str
         """
+        if not isfinite(x):
+            return "nan"
         # needed e.g. when rounding values like 9.999999 -> 10.0 (shift in decimal place)
         _rounded_x = abs(np.around(x, self._sig))
         # fallback to rounding to 10^(-1) if value is zero
@@ -109,8 +148,7 @@ class ParameterFormatter(FileIOMixin, object):
     The formatted string is obtained by calling the :py:meth:`~.get_formatted` method.
     """
 
-    def __init__(self, arg_name, value=None, error=None, asymmetric_error=None, name=None,
-                 latex_name=None):
+    def __init__(self, arg_name, value=None, error=None, asymmetric_error=None, name=None, latex_name=None):
         """Construct a Parameter Formatter.
 
         :param str arg_name: A plain string indicating the parameter's signature inside the
@@ -144,7 +182,7 @@ class ParameterFormatter(FileIOMixin, object):
 
     @classmethod
     def _get_object_type_name(cls):
-        return 'parameter_formatter'
+        return "parameter_formatter"
 
     @property
     def arg_name(self):
@@ -182,10 +220,10 @@ class ParameterFormatter(FileIOMixin, object):
         # TODO: validate
         if new_latex_name is None:
             self._latex_name = latexify_ascii(self.name)
-        elif new_latex_name.startswith('{') and new_latex_name.endswith('}'):
+        elif new_latex_name.startswith("{") and new_latex_name.endswith("}"):
             self._latex_name = new_latex_name
         else:
-            self._latex_name = '{' + new_latex_name + '}'
+            self._latex_name = "{" + new_latex_name + "}"
 
     @property
     def value(self):
@@ -262,9 +300,17 @@ class ParameterFormatter(FileIOMixin, object):
     def fixed(self, fixed):
         self._fixed = fixed
 
-    def get_formatted(self, with_name=False, with_value=True, with_errors=True,
-                      n_significant_digits=2, round_value_to_error=True, asymmetric_error=False,
-                      format_as_latex=False):
+    def get_formatted(
+        self,
+        value=None,
+        with_name=False,
+        with_value=True,
+        with_errors=True,
+        n_significant_digits=2,
+        round_value_to_error=True,
+        asymmetric_error=False,
+        format_as_latex=False,
+    ):
         """Get a formatted string representing this model parameter.
 
         :param bool with_name: If :py:obj:`True`, the output will include the parameter name.
@@ -280,6 +326,8 @@ class ParameterFormatter(FileIOMixin, object):
         :return: The string representation of the parameter.
         :rtype: str
         """
+        if value is None:
+            value = self.value
         _display_string = ""
         if with_name:
             if format_as_latex:
@@ -296,13 +344,15 @@ class ParameterFormatter(FileIOMixin, object):
                     _display_string += r"$%g$ (fixed)" % self._value
                 else:
                     _display_string += "%g (fixed)" % self._value
-            elif not with_errors or (not asymmetric_error and self.error in (None, 0)) or \
-                    (asymmetric_error and (
-                            self.asymmetric_error is None or np.all(self.asymmetric_error == 0))):
+            elif (
+                not with_errors
+                or (not asymmetric_error and self.error in (None, 0))
+                or (asymmetric_error and (self.asymmetric_error is None or np.all(self.asymmetric_error == 0)))
+            ):
                 if format_as_latex:
-                    _display_string += f"$%.{n_significant_digits}g$" % self.value
+                    _display_string += f"$%.{n_significant_digits}g$" % value
                 else:
-                    _display_string += f"%.{n_significant_digits}g" % self.value
+                    _display_string += f"%.{n_significant_digits}g" % value
             else:
                 if asymmetric_error:
                     _min_err = min(abs(self.error_up), abs(self.error_down))
@@ -315,7 +365,7 @@ class ParameterFormatter(FileIOMixin, object):
                 # calculate decimal precision if rounding:
                 if round_value_to_error:
                     val_formatter = ScalarFormatter(_min_err, n_significant_digits=n_significant_digits)
-                    _val = val_formatter(self.value)
+                    _val = val_formatter(value)
                     _err = "%#.{n}g".format(n=n_significant_digits) % self.error
                     if asymmetric_error:  # needed for different powers of 10 in asymmetric errs
                         if abs(self.error_down) <= abs(self.error_up):
@@ -326,7 +376,7 @@ class ParameterFormatter(FileIOMixin, object):
                             _err_u = "%#.{n}g".format(n=n_significant_digits) % abs(self.error_up)
                 # default cases if no rounding
                 else:
-                    _val = f"%.{n_significant_digits}g" % self.value
+                    _val = f"%.{n_significant_digits}g" % value
                     _err = f"%.{n_significant_digits}g" % self.error
                     if asymmetric_error:
                         _err_u = f"%.{n_significant_digits}g" % self.error_up
@@ -345,8 +395,7 @@ class ParameterFormatter(FileIOMixin, object):
 
             # replace scientific notation with power of ten (LaTeX only)
             if format_as_latex:
-                _display_string = re.sub(r'(-?\d*\.?\d+?)0*e\+?(-?[0-9]*[1-9]?)',
-                                         r'\1\\times10^{\2}', _display_string)
+                _display_string = re.sub(r"(-?\d*\.?\d+?)0*e\+?(-?[0-9]*[1-9]?)", r"\1\\times10^{\2}", _display_string)
         return _display_string
 
 
@@ -365,11 +414,18 @@ class FunctionFormatter(FileIOMixin, object):
 
     The formatted string is obtained by calling the :py:meth:`~get_formatted` method.
     """
+
     DEFAULT_EXPRESSION_STRING = None
     DEFAULT_LATEX_EXPRESSION_STRING = None
 
-    def __init__(self, name, latex_name=None, arg_formatters=None, expression_string=None,
-                 latex_expression_string=None):
+    def __init__(
+        self,
+        name,
+        latex_name=None,
+        arg_formatters=None,
+        expression_string=None,
+        latex_expression_string=None,
+    ):
         """Construct a formatter for a model function:
 
         :param name: A plain-text-formatted string indicating the function name.
@@ -401,7 +457,7 @@ class FunctionFormatter(FileIOMixin, object):
 
     @classmethod
     def _get_object_type_name(cls):
-        return 'function_formatter'
+        return "function_formatter"
 
     def _get_format_kwargs(self, format_as_latex=False):
         """Create a dictionary containing argument name and format pairs.
@@ -427,8 +483,7 @@ class FunctionFormatter(FileIOMixin, object):
             return self._latex_name
         return self._name
 
-    def _get_formatted_pars(self, with_par_values=True, n_significant_digits=2,
-                            format_as_latex=False):
+    def _get_formatted_pars(self, with_par_values=True, n_significant_digits=2, format_as_latex=False):
         """Get a list of the formatted parameters including their values. This can be turned off.
 
         :param bool with_par_values: If the strings should contain the parameter values.
@@ -446,12 +501,16 @@ class FunctionFormatter(FileIOMixin, object):
         if with_par_values:
             _par_val_strings = []
             for _pf in self.par_formatters:
-                _par_val_strings.append(_pf.get_formatted(with_name=False,
-                                                          with_value=True,
-                                                          with_errors=False,
-                                                          n_significant_digits=n_significant_digits,
-                                                          round_value_to_error=False,
-                                                          format_as_latex=format_as_latex))
+                _par_val_strings.append(
+                    _pf.get_formatted(
+                        with_name=False,
+                        with_value=True,
+                        with_errors=False,
+                        n_significant_digits=n_significant_digits,
+                        round_value_to_error=False,
+                        format_as_latex=format_as_latex,
+                    )
+                )
             return ["%s=%s" % (_pn, _pv) for _pn, _pv in zip(_par_name_strings, _par_val_strings)]
         return ["%s" % (_pn,) for _pn in _par_name_strings]
 
@@ -464,11 +523,9 @@ class FunctionFormatter(FileIOMixin, object):
         _kwargs = self._get_format_kwargs(format_as_latex=format_as_latex)
         if format_as_latex and self._latex_expr_string is not None:
             # use all arguments to format the expression string
-            _par_expr_string = self._latex_expr_string.format(
-                *[_af.latex_name for _af in self.arg_formatters], **_kwargs)
+            _par_expr_string = self._latex_expr_string.format(*[_af.latex_name for _af in self.arg_formatters], **_kwargs)
         elif not format_as_latex and self._expr_string is not None:
-            _par_expr_string = self._expr_string.format(
-                *[_af.name for _af in self.arg_formatters], **_kwargs)
+            _par_expr_string = self._expr_string.format(*[_af.name for _af in self.arg_formatters], **_kwargs)
         elif format_as_latex and self._latex_expr_string is None:
             _par_expr_string = self.DEFAULT_LATEX_EXPRESSION_STRING
         else:
@@ -492,10 +549,8 @@ class FunctionFormatter(FileIOMixin, object):
         try:
             self._get_formatted_expression(format_as_latex=False)
         except LookupError:  # fetch key and index errors. Other Errors have other causes.
-            _af_arg_names = [_af.arg_name for _af in self.arg_formatters] if self.arg_formatters \
-                else None
-            raise FormatterException("Expression string %s does not match argument structure %s"
-                                     % (expression_format_string, _af_arg_names))
+            _af_arg_names = [_af.arg_name for _af in self.arg_formatters] if self.arg_formatters else None
+            raise ValueError("Expression string %s does not match argument structure %s" % (expression_format_string, _af_arg_names))
 
     @property
     def latex_expression_format_string(self):
@@ -519,13 +574,11 @@ class FunctionFormatter(FileIOMixin, object):
         self._latex_expr_string = latex_expression_format_string
         try:
             self._get_formatted_expression(format_as_latex=True)
-        except LookupError:  # fetch key and index errors. Other Errors have other causes.
-            _af_arg_names = [_af.arg_name for _af in self.arg_formatters] if self.arg_formatters \
-                else None
-            raise FormatterException(
-                "LaTeX expression string %s does not match argument structure %s" % (
-                    latex_expression_format_string, _af_arg_names)
-            )
+        except LookupError as _e:  # fetch key and index errors. Other Errors have other causes.
+            _af_arg_names = [_af.arg_name for _af in self.arg_formatters] if self.arg_formatters else None
+            raise ValueError(
+                "LaTeX expression string %s does not match argument structure %s" % (latex_expression_format_string, _af_arg_names)
+            ) from _e
 
     @property
     def name(self):
@@ -587,8 +640,13 @@ class FunctionFormatter(FileIOMixin, object):
         """
         return self._arg_formatters  # same as all arguments for base, overwrite when necessary
 
-    def get_formatted(self, with_par_values=False, n_significant_digits=2, format_as_latex=False,
-                      with_expression=False):
+    def get_formatted(
+        self,
+        with_par_values=False,
+        n_significant_digits=2,
+        format_as_latex=False,
+        with_expression=False,
+    ):
         """Get a formatted string representing this model function.
 
         :param bool with_par_values: If :py:obj:`True`, output will include the value of each function parameter
@@ -598,9 +656,11 @@ class FunctionFormatter(FileIOMixin, object):
         :param bool with_expression: If :py:obj:`True`, the returned string will include the expression assigned to the
                                      function.
         """
-        _par_strings = self._get_formatted_pars(with_par_values=with_par_values,
-                                                n_significant_digits=n_significant_digits,
-                                                format_as_latex=format_as_latex)
+        _par_strings = self._get_formatted_pars(
+            with_par_values=with_par_values,
+            n_significant_digits=n_significant_digits,
+            format_as_latex=format_as_latex,
+        )
         _par_expr_string = ""
         if with_expression:
             _par_expr_string = self._get_formatted_expression(format_as_latex=format_as_latex)
@@ -618,15 +678,25 @@ class FunctionFormatter(FileIOMixin, object):
 
 
 class CostFunctionFormatter(FunctionFormatter):
-    """A Formatter class for Cost Functions.
-    """
+    """A Formatter class for Cost Functions."""
 
     def __init__(
-            self, name, name_saturated=None, latex_name=None, latex_name_saturated=None,
-            arg_formatters=None, expression_string=None, latex_expression_string=None):
+        self,
+        name,
+        name_saturated=None,
+        latex_name=None,
+        latex_name_saturated=None,
+        arg_formatters=None,
+        expression_string=None,
+        latex_expression_string=None,
+    ):
         super(CostFunctionFormatter, self).__init__(
-            name=name, latex_name=latex_name, arg_formatters=arg_formatters,
-            expression_string=expression_string, latex_expression_string=latex_expression_string)
+            name=name,
+            latex_name=latex_name,
+            arg_formatters=arg_formatters,
+            expression_string=expression_string,
+            latex_expression_string=latex_expression_string,
+        )
         self.name_saturated = name_saturated
         self.latex_name_saturated = latex_name_saturated
 
@@ -649,16 +719,21 @@ class CostFunctionFormatter(FunctionFormatter):
 
         :rtype: str
         """
-        return self._latex_name_saturated if self._latex_name_saturated is not None \
-            else self.latex_name
+        return self._latex_name_saturated if self._latex_name_saturated is not None else self.latex_name
 
     @latex_name_saturated.setter
     def latex_name_saturated(self, latex_name_saturated):
         self._latex_name_saturated = latex_name_saturated  # TODO validate
 
     def get_formatted(
-            self, value=None, n_degrees_of_freedom=None, with_name=True, saturated=False,
-            with_value_per_ndf=True, format_as_latex=False):
+        self,
+        value=None,
+        n_degrees_of_freedom=None,
+        with_name=True,
+        saturated=False,
+        with_value_per_ndf=True,
+        format_as_latex=False,
+    ):
         """Get a formatted string representing this cost function.
 
         :param value: Value of the cost function (if not :py:obj:`None`, the returned string will
@@ -693,12 +768,13 @@ class CostFunctionFormatter(FunctionFormatter):
                     _name_string = "%s / ndf" % _name
                 _value_string = "%s / %d" % (_value_string, n_degrees_of_freedom)
                 if with_value_per_ndf and n_degrees_of_freedom > 0:
-                    _value_string = "%s = %.4g" % (_value_string,
-                                                   float(value) / n_degrees_of_freedom)
+                    _value_string = "%s = %.4g" % (
+                        _value_string,
+                        float(value) / n_degrees_of_freedom,
+                    )
         if format_as_latex:
             # replace scientific notation with power of ten (LaTeX only)
-            _value_string = re.sub(r'(-?\d*\.?\d+?)0*e\+?(-?[0-9]*[1-9]?)',
-                                     r'\1\\times10^{\2}', _value_string)
+            _value_string = re.sub(r"(-?\d*\.?\d+?)0*e\+?(-?[0-9]*[1-9]?)", r"\1\\times10^{\2}", _value_string)
 
         if with_name:
             _out_string = "%s = %s" % (_name_string, _value_string)
@@ -727,7 +803,7 @@ class ModelFunctionFormatter(FunctionFormatter):
 
     @classmethod
     def _get_object_type_name(cls):
-        return 'model_function_formatter'
+        return "model_function_formatter"
 
     @property
     def par_formatters(self):
@@ -736,8 +812,13 @@ class ModelFunctionFormatter(FunctionFormatter):
         formatters.pop(0)  # first formatter is independent var, delete it
         return formatters
 
-    def get_formatted(self, with_par_values=False, n_significant_digits=2, format_as_latex=False,
-                      with_expression=False):
+    def get_formatted(
+        self,
+        with_par_values=False,
+        n_significant_digits=2,
+        format_as_latex=False,
+        with_expression=False,
+    ):
         """Create a formatted string representing this model function.
 
         :param bool with_par_values: If :py:obj:`True`, output will include the value of each
@@ -750,9 +831,11 @@ class ModelFunctionFormatter(FunctionFormatter):
         :returns: The formatted string representing this model function.
         :rtype: str
         """
-        _par_strings = self._get_formatted_pars(with_par_values=with_par_values,
-                                                n_significant_digits=n_significant_digits,
-                                                format_as_latex=format_as_latex)
+        _par_strings = self._get_formatted_pars(
+            with_par_values=with_par_values,
+            n_significant_digits=n_significant_digits,
+            format_as_latex=format_as_latex,
+        )
         _par_expr_string = ""
         if with_expression:
             _par_expr_string = self._get_formatted_expression(format_as_latex=format_as_latex)
@@ -760,7 +843,10 @@ class ModelFunctionFormatter(FunctionFormatter):
         x_formatter = self.arg_formatters[0]
         if format_as_latex:
             _out_string = r"%s\left(%s;%s\right)" % (
-            self._latex_name, x_formatter.latex_name, ", ".join(_par_strings))
+                self._latex_name,
+                x_formatter.latex_name,
+                ", ".join(_par_strings),
+            )
             if _par_expr_string:
                 _out_string += " = " + _par_expr_string
             _out_string = "$%s$" % (_out_string,)
