@@ -1,15 +1,10 @@
 import warnings
+
 import numpy as np
 
 from ..indexed import IndexedContainer
-from ..indexed.container import IndexedContainerException
 
-
-__all__ = ['HistContainer', 'HistContainerException']
-
-
-class HistContainerException(IndexedContainerException):
-    pass
+__all__ = ["HistContainer"]
 
 
 class HistContainer(IndexedContainer):
@@ -25,53 +20,61 @@ class HistContainer(IndexedContainer):
     ..    :parts: 1
 
     """
-    def __init__(self, n_bins, bin_range, bin_edges=None, fill_data=None, dtype=int):
+
+    def __init__(self, n_bins=None, bin_range=None, bin_edges=None, fill_data=None, dtype=int):
         """
         Construct a histogram:
 
-        :param n_bins: number of bins
+        :param n_bins: how many bins raw data should be split into.
         :type n_bins: int
-        :param bin_range: the lower and upper edges of the entire histogram
-        :type bin_range: tuple of floats
-        :param bin_edges: the bin edges (if ``None``, each bin will have the same width)
-        :type bin_edges: list of floats
+        :param bin_range: the lower and upper bound for the bins specified by n_bins.
+        :type bin_range: iterable[float] of length 2
+        :param bin_edges: explicit bin edges for raw data. If ``None``, each bin will have the same
+            width.
+        :type bin_edges: iterable[float]
         :param fill_data: entries to fill into the histogram
-        :type fill_data: list of floats
+        :type fill_data: iterable[float]
         :param dtype: data type of histogram entries
         :type dtype: type
         """
-        super(HistContainer, self).__init__(data=np.zeros(n_bins+2), dtype=dtype)  # underflow and overflow bins
+        if bin_edges is None:
+            if n_bins is None or bin_range is None:
+                raise ValueError("Either n_bins and bin_range or bin_edges must be specified.")
+        else:
+            if n_bins is None:
+                n_bins = len(bin_edges) - 1
+            if n_bins != len(bin_edges) - 1 and n_bins != len(bin_edges) + 1:
+                raise ValueError(f"n_bins is {n_bins} but bin_edges implies either " f"{len(bin_edges) - 1} or {len(bin_edges) - 1} bins")
+            if bin_range is None:
+                bin_range = (bin_edges[0], bin_edges[-1])
+            if n_bins == len(bin_edges) - 1:
+                if bin_range[0] != bin_edges[0] or bin_range[1] != bin_edges[-1]:
+                    raise ValueError(f"bin_range is {bin_range} but bin_edges implies " f"{(bin_edges[0], bin_edges[-1])}")
+            if n_bins == len(bin_edges) + 1:
+                if bin_range[0] > bin_edges[0] or bin_range[1] < bin_edges[-1]:
+                    raise ValueError(f"bin_range is {bin_range} but does not encompass inner " f"bin edges {(bin_edges[0], bin_edges[-1])}")
+
+        if len(bin_range) != 2:
+            raise ValueError(f"bin_range must be iterable of 2 floats but received {bin_range}")
+        low, high = tuple(bin_range)
+
+        super(HistContainer, self).__init__(data=np.zeros(n_bins + 2), dtype=dtype)  # underflow and overflow bins
         self._manual_heights = False
         self._processed_entries = []
         self._unprocessed_entries = []
         # TODO: think of a way to implement weights
 
-        if len(bin_range) != 2:
-            raise HistContainerException(
-                "Invalid bin range specification: %r! Must be tuple of 2 floats..." % (bin_range,))
-        low, high = tuple(bin_range)
-
         if bin_edges is not None:
-            # user specified bin edges -> check that these match the given 'n_bins' and 'bin_range'
-            _sz = self.size
-            if len(bin_edges) == _sz + 1:
-                # assume bin edges given including bin range
-                if not (bin_edges[0] == low and bin_edges[-1] == high):
-                    raise HistContainerException(
-                        "Invalid bin edge specification! First and last elements %r must match histogram bin range %r."
-                        % ((bin_edges[0], bin_edges[-1]), bin_range))
-                _bin_edges_including_low_and_high = bin_edges
-            elif len(bin_edges) == _sz - 1:
-                # <check if ordered and strictly within bin range>
-                _bin_edges_including_low_and_high = [low] + bin_edges + [high]
+            if len(bin_edges) == self.size + 1:
+                self.rebin(bin_edges)
+            elif len(bin_edges) == self.size - 1:
+                # Add low and high to edges if inner edges specified:
+                self.rebin([low] + list(bin_edges) + [high])
             else:
-                raise HistContainerException(
-                    "Invalid bin edge specification! Number of elements (%d) must match histogram bin number (%d) +/- 1."
-                    % (len(bin_edges), _sz))
-            self.rebin(new_bin_edges=_bin_edges_including_low_and_high)
+                assert False
         else:
             # construct own bin edges
-            self._bin_edges = np.linspace(bin_range[0], bin_range[1], n_bins+1)
+            self._bin_edges = np.linspace(bin_range[0], bin_range[1], n_bins + 1)
 
         if fill_data is not None:
             self.fill(fill_data)
@@ -81,11 +84,14 @@ class HistContainer(IndexedContainer):
     def _fill_unprocessed(self):
         """fill any entries marked as unprocessed into the histogram"""
         if self._manual_heights:
-            raise HistContainerException("The bin heights have been set manually. Filling entries is not available "
-                                         "anymore. Please construct a new HistContainer!")
+            raise RuntimeError(
+                "The bin heights have been set manually. Filling entries is not " "available anymore. Please construct a new HistContainer!"
+            )
         if not self._unprocessed_entries:
             return
         _entries_sorted = np.sort(self._unprocessed_entries)
+        if np.all(self._unprocessed_entries == np.floor(self._unprocessed_entries)):
+            warnings.warn("Histogram data is int. Make sure to consider this for your bin edges!")
 
         _current_entry_index = 0
         _current_entry_value = _entries_sorted[0]
@@ -114,13 +120,12 @@ class HistContainer(IndexedContainer):
             self._processed_entries.append(_current_entry_value)
             self._data[_current_bin_index] += 1
             _current_entry_index += 1
-            if _current_entry_index >= len(_entries_sorted):    # important BUGFIX!!!!!!!!!!
+            if _current_entry_index >= len(_entries_sorted):  # important BUGFIX!!!!!!!!!!
                 break
             _current_entry_value = _entries_sorted[_current_entry_index]
 
         # any remaining entries are overflows
-        if _current_entry_index < len(_entries_sorted):    # important BUGFIX!!!!!!!!!!
-
+        if _current_entry_index < len(_entries_sorted):  # important BUGFIX!!!!!!!!!!
             _overflow_entries = _entries_sorted[_current_entry_index:]
             self._data[-1] += len(_overflow_entries)
             # print "Bin %d (of): add %d entries" % (_current_bin_index+1, len(_overflow_entries))
@@ -129,8 +134,6 @@ class HistContainer(IndexedContainer):
             self._processed_entries += list(_overflow_entries)
 
         self._unprocessed_entries = []
-        if np.all(self._data == np.floor(self._data)):
-            warnings.warn("Historam data is int. Make sure to consider this for your bin edges!")
 
     def _get_error_reference(self):
         return self._data[1:-1]
@@ -157,7 +160,7 @@ class HistContainer(IndexedContainer):
 
     @data.setter
     def data(self, data):
-        raise HistContainerException("Changing histogram data directly is not allowed! Use fill() or set_bins().")
+        raise TypeError("Changing histogram data directly is not allowed! Use fill() or set_bins().")
 
     @property
     def raw_data(self):
@@ -204,13 +207,13 @@ class HistContainer(IndexedContainer):
     def bin_widths(self):
         """a list of the bin widths"""
         _be = self._bin_edges
-        return (_be[1:] - _be[:-1])
+        return _be[1:] - _be[:-1]
 
     @property
     def bin_centers(self):
         """a list of the (geometrical) bin centers"""
         _be = self._bin_edges
-        return 0.5*(_be[1:] + _be[:-1])
+        return 0.5 * (_be[1:] + _be[:-1])
 
     # -- public methods
 
@@ -222,11 +225,11 @@ class HistContainer(IndexedContainer):
         :type entries: list of floats
         """
         if self._manual_heights:
-            raise HistContainerException("The bin heights have been set manually. Filling additional data is not "
-                                         "possible anymore. Please construct a new HistContainer!")
+            raise RuntimeError(
+                "The bin heights have been set manually. Filling additional data is not " "possible anymore. Please construct a new HistContainer!"
+            )
         if np.asarray(entries).ndim > 1:
-            raise ValueError("Fill data must be scalar or one-dimensional "
-                             f"but received fill data with {np.asarray(entries).ndim} dimensions.")
+            raise ValueError("Fill data must be scalar or one-dimensional " f"but received fill data with {np.asarray(entries).ndim} dimensions.")
         try:
             self._unprocessed_entries += list(entries)
         except TypeError:
@@ -240,13 +243,11 @@ class HistContainer(IndexedContainer):
         :type new_bin_edges: list of float
         """
         if self._manual_heights:
-            raise HistContainerException("The bin heights have been set manually. Rebinning is not possible anymore. "
-                                         "Please construct a new HistContainer!")
+            raise RuntimeError("The bin heights have been set manually. Rebinning is not possible " "anymore. Please construct a new HistContainer!")
         _new_bin_edges = np.asarray(new_bin_edges, dtype=float)
         # check if list is sorted
         if not (np.diff(_new_bin_edges) >= 0).all():
-            raise HistContainerException(
-                "Invalid bin edge specification! Edge sequence must be sorted in ascending order!")
+            raise ValueError("Invalid bin edge specification! Edge sequence must be sorted in ascending order!")
         self._bin_edges = _new_bin_edges
         self._data = np.zeros(len(self._bin_edges) - 1 + 2)
 
@@ -267,12 +268,10 @@ class HistContainer(IndexedContainer):
         self._manual_heights = True
         _new_data = np.array(bin_heights)
         if _new_data.ndim != 1:
-            raise ValueError('Invalid dimensions for bin heights. '
-                             f'Got {_new_data.ndim}-d array, expected 1-d array')
+            raise ValueError("Invalid dimensions for bin heights. " f"Got {_new_data.ndim}-d array, expected 1-d array")
         _new_data = np.append(np.insert(_new_data, 0, underflow), overflow)
         if len(_new_data) != len(self._data):
-            raise HistContainerException('Length of bin entries does not match binning. '
-                                         'Got {}, expected {}'.format(len(_new_data)-2, len(self._data)-2))
+            raise ValueError("Length of bin entries does not match binning. " "Got {}, expected {}".format(len(_new_data) - 2, len(self._data) - 2))
         self._data = _new_data
         self._processed_entries = []
         self._unprocessed_entries = []
