@@ -1,12 +1,15 @@
-from .._base.cost import CostFunction, CostFunction_Chi2, CostFunction_NegLogLikelihood, \
-    CostFunction_GaussApproximation
-
+from .._base.cost import (
+    CostFunction,
+    CostFunction_Chi2,
+    CostFunction_GaussApproximation,
+    CostFunction_NegLogLikelihood,
+)
 
 __all__ = [
     "HistCostFunction",
     "HistCostFunction_Chi2",
     "HistCostFunction_NegLogLikelihood",
-    "HistCostFunction_GaussApproximation"
+    "HistCostFunction_GaussApproximation",
 ]
 
 
