@@ -1,12 +1,12 @@
+from inspect import getsource
+
 import numpy as np
 import six
 from scipy import integrate
-from inspect import getsource
 
-from .._base import ParametricModelBaseMixin, ModelFunctionBase, ModelFunctionException
-from .container import HistContainer, HistContainerException
+from .._base import ModelFunctionBase, ParametricModelBaseMixin
 from ..util import function_library
-
+from .container import HistContainer
 
 if six.PY2:
     from funcsigs import signature
@@ -17,13 +17,7 @@ else:
 __all__ = ["HistParametricModel", "HistModelFunction"]
 
 
-class HistModelFunctionException(ModelFunctionException):
-    pass
-
-
 class HistModelFunction(ModelFunctionBase):
-    EXCEPTION_TYPE = HistModelFunctionException
-
     def __init__(self, model_function=None):
         """
         Construct :py:class:`XYModelFunction` object (a wrapper for a native Python function):
@@ -31,25 +25,32 @@ class HistModelFunction(ModelFunctionBase):
         :param model_function: function handle
         """
         # TODO: default model function
-        super(HistModelFunction, self).__init__(
-            model_function=model_function, independent_argcount=1)
-
-
-class HistParametricModelException(HistContainerException):
-    pass
+        super(HistModelFunction, self).__init__(model_function=model_function, independent_argcount=1)
 
 
 class HistParametricModel(ParametricModelBaseMixin, HistContainer):
     MODEL_FUNCTION_TYPE = HistModelFunction
 
-    #TODO n_bins, bin_range, bin_edges contain redundant information, should the arguments for HistParametricModel be refactored?
-    def __init__(self, n_bins, bin_range,
-                 model_density_func=function_library.normal_distribution,
-                 model_parameters=[1.0, 1.0], bin_edges=None, bin_evaluation="simpson",
-                 density=True):
+    # TODO n_bins, bin_range, bin_edges contain redundant information, should the arguments for HistParametricModel be refactored?
+    def __init__(
+        self,
+        n_bins,
+        bin_range,
+        model_density_func=function_library.normal_distribution,
+        model_parameters=[1.0, 1.0],
+        bin_edges=None,
+        bin_evaluation="simpson",
+        density=True,
+    ):
         super(HistParametricModel, self).__init__(
-            model_density_func, model_parameters, n_bins, bin_range,
-            bin_edges=bin_edges, fill_data=None, dtype=float)
+            model_density_func,
+            model_parameters,
+            n_bins,
+            bin_range,
+            bin_edges=bin_edges,
+            fill_data=None,
+            dtype=float,
+        )
         self._bin_evaluation = bin_evaluation
         if isinstance(self._bin_evaluation, str):
             self._bin_evaluation = self._bin_evaluation.lower()
@@ -73,9 +74,7 @@ class HistParametricModel(ParametricModelBaseMixin, HistContainer):
                 _antiderivative_function_handle = self._bin_evaluation
             else:
                 # raise if not string and not callable
-                raise ValueError(
-                    "Cannot use {} as bin evaluation method: not a string and not callable!".format(
-                        self._bin_evaluation))
+                raise ValueError("Cannot use {} as bin evaluation method: not a string and not callable!".format(self._bin_evaluation))
 
             # Retrieving source code will fail if the function was generated through exec.
             # For kafe2go self._bin_evaluation_string will be replaced.
@@ -95,11 +94,12 @@ class HistParametricModel(ParametricModelBaseMixin, HistContainer):
             if _model_func_parameters != _antider_parameters:
                 raise ValueError(
                     "Model density function and its antiderivative have different argument "
-                    "signatures: (%r vs %r)"
-                    % (_model_func_parameters, _antider_parameters))
+                    "signatures: (%r vs %r)" % (_model_func_parameters, _antider_parameters)
+                )
             self._bin_evaluation_method = self._bin_evaluation_antiderivative
 
         self._density = density
+
     # -- private methods
 
     def _recalculate(self):
@@ -118,10 +118,10 @@ class HistParametricModel(ParametricModelBaseMixin, HistContainer):
     def _bin_evaluation_simpson(self):
         _height_edges = self.eval_model_function_density(self._bin_edges)
         _height_centers = self.eval_model_function_density(self.bin_centers)
-        return self.bin_widths / 6.0 * (
-                _height_edges[:-1] + 4.0 * _height_centers + _height_edges[1:])
+        return self.bin_widths / 6.0 * (_height_edges[:-1] + 4.0 * _height_centers + _height_edges[1:])
 
     def _bin_evaluation_numerical(self):
+        # flake8: noqa: E731 (lambda expression)
         _integrand_func = lambda x: self.eval_model_function_density(x)
         _int_val = np.zeros(self.size)
         for _i, (_a, _b) in enumerate(zip(self._bin_edges[:-1], self._bin_edges[1:])):
@@ -145,7 +145,7 @@ class HistParametricModel(ParametricModelBaseMixin, HistContainer):
 
     @data.setter
     def data(self, new_data):
-        raise HistParametricModelException("Parametric model data cannot be set!")
+        raise TypeError("Parametric model data cannot be set!")
 
     @property
     def bin_evaluation(self):
@@ -187,4 +187,4 @@ class HistParametricModel(ParametricModelBaseMixin, HistContainer):
         return _y
 
     def fill(self, entries):
-        raise HistParametricModelException("Parametric model of histogram cannot be filled!")
+        raise TypeError("Parametric model of histogram cannot be filled!")
