@@ -1,21 +1,14 @@
+import numdifftools as nd
 import numpy as np
 
-from scipy.misc import derivative
-
-from .._base import ParametricModelBaseMixin, ModelFunctionBase, ModelFunctionException
-from .container import IndexedContainer, IndexedContainerException
+from .._base import ModelFunctionBase, ParametricModelBaseMixin
+from .container import IndexedContainer
 from .format import IndexedModelFunctionFormatter
 
-
 __all__ = ["IndexedParametricModel", "IndexedModelFunction"]
 
 
-class IndexedModelFunctionException(ModelFunctionException):
-    pass
-
-
 class IndexedModelFunction(ModelFunctionBase):
-    EXCEPTION_TYPE = IndexedModelFunctionException
     FORMATTER_TYPE = IndexedModelFunctionFormatter
 
     def __init__(self, model_function):
@@ -28,10 +21,6 @@ class IndexedModelFunction(ModelFunctionBase):
         super(IndexedModelFunction, self).__init__(model_function=model_function, independent_argcount=0)
 
 
-class IndexedParametricModelException(IndexedContainerException):
-    pass
-
-
 class IndexedParametricModel(ParametricModelBaseMixin, IndexedContainer):
     MODEL_FUNCTION_TYPE = IndexedModelFunction
 
@@ -48,10 +37,10 @@ class IndexedParametricModel(ParametricModelBaseMixin, IndexedContainer):
             _data = np.zeros_like(shape_like)
             try:
                 _data[:] = model_func(*model_parameters)
-            except ValueError:
-                raise IndexedParametricModelException("Indexed Data and Function must have the same shape! "
-                                                      "Got {} and {}".format(len(_data),
-                                                                             len(model_func(*model_parameters))))
+            except ValueError as _e:
+                raise ValueError(
+                    "Indexed Data and Function must have the same shape! Got {} and {}".format(len(_data), len(model_func(*model_parameters)))
+                ) from _e
         else:
             _data = model_func(*model_parameters)
         super(IndexedParametricModel, self).__init__(model_func, model_parameters, _data)
@@ -63,7 +52,6 @@ class IndexedParametricModel(ParametricModelBaseMixin, IndexedContainer):
         IndexedContainer.data.fset(self, self.eval_model_function())
         self._pm_calculation_stale = False
 
-
     # -- public properties
 
     @property
@@ -75,7 +63,7 @@ class IndexedParametricModel(ParametricModelBaseMixin, IndexedContainer):
 
     @data.setter
     def data(self, new_data):
-        raise IndexedParametricModelException("Parametric model data cannot be set!")
+        raise TypeError("Parametric model data cannot be set!")
 
     @property
     def data_range(self):
@@ -114,11 +102,15 @@ class IndexedParametricModel(ParametricModelBaseMixin, IndexedContainer):
 
         _ret = []
         for _par_idx, (_par_val, _par_dx) in enumerate(zip(_pars, _par_dxs)):
+            if _par_dx == 0.0:  # fixed parameter
+                _ret[_par_idx] = 0.0
+                continue
+
             def _chipped_func(par):
                 _chipped_pars = _pars.copy()
                 _chipped_pars[_par_idx] = par
                 return self._model_function_object(*_chipped_pars)
 
-            _der_val = derivative(_chipped_func, _par_val, dx=_par_dx)
-            _ret.append(_der_val)
+            _first_derivative = nd.Derivative(_chipped_func, step=_par_dx, order=4, n=1)
+            _ret.append(_first_derivative(_par_val))
         return np.array(_ret)
