@@ -2,7 +2,7 @@ import numpy as np
 
 from .._base import CostFunction, CostFunction_Chi2
 
-__all__ = ['SharedCostFunction', 'MultiCostFunction']
+__all__ = ["SharedCostFunction", "MultiCostFunction"]
 
 
 class SharedCostFunction(CostFunction_Chi2):
@@ -10,19 +10,22 @@ class SharedCostFunction(CostFunction_Chi2):
         self._DATA_NAME = "y_data"
         self._MODEL_NAME = "y_model"
         self._COV_MAT_CHOLESKY_NAME = "total_cov_mat_cholesky"
+        self._COV_MAT_QR_NAME = "total_cov_mat_qr"
         super(SharedCostFunction, self).__init__(
-            errors_to_use="covariance", fallback_on_singular=fallback_on_singular,
-            add_constraint_cost=False, add_determinant_cost=True)
+            errors_to_use="covariance",
+            fallback_on_singular=fallback_on_singular,
+            add_constraint_cost=False,
+            add_determinant_cost=True,
+        )
 
 
 class MultiCostFunction(CostFunction):
-
     def __init__(self, singular_cost_functions, cost_function_names):
         super(MultiCostFunction, self).__init__(
             cost_function=MultiCostFunction.cost_sum,
             arg_names=cost_function_names,
             add_constraint_cost=True,
-            add_determinant_cost=False
+            add_determinant_cost=False,
         )
         self._needs_errors = np.any([_scf.needs_errors for _scf in singular_cost_functions])
         self._saturated = np.all([_scf.saturated for _scf in singular_cost_functions])
