@@ -1,3 +1,4 @@
+# flake8: noqa F401 (imported but unused)
 import sys
 import warnings
 from collections import OrderedDict
@@ -5,15 +6,21 @@ from copy import copy
 
 import numpy as np
 
-from .cost import SharedCostFunction, MultiCostFunction
-from .._base import FitBase
+from ...core.error import CovMat, MatrixGaussianError, SimpleGaussianError
 from ...core.fitters import NexusFitter
-from ...core.error import SimpleGaussianError, MatrixGaussianError, CovMat
-from ...core.fitters.nexus import Alias, Function, Array, Parameter
+from ...core.fitters.nexus import Alias, Array, Function, Parameter
 from ...tools import random_alphanumeric
-from ..util import cholesky_decomposition, log_determinant, invert_matrix
+from .._base import FitBase
+from ..util import (
+    cholesky_decomposition,
+    invert_matrix,
+    log_determinant_cholesky,
+    log_determinant_qr,
+    qr_decomposition,
+)
+from .cost import MultiCostFunction, SharedCostFunction
 
-__all__ = ['MultiFit']
+__all__ = ["MultiFit"]
 
 
 class MultiFit(FitBase):
@@ -26,9 +33,7 @@ class MultiFit(FitBase):
     _AXES = ()
     _MODEL_ERROR_NODE_NAMES = []
 
-    def __init__(
-            self, fit_list, minimizer=None, minimizer_kwargs=None,
-            dynamic_error_algorithm="nonlinear"):
+    def __init__(self, fit_list, minimizer=None, minimizer_kwargs=None, dynamic_error_algorithm="nonlinear"):
         """
         :param fit_list: List or Iterable of the individual fits from which to create the MultiFit.
         :type fit_list: collections.Iterable[FitBase]
@@ -46,8 +51,13 @@ class MultiFit(FitBase):
         self._shared_error_nodes_initialized = False
         self._min_x_error = None
         super(MultiFit, self).__init__(
-            data=None, model_function=None, cost_function=None, minimizer=minimizer,
-            minimizer_kwargs=minimizer_kwargs, dynamic_error_algorithm=dynamic_error_algorithm)
+            data=None,
+            model_function=None,
+            cost_function=None,
+            minimizer=minimizer,
+            minimizer_kwargs=minimizer_kwargs,
+            dynamic_error_algorithm=dynamic_error_algorithm,
+        )
 
     # -- private methods
 
@@ -104,7 +114,7 @@ class MultiFit(FitBase):
                 parameter_errors=self.parameter_errors[_parameter_indices],
                 parameter_cor_mat=_par_cor_mat,
                 parameter_cov_mat=_par_cov_mat,
-                asymmetric_parameter_errors=_asymmetric_parameter_errors
+                asymmetric_parameter_errors=_asymmetric_parameter_errors,
             )
         self._update_parameter_formatters()
 
@@ -113,8 +123,8 @@ class MultiFit(FitBase):
 
         self._combined_parameter_node_dict = OrderedDict()
         for _i, _fit_i in enumerate(self._fits):
-            _original_cost_i = _fit_i._nexus.get('cost')
-            _cost_alias_name_i = 'cost%s' % _i
+            _original_cost_i = _fit_i._nexus.get("cost")
+            _cost_alias_name_i = "cost%s" % _i
             _cost_alias_i = Alias(ref=_original_cost_i, name=_cost_alias_name_i)
             self._nexus.add(_cost_alias_i, add_children=False)
             for _par_node in _fit_i.parameter_names:
@@ -123,54 +133,48 @@ class MultiFit(FitBase):
             self._nexus.add(_par_node)
             for _fit in self._fits:
                 if _par_node.name in _fit.parameter_names:
-                    _fit._nexus.add(node=_par_node, existing_behavior='replace')
+                    _fit._nexus.add(node=_par_node, existing_behavior="replace")
         self._nexus.add(
-            Array(nodes=self._combined_parameter_node_dict.values(), name='parameter_values'),
-            existing_behavior="replace"
+            Array(nodes=self._combined_parameter_node_dict.values(), name="parameter_values"),
+            existing_behavior="replace",
         )
 
         _log_det_names = []
         for _i, _fit_i in enumerate(self._fits):
             _fit_i._initialize_fitter()
 
-            _x_data_node = _fit_i._nexus.get('x_data')
+            _x_data_node = _fit_i._nexus.get("x_data")
             if _x_data_node is not None:
-                _x_data_name = 'x_data%s' % _i
-                self._nexus.add(
-                    Alias(ref=_x_data_node, name=_x_data_name),
-                    add_children=False)
+                _x_data_name = "x_data%s" % _i
+                self._nexus.add(Alias(ref=_x_data_node, name=_x_data_name), add_children=False)
 
-            _y_data_node = _fit_i._nexus.get('y_data')
+            _y_data_node = _fit_i._nexus.get("y_data")
             if _y_data_node is not None:
-                _y_data_name = 'y_data%s' % _i
-                self._nexus.add(
-                    Alias(ref=_y_data_node, name=_y_data_name),
-                    add_children=False)
+                _y_data_name = "y_data%s" % _i
+                self._nexus.add(Alias(ref=_y_data_node, name=_y_data_name), add_children=False)
 
-            _log_det_node = _fit_i._nexus.get('total_cov_mat_log_determinant')
+            _log_det_node = _fit_i._nexus.get("total_cov_mat_log_determinant")
             if _log_det_node is not None:
-                _log_det_name = 'total_cov_mat_log_determinant%s' % _i
-                self._nexus.add(
-                    Alias(ref=_log_det_node, name=_log_det_name),
-                    add_children=False)
+                _log_det_name = "total_cov_mat_log_determinant%s" % _i
+                self._nexus.add(Alias(ref=_log_det_node, name=_log_det_name), add_children=False)
                 _log_det_names.append(_log_det_name)
 
         self._nexus.add_function(
             lambda *log_dets: np.sum(log_dets),
-            func_name='total_cov_mat_log_determinant', par_names=_log_det_names,
-            existing_behavior="replace")
+            func_name="total_cov_mat_log_determinant",
+            par_names=_log_det_names,
+            existing_behavior="replace",
+        )
 
         _cost_functions = [_fit._cost_function for _fit in self._fits]
-        _cost_names = ['cost%s' % _i for _i in range(len(self._fits))]
-        self._cost_function = MultiCostFunction(
-            singular_cost_functions=_cost_functions, cost_function_names=_cost_names)
+        _cost_names = ["cost%s" % _i for _i in range(len(self._fits))]
+        self._cost_function = MultiCostFunction(singular_cost_functions=_cost_functions, cost_function_names=_cost_names)
         _cost_function_node = self._nexus.add_function(
             func=self._cost_function,
             func_name=self._cost_function.name,
-            par_names=self._cost_function.arg_names
+            par_names=self._cost_function.arg_names,
         )
-        self._nexus.add_alias(
-            name='cost', alias_for=_cost_function_node.name)
+        self._nexus.add_alias(name="cost", alias_for=_cost_function_node.name)
 
         self._initialize_fitter()
 
@@ -194,50 +198,49 @@ class MultiFit(FitBase):
                 _fit_index_to_data_index[_i] = len(_data_indices) - 1
                 _data_indices.append(_data_indices[-1] + _fit_i.data_size)
 
-                _x_cov_mat_name = 'x_cov_mat%s' % _i
-                _derivatives_name = 'derivatives%s' % _i
+                _x_cov_mat_name = "x_cov_mat%s" % _i
+                _derivatives_name = "derivatives%s" % _i
                 if isinstance(_fit_i, XYFit):
                     self._nexus.add(
-                        Alias(ref=_fit_i._nexus.get('x_total_cov_mat'), name=_x_cov_mat_name),
-                        add_children=False)
+                        Alias(ref=_fit_i._nexus.get("x_total_cov_mat"), name=_x_cov_mat_name),
+                        add_children=False,
+                    )
 
                     # Bind fit object (Python is call-by-value), otherwise all derivatives would
                     # use the same fit.
                     def _get_derivatives_func(fit):
-                        return lambda: (fit._param_model.eval_model_function_derivative_by_x(
-                            model_parameters=fit.parameter_values,
-                            dx=0.01 * self._min_x_error
-                        ) if self._min_x_error is not None else np.zeros(fit.data_size))
+                        return lambda: (
+                            fit._param_model.eval_model_function_derivative_by_x(model_parameters=fit.parameter_values, dx=0.01 * self._min_x_error)
+                            if self._min_x_error is not None
+                            else np.zeros(fit.data_size)
+                        )
 
                     self._nexus.add(
                         Function(func=_get_derivatives_func(_fit_i), name=_derivatives_name),
-                        add_children=False)
-                    self._nexus.add_dependency(
-                        name=_derivatives_name, depends_on='parameter_values')
+                        add_children=False,
+                    )
+                    self._nexus.add_dependency(name=_derivatives_name, depends_on="parameter_values")
                 else:
-                    self._nexus.add(Parameter(
-                        np.zeros(_fit_i.data_size), name=_derivatives_name))
-                    self._nexus.add(Parameter(
-                        np.zeros((_fit_i.data_size, _fit_i.data_size)), name=_x_cov_mat_name))
+                    self._nexus.add(Parameter(np.zeros(_fit_i.data_size), name=_derivatives_name))
+                    self._nexus.add(Parameter(np.zeros((_fit_i.data_size, _fit_i.data_size)), name=_x_cov_mat_name))
                 _x_cov_mat_names.append(_x_cov_mat_name)
                 _derivative_names.append(_derivatives_name)
 
-                _y_data_names.append('y_data%s' % _i)
+                _y_data_names.append("y_data%s" % _i)
 
-                _y_model_name = 'y_model%s' % _i
-                self._nexus.add(
-                    Alias(ref=_fit_i._nexus.get('y_model'), name=_y_model_name),
-                    add_children=False)
+                _y_model_name = "y_model%s" % _i
+                self._nexus.add(Alias(ref=_fit_i._nexus.get("y_model"), name=_y_model_name), add_children=False)
                 _y_model_names.append(_y_model_name)
 
-                _y_cov_mat_name = 'y_cov_mat%s' % _i
+                _y_cov_mat_name = "y_cov_mat%s" % _i
                 self._nexus.add(
-                    Alias(ref=_fit_i._nexus.get('y_total_cov_mat'), name=_y_cov_mat_name),
-                    add_children=False)
+                    Alias(ref=_fit_i._nexus.get("y_total_cov_mat"), name=_y_cov_mat_name),
+                    add_children=False,
+                )
                 _y_cov_mat_names.append(_y_cov_mat_name)
             else:
                 _cost_functions.append(_fit_i._cost_function)
-                _cost_names.append('cost%s' % _i)
+                _cost_names.append("cost%s" % _i)
 
         # Combines 1-dimensional properties by concatenating them.
         def _combine_1d_property(*single_fit_properties):
@@ -258,9 +261,9 @@ class MultiFit(FitBase):
                 _upper = _data_indices[_j + 1]
                 _combined_property[_lower:_upper, _lower:_upper] = _single_fit_property
             for _error_dict in self._shared_error_dicts.values():
-                if _error_dict['axis'] != axis_name:
+                if _error_dict["axis"] != axis_name:
                     continue
-                _error = _error_dict['err']
+                _error = _error_dict["err"]
                 for _j, _fit_index_j in enumerate(_error.fit_indices):
                     _data_index_j = _fit_index_to_data_index[_fit_index_j]
                     _lower_j = _data_indices[_data_index_j]
@@ -274,23 +277,38 @@ class MultiFit(FitBase):
             return _combined_property
 
         self._nexus.add_function(
-            func=lambda *p: _combine_cov_mats('x', *p),
-            func_name='x_cov_mat', par_names=_x_cov_mat_names, add_children=False)
+            func=lambda *p: _combine_cov_mats("x", *p),
+            func_name="x_cov_mat",
+            par_names=_x_cov_mat_names,
+            add_children=False,
+        )
         self._nexus.add_function(
-            func=_combine_1d_property, func_name='derivatives', par_names=_derivative_names,
-            add_children=False)
+            func=_combine_1d_property,
+            func_name="derivatives",
+            par_names=_derivative_names,
+            add_children=False,
+        )
 
         self._nexus.add_function(
-            func=_combine_1d_property, func_name='y_data',
-            par_names=_y_data_names, add_children=False)
-        self._nexus.add_alias(name='data', alias_for='y_data')
+            func=_combine_1d_property,
+            func_name="y_data",
+            par_names=_y_data_names,
+            add_children=False,
+        )
+        self._nexus.add_alias(name="data", alias_for="y_data")
         self._nexus.add_function(
-            func=_combine_1d_property, func_name='y_model',
-            par_names=_y_model_names, add_children=False)
-        self._nexus.add_alias(name='model', alias_for='y_model')
+            func=_combine_1d_property,
+            func_name="y_model",
+            par_names=_y_model_names,
+            add_children=False,
+        )
+        self._nexus.add_alias(name="model", alias_for="y_model")
         self._nexus.add_function(
-            func=lambda *p: _combine_cov_mats('y', *p),
-            func_name='y_cov_mat', par_names=_y_cov_mat_names, add_children=False)
+            func=lambda *p: _combine_cov_mats("y", *p),
+            func_name="y_cov_mat",
+            par_names=_y_cov_mat_names,
+            add_children=False,
+        )
 
         def total_cov_mat_cholesky(x_cov_mat, derivatives, y_cov_mat):
             if self._min_x_error is not None:
@@ -298,69 +316,91 @@ class MultiFit(FitBase):
             else:
                 _cov_mat = y_cov_mat
             return cholesky_decomposition(_cov_mat)
+
+        def total_cov_mat_qr(x_cov_mat, derivatives, y_cov_mat):
+            if self._min_x_error is not None:
+                _cov_mat = y_cov_mat + x_cov_mat * np.outer(derivatives, derivatives)
+            else:
+                _cov_mat = y_cov_mat
+            return qr_decomposition(_cov_mat)
+
         self._nexus.add_function(total_cov_mat_cholesky)
-        self._nexus.add_function(log_determinant, func_name="total_cov_mat_log_determinant",
-                                 par_names=["total_cov_mat_cholesky"], existing_behavior="replace")
+        self._nexus.add_function(total_cov_mat_qr)
+
+        any_fast_math = False
+        for fit in self.fits:
+            if fit._cost_function._fast_math:
+                any_fast_math = True
+        if any_fast_math:
+            self._nexus.add_function(
+                log_determinant_cholesky,
+                func_name="total_cov_mat_log_determinant",
+                par_names=["total_cov_mat_cholesky"],
+                existing_behavior="replace",
+            )
+        else:
+            self._nexus.add_function(
+                log_determinant_qr,
+                func_name="total_cov_mat_log_determinant",
+                par_names=["total_cov_mat_qr"],
+                existing_behavior="replace",
+            )
 
         self._shared_cost_function = SharedCostFunction()
         self._nexus.add_function(
-            func=self._shared_cost_function, func_name=self._shared_cost_function.name,
-            par_names=self._shared_cost_function.arg_names
+            func=self._shared_cost_function,
+            func_name=self._shared_cost_function.name,
+            par_names=self._shared_cost_function.arg_names,
         )
         _cost_functions.append(self._shared_cost_function)
         _cost_names.append(self._shared_cost_function.name)
-        self._cost_function = MultiCostFunction(
-            singular_cost_functions=_cost_functions, cost_function_names=_cost_names)
+        self._cost_function = MultiCostFunction(singular_cost_functions=_cost_functions, cost_function_names=_cost_names)
         self._nexus.add_function(
             func=self._cost_function,
             func_name=self._cost_function.name,
             par_names=self._cost_function.arg_names,
-            existing_behavior='replace'
+            existing_behavior="replace",
         )
         self._initialize_fitter()
 
     def _initialize_fitter(self):
         self._fitter = NexusFitter(
-            nexus=self._nexus, parameters_to_fit=list(self._combined_parameter_node_dict.keys()),
-            parameter_to_minimize=self._cost_function.name, minimizer=self._minimizer,
-            minimizer_kwargs=self._minimizer_kwargs
+            nexus=self._nexus,
+            parameters_to_fit=list(self._combined_parameter_node_dict.keys()),
+            parameter_to_minimize=self._cost_function.name,
+            minimizer=self._minimizer,
+            minimizer_kwargs=self._minimizer_kwargs,
         )
 
     def _add_error_object(self, error_object, reference, name=None, axis=None):
         from ..indexed import IndexedFit
         from ..xy import XYFit
 
-        if axis not in [None, 'x', 'y']:
+        if axis not in [None, "x", "y"]:
             raise ValueError("axis must be one of: None, 'x', 'y'")
         _data_size_0 = self._fits[error_object.fit_indices[0]].data_size
         for _fit_index in error_object.fit_indices:
             if not self._fits[_fit_index]._cost_function.is_chi2:
-                raise ValueError(
-                    "Cannot add shared error because cost function of fit %s is not chi2!"
-                    % _fit_index)
+                raise ValueError("Cannot add shared error because cost function of fit %s is not chi2!" % _fit_index)
             if isinstance(self._fits[_fit_index], XYFit) and axis is None:
                 raise ValueError("axis=None is ambiguous for fit %s because it is an XYFit!" % axis)
-            if isinstance(self._fits[_fit_index], IndexedFit) and axis == 'x':
-                raise ValueError(
-                    "axis='x' is incompatible with fit %s because it is an IndexedFit!"
-                    % _fit_index)
+            if isinstance(self._fits[_fit_index], IndexedFit) and axis == "x":
+                raise ValueError("axis='x' is incompatible with fit %s because it is an IndexedFit!" % _fit_index)
             if self._fits[_fit_index].data_size != _data_size_0:
-                raise ValueError(
-                    "Fit %s data_size not the same as data_size of Fit 0!" % _fit_index)
+                raise ValueError("Fit %s data_size not the same as data_size of Fit 0!" % _fit_index)
 
         if error_object.relative:
-            if reference not in ('data', 'model'):
-                raise ValueError(
-                    "Error reference must be either 'model' or 'data' but received %s" % reference)
-            if axis == 'x' and reference == 'data':
-                _node_name = 'x_data%s'
-            elif axis == 'y' and reference == 'data':
-                _node_name = 'y_data%s'
-            elif axis == 'x' and reference == 'model':
-                _node_name = 'x_model%s'
+            if reference not in ("data", "model"):
+                raise ValueError("Error reference must be either 'model' or 'data' but received %s" % reference)
+            if axis == "x" and reference == "data":
+                _node_name = "x_data%s"
+            elif axis == "y" and reference == "data":
+                _node_name = "y_data%s"
+            elif axis == "x" and reference == "model":
+                _node_name = "x_model%s"
                 raise ValueError("Shared errors relative to model are not supported.")
-            elif axis == 'y' and reference == 'model':
-                _node_name = 'y_model%s'
+            elif axis == "y" and reference == "model":
+                _node_name = "y_model%s"
                 raise ValueError("Shared errors relative to model are not supported.")
             else:
                 raise AssertionError()
@@ -372,15 +412,14 @@ class MultiFit(FitBase):
                     _first_index = _fit_index
                 else:
                     _other_reference_value = self._nexus.get(_node_name % _fit_index).value
-                    if _reference_value.shape != _other_reference_value.shape or np.any(
-                            (_reference_value - _other_reference_value) != 0):
+                    if _reference_value.shape != _other_reference_value.shape or np.any((_reference_value - _other_reference_value) != 0):
                         raise ValueError(
-                            "Cannot add a relative error for fits %s and %s because they have "
-                            "conflicting references." % (_first_index, _fit_index))
+                            "Cannot add a relative error for fits %s and %s because they have " "conflicting references." % (_first_index, _fit_index)
+                        )
             error_object.reference = _reference_value
 
         if axis is None:
-            axis = 'y'
+            axis = "y"
         if name in self._shared_error_dicts:
             raise ValueError("Error with name=%s already exists!" % name)
         if name is None:
@@ -448,9 +487,9 @@ class MultiFit(FitBase):
         for _fit in self._fits:
             _fit._pre_fit_iteration(first_fit)
 
-    def _post_fit_iteration(self, first_fit=False):
+    def _post_fit_iteration(self, runtime, first_fit=False):
         for _fit in self._fits:
-            _fit._post_fit_iteration(first_fit)
+            _fit._post_fit_iteration(runtime, first_fit)
 
     # -- public properties
 
@@ -603,8 +642,7 @@ class MultiFit(FitBase):
         if _data_size is None:
             return None
         else:
-            return self.data_size - len(self._combined_parameter_node_dict.keys()) \
-                + len(self._fitter.fixed_parameters)
+            return self.data_size - len(self._combined_parameter_node_dict.keys()) + len(self._fitter.fixed_parameters)
 
     @property
     def goodness_of_fit(self):
@@ -618,8 +656,8 @@ class MultiFit(FitBase):
             _gof_sum += _gof
         if self._shared_error_nodes_initialized:
             _gof_sum += self._shared_cost_function.goodness_of_fit(
-                *[self._nexus.get(_node_name).value
-                  for _node_name in self._shared_cost_function.arg_names])
+                *[self._nexus.get(_node_name).value for _node_name in self._shared_cost_function.arg_names]
+            )
         return _gof_sum
 
     @property
@@ -630,15 +668,24 @@ class MultiFit(FitBase):
             _cost -= self._nexus.get("total_cov_mat_log_determinant").value
         for _fit in self._fits:
             _cost_func = _fit._cost_function
-            if _cost_func.add_determinant_cost and not (
-                    self._shared_error_nodes_initialized and _cost_func.is_chi2):
+            if _cost_func.add_determinant_cost and not (self._shared_error_nodes_initialized and _cost_func.is_chi2):
                 _cost -= _fit._nexus.get("total_cov_mat_log_determinant").value
         return self._cost_function.chi2_probability(_cost, self.ndf)
 
     # -- public methods
 
-    def add_matrix_error(self, err_matrix, matrix_type, fits, axis=None, name=None, err_val=None,
-                         relative=False, reference='data', **kwargs):
+    def add_matrix_error(
+        self,
+        err_matrix,
+        matrix_type,
+        fits,
+        axis=None,
+        name=None,
+        err_val=None,
+        relative=False,
+        reference="data",
+        **kwargs,
+    ):
         """Add a matrix uncertainty source for use in the fit.
 
         :param err_matrix: Covariance or correlation matrix.
@@ -665,20 +712,40 @@ class MultiFit(FitBase):
         """
         # TODO relative errors
         if isinstance(fits, int):
-            self._fits[fits].add_matrix_error(err_matrix=err_matrix, matrix_type=matrix_type, axis=axis, name=name,
-                                              err_val=err_val, relative=relative, reference=reference, **kwargs)
+            self._fits[fits].add_matrix_error(
+                err_matrix=err_matrix,
+                matrix_type=matrix_type,
+                axis=axis,
+                name=name,
+                err_val=err_val,
+                relative=relative,
+                reference=reference,
+                **kwargs,
+            )
         else:
-            if fits == 'all':
+            if fits == "all":
                 fits = list(range(len(self._fits)))
             _matrix_error = MatrixGaussianError(
-                err_matrix=err_matrix, matrix_type=matrix_type, err_val=err_val, relative=relative,
-                fit_indices=fits
+                err_matrix=err_matrix,
+                matrix_type=matrix_type,
+                err_val=err_val,
+                relative=relative,
+                fit_indices=fits,
             )
             _matrix_error.check_cov_mat_symmetry()
-            return self._add_error_object(error_object=_matrix_error, reference=reference,
-                                          name=name, axis=axis)
+            return self._add_error_object(error_object=_matrix_error, reference=reference, name=name, axis=axis)
 
-    def add_error(self, err_val, fits, axis=None, name=None, correlation=0, relative=False, reference='data', **kwargs):
+    def add_error(
+        self,
+        err_val,
+        fits,
+        axis=None,
+        name=None,
+        correlation=0,
+        relative=False,
+        reference="data",
+        **kwargs,
+    ):
         """Add an uncertainty source to the fit.
 
         :param err_val: Pointwise uncertainty/uncertainties for all data points.
@@ -703,11 +770,16 @@ class MultiFit(FitBase):
         """
         if isinstance(fits, int):
             self._fits[fits].add_error(
-                err_val=err_val, name=name, correlation=correlation, relative=relative,
-                axis=axis, reference=reference, **kwargs
+                err_val=err_val,
+                name=name,
+                correlation=correlation,
+                relative=relative,
+                axis=axis,
+                reference=reference,
+                **kwargs,
             )
         else:
-            if fits == 'all':
+            if fits == "all":
                 fits = list(range(len(self._fits)))
             try:
                 err_val.ndim  # will raise if simple float
@@ -717,11 +789,8 @@ class MultiFit(FitBase):
             if err_val.ndim == 0:  # if dimensionless numpy array (i.e. float64), add a dimension
                 err_val = np.ones(self._fits[fits[0]].data_size) * err_val
                 # Consistent data size is checked later.
-            _simple_error = SimpleGaussianError(
-                err_val=err_val, corr_coeff=correlation, relative=relative, fit_indices=fits
-            )
-            return self._add_error_object(error_object=_simple_error, reference=reference,
-                                          name=name, axis=axis)
+            _simple_error = SimpleGaussianError(err_val=err_val, corr_coeff=correlation, relative=relative, fit_indices=fits)
+            return self._add_error_object(error_object=_simple_error, reference=reference, name=name, axis=axis)
 
     def assign_model_function_expression(self, expression_format_string, fit_index=None):
         """Assign a plain-text-formatted expression string to the model function of one of the individual fits.
@@ -733,11 +802,9 @@ class MultiFit(FitBase):
         """
         if fit_index is None:
             for _fit in self._fits:
-                _fit.assign_model_function_expression(
-                    expression_format_string=expression_format_string)
+                _fit.assign_model_function_expression(expression_format_string=expression_format_string)
         else:
-            self._fits[fit_index].assign_model_function_expression(
-                expression_format_string=expression_format_string)
+            self._fits[fit_index].assign_model_function_expression(expression_format_string=expression_format_string)
 
     def assign_model_function_latex_name(self, latex_name, fit_index=None):
         """Assign a LaTeX-formatted string to be the model function name of one of the individual fits.
@@ -765,11 +832,9 @@ class MultiFit(FitBase):
         """
         if fit_index is None:
             for _fit in self._fits:
-                _fit.assign_model_function_latex_expression(
-                    latex_expression_format_string=latex_expression_format_string)
+                _fit.assign_model_function_latex_expression(latex_expression_format_string=latex_expression_format_string)
         else:
-            self._fits[fit_index].assign_model_function_latex_expression(
-                latex_expression_format_string=latex_expression_format_string)
+            self._fits[fit_index].assign_model_function_latex_expression(latex_expression_format_string=latex_expression_format_string)
 
     def assign_parameter_latex_names(self, **par_latex_names_dict):
         _keys = list(par_latex_names_dict.keys())
@@ -783,9 +848,7 @@ class MultiFit(FitBase):
                     except ValueError:
                         pass
         if _keys:
-            warnings.warn(
-                "Could not assign all parameter latex names to single fits. Leftover: {}".format(
-                    _keys))
+            warnings.warn("Could not assign all parameter latex names to single fits. Leftover: {}".format(_keys))
 
     def disable_error(self, err_id):
         for _fit in self._fits:
@@ -808,12 +871,11 @@ class MultiFit(FitBase):
             fit.release_parameter(name)
 
     def do_fit(self, asymmetric_parameter_errors=False):
-        _fit_result = super(MultiFit, self).do_fit(
-            asymmetric_parameter_errors=asymmetric_parameter_errors)
+        _fit_result = super(MultiFit, self).do_fit(asymmetric_parameter_errors=asymmetric_parameter_errors)
         self._update_singular_fits()
         return _fit_result
 
-    def get_matching_errors(self, fit_index=None, matching_criteria=None, matching_type='equal'):
+    def get_matching_errors(self, fit_index=None, matching_criteria=None, matching_type="equal"):
         """Return a list of uncertainty objects fulfilling the specified matching criteria.
 
         Valid keys for **matching_criteria**:
@@ -848,18 +910,22 @@ class MultiFit(FitBase):
         if fit_index is None:
             _combined_matching_errors = dict()
             for _fit in self._fits:
-                _matching_errors = _fit.get_matching_errors(
-                    matching_criteria=matching_criteria, matching_type=matching_type)
+                _matching_errors = _fit.get_matching_errors(matching_criteria=matching_criteria, matching_type=matching_type)
                 for _key in _matching_errors:
                     # FATAL: there is an error with the same name in separate fits
                     assert _key not in _combined_matching_errors
                     _combined_matching_errors[_key] = _matching_errors[_key]
             return _combined_matching_errors
-        return self._fits[fit_index].get_matching_errors(matching_criteria=matching_criteria,
-                                                         matching_type=matching_type)
+        return self._fits[fit_index].get_matching_errors(matching_criteria=matching_criteria, matching_type=matching_type)
 
-    def report(self, output_stream=sys.stdout, show_data=True, show_model=True, show_fit_results=True,
-               asymmetric_parameter_errors=False):
+    def report(
+        self,
+        output_stream=sys.stdout,
+        show_data=True,
+        show_model=True,
+        show_fit_results=True,
+        asymmetric_parameter_errors=False,
+    ):
         """Print a summary for each fit state and/or the multifit results.
 
         :param output_stream: The output stream to which the report should be printed.
@@ -873,22 +939,27 @@ class MultiFit(FitBase):
         :param asymmetric_parameter_errors: If ``True``, use two different parameter errors for up/down directions.
         :type asymmetric_parameter_errors: bool
         """
-        _indent = ' ' * 4
+        _indent = " " * 4
 
         for _i, _fit in enumerate(self._fits):
-            _header_string = '#########\n'
-            if _i > 9:
-                _header_string = '#' + _header_string
-            if _i > 99:
-                _header_string = '#' + _header_string
-            output_stream.write(_header_string)
-            output_stream.write('# Fit %s #\n' % _i)
-            output_stream.write(_header_string)
-            output_stream.write('\n')
+            if show_data or show_model:
+                _header_string = "#########\n"
+                if _i > 9:
+                    _header_string = "#" + _header_string
+                if _i > 99:
+                    _header_string = "#" + _header_string
+                output_stream.write(_header_string)
+                output_stream.write("# Fit %s #\n" % _i)
+                output_stream.write(_header_string)
+                output_stream.write("\n")
 
             if show_data:
                 _fit._report_data(output_stream=output_stream, indent=_indent, indentation_level=1)
             if show_model:
                 _fit._report_model(output_stream=output_stream, indent=_indent, indentation_level=1)
-        self._report_fit_results(output_stream=output_stream, indent=_indent, indentation_level=0,
-                                 asymmetric_parameter_errors=asymmetric_parameter_errors)
+        self._report_fit_results(
+            output_stream=output_stream,
+            indent=_indent,
+            indentation_level=0,
+            asymmetric_parameter_errors=asymmetric_parameter_errors,
+        )
