@@ -1,38 +1,36 @@
 import numpy as np
 from matplotlib.collections import LineCollection
 
-from .._base import PlotAdapterBase, PlotAdapterException
 from .._aux import add_pad_to_range
-
+from .._base import PlotAdapterBase
 
 __all__ = ["UnbinnedPlotAdapter"]
 
 
-class UnbinnedPlotAdapterException(PlotAdapterException):
-    pass
-
-
 class UnbinnedPlotAdapter(PlotAdapterBase):
-
-    PLOT_STYLE_CONFIG_DATA_TYPE = 'unbinned'
+    PLOT_STYLE_CONFIG_DATA_TYPE = "unbinned"
 
     PLOT_SUBPLOT_TYPES = dict(
         PlotAdapterBase.PLOT_SUBPLOT_TYPES,
         model_line=dict(
-            plot_adapter_method='plot_model_line',
-            target_axes='main',
-        )
+            plot_adapter_method="plot_model_line",
+            target_axes="main",
+        ),
     )
-    PLOT_SUBPLOT_TYPES['model']['hide'] = True  # don't show "model" points
+    PLOT_SUBPLOT_TYPES["model"]["hide"] = True  # don't show "model" points
 
-    AVAILABLE_X_SCALES = ('linear', 'log')
+    AVAILABLE_X_SCALES = ("linear", "log")
 
-    def __init__(self, unbinned_fit_object):
+    def __init__(self, unbinned_fit_object, from_container=False):
         """
         Construct an :py:obj:`UnbinnedPlotAdapter` for a :py:obj:`~kafe2.fit.unbinned.UnbinnedFit` object:
+
         :param unbinned_fit_object: an :py:obj:`~kafe2.fit.unbinned.UnbinnedFit` object
+        :param from_container: Whether unbinned_fit_object was created ad-hoc from just a data
+            container.
+        :type from_container: bool
         """
-        super(UnbinnedPlotAdapter, self).__init__(fit_object=unbinned_fit_object)
+        super(UnbinnedPlotAdapter, self).__init__(fit_object=unbinned_fit_object, from_container=from_container)
         self.n_plot_points = 100 if len(self.data_x) < 100 else len(self.data_x)
 
         self.x_range = add_pad_to_range(self._fit.data_range, scale=self.x_scale)
@@ -58,7 +56,7 @@ class UnbinnedPlotAdapter(PlotAdapterBase):
 
         :return: iterable
         """
-        raise UnbinnedPlotAdapterException("There's no y-data in the unbinned container")
+        raise TypeError("There's no y-data in the unbinned container")
 
     @property
     def data_xerr(self):
@@ -71,7 +69,7 @@ class UnbinnedPlotAdapter(PlotAdapterBase):
 
     @property
     def data_yerr(self):
-        raise UnbinnedPlotAdapterException("There's no y-data in the unbinned container, hence no y-error")
+        raise TypeError("There's no y-data in the unbinned container, hence no y-error")
 
     @property
     def model_x(self):
@@ -86,23 +84,19 @@ class UnbinnedPlotAdapter(PlotAdapterBase):
         :return: iterable
         """
         return self._fit.model
-        #raise UnbinnedPlotAdapterException("There's no y-model in the unbinned container")
 
     @property
     def model_line_x(self):
         """x support values for model function"""
         _xmin, _xmax = self.x_range
-        if self.x_scale == 'linear':
+        if self.x_scale == "linear":
             return np.linspace(_xmin, _xmax, self.n_plot_points)
-        if self.x_scale == 'log':
+        if self.x_scale == "log":
             try:
                 return np.geomspace(_xmin, _xmax, self.n_plot_points)
             except ValueError:
-                raise UnbinnedPlotAdapterException("Support point calculation failed. "
-                                                   "The plot range can't include 0 when using log "
-                                                   "scale.")
-        raise UnbinnedPlotAdapterException("x_range has to be one of {}. Found {} instead.".format(
-            self.AVAILABLE_X_SCALES, self.x_scale))
+                raise ValueError("Support point calculation failed. The plot range can't include 0 " "when using log scale.")
+        raise ValueError("x_range has to be one of {}. Found {} instead.".format(self.AVAILABLE_X_SCALES, self.x_scale))
 
     @property
     def model_line_y(self):
@@ -149,17 +143,16 @@ class UnbinnedPlotAdapter(PlotAdapterBase):
         :type height: float
         :return: plot handle(s)
         """
-        kwargs.pop('marker', None)  # pop marker keyword, as LineCollection doesn't support it
+        kwargs.pop("marker", None)  # pop marker keyword, as LineCollection doesn't support it
 
         if height is None:
-            if self.y_scale == 'linear':
-                height = self.y_range[1]/10  # set height to 1/10th of the max height of the model
-            elif self.y_scale == 'log':
-                height = 10**(np.log10(self.y_range[1])/10)
+            if self.y_scale == "linear":
+                height = self.y_range[1] / 10  # set height to 1/10th of the max height of the model
+            elif self.y_scale == "log":
+                height = 10 ** (np.log10(self.y_range[1]) / 10)
 
         data = self.data_x
-        xy_pairs = np.column_stack([np.repeat(data, 2),
-                                    np.tile([self.y_range[0], height], len(data))])
+        xy_pairs = np.column_stack([np.repeat(data, 2), np.tile([self.y_range[0], height], len(data))])
         lines = xy_pairs.reshape([len(data), 2, 2])
         line_segments = LineCollection(lines, **kwargs)
         return target_axes.add_collection(line_segments)
@@ -174,10 +167,10 @@ class UnbinnedPlotAdapter(PlotAdapterBase):
         """
         return target_axes.plot(self.model_x, self.model_y, **kwargs)
 
-    def plot_ratio(self, target_axes, error_contributions=('data',), **kwargs):
+    def plot_ratio(self, target_axes, error_contributions=("data",), **kwargs):
         raise TypeError("Data/model ratio cannot be plotted for unbinned fits.")
 
-    def plot_residual(self, target_axes, error_contributions=('data',), **kwargs):
+    def plot_residual(self, target_axes, error_contributions=("data",), **kwargs):
         raise TypeError("Residuals cannot be plotted for unbinned fits.")
 
     def plot_model_line(self, target_axes, **kwargs):
