@@ -1,27 +1,29 @@
+# flake8: noqa F401 (imported but unused)
 try:
     import typing  # help IDEs with type-hinting inside docstrings
 except ImportError:
     pass
-import numpy  # help IDEs with type-hinting inside docstrings
 from collections import OrderedDict
 from copy import deepcopy
+
+import numpy  # help IDEs with type-hinting inside docstrings
 import numpy as np
 
 from ...core.error import CovMat
 from ...tools import print_dict_as_table
-from .._base import FitException, FitBase, DataContainerBase, ModelFunctionBase
+from .._base import DataContainerBase, FitBase, ModelFunctionBase
+from ..util import (
+    add_in_quadrature,
+    check_numerical_range,
+    function_library,
+    invert_matrix,
+)
 from .container import XYContainer
-from .cost import XYCostFunction_Chi2, STRING_TO_COST_FUNCTION
+from .cost import STRING_TO_COST_FUNCTION, XYCostFunction_Chi2
 from .model import XYParametricModel
 from .plot import XYPlotAdapter
-from ..util import function_library, add_in_quadrature, invert_matrix
 
-
-__all__ = ['XYFit', 'XYFitException']
-
-
-class XYFitException(FitException):
-    pass
+__all__ = ["XYFit"]
 
 
 class XYFit(FitBase):
@@ -29,38 +31,61 @@ class XYFit(FitBase):
     MODEL_TYPE = XYParametricModel
     MODEL_FUNCTION_TYPE = ModelFunctionBase
     PLOT_ADAPTER_TYPE = XYPlotAdapter
-    EXCEPTION_TYPE = XYFitException
-    RESERVED_NODE_NAMES = {'y_data', 'y_model', 'cost',
-                           'x_error', 'y_data_error', 'y_model_error', 'total_error',
-                           'x_cov_mat', 'y_data_cov_mat', 'y_model_cov_mat', 'total_cov_mat',
-                           'x_cor_mat', 'y_data_cor_mat', 'y_model_cor_mat', 'total_cor_mat',
-                           'x_cov_mat_inverse', 'y_data_cov_mat_inverse', 'y_model_cov_mat_inverse', 'total_cor_mat_inverse'
-                           'x_data_cov_mat'}
-    _BASIC_ERROR_NAMES = {
-        'x_data_error', 'x_model_error', 'x_data_cov_mat', 'x_model_cov_mat',
-        'y_data_error', 'y_model_error', 'y_data_cov_mat', 'y_model_cov_mat'
+    RESERVED_NODE_NAMES = {
+        "y_data",
+        "y_model",
+        "cost",
+        "x_error",
+        "y_data_error",
+        "y_model_error",
+        "total_error",
+        "x_cov_mat",
+        "y_data_cov_mat",
+        "y_model_cov_mat",
+        "total_cov_mat",
+        "x_cor_mat",
+        "y_data_cor_mat",
+        "y_model_cor_mat",
+        "total_cor_mat",
+        "x_cov_mat_inverse",
+        "y_data_cov_mat_inverse",
+        "y_model_cov_mat_inverse",
+        "total_cor_mat_inverse" "x_data_cov_mat",
     }
-    X_ERROR_ALGORITHMS = ('iterative linear', 'nonlinear')
+    _BASIC_ERROR_NAMES = {
+        "x_data_error",
+        "x_model_error",
+        "x_data_cov_mat",
+        "x_model_cov_mat",
+        "y_data_error",
+        "y_model_error",
+        "y_data_cov_mat",
+        "y_model_cov_mat",
+    }
+    X_ERROR_ALGORITHMS = ("iterative linear", "nonlinear")
     _STRING_TO_COST_FUNCTION = STRING_TO_COST_FUNCTION
     _AXES = (None, "x", "y")
     _MODEL_NAME = "y_model"
     _MODEL_ERROR_NODE_NAMES = ["y_model_error", "y_model_cov_mat"]
     _PROJECTED_NODE_NAMES = ["total_error", "total_cov_mat"]
 
-    def __init__(self,
-                 xy_data,
-                 model_function=function_library.linear_model,
-                 cost_function="chi2",
-                 minimizer=None, minimizer_kwargs=None,
-                 dynamic_error_algorithm="nonlinear"):
+    def __init__(
+        self,
+        xy_data,
+        model_function=function_library.linear_model,
+        cost_function="chi2",
+        minimizer=None,
+        minimizer_kwargs=None,
+        dynamic_error_algorithm="nonlinear",
+    ):
         """Construct a fit of a model to *xy* data.
 
         :param xy_data: A :py:obj:`~.XYContainer` or a raw 2D array of shape ``(2, N)``
          containing the measurement data.
         :type xy_data: XYContainer or typing.Sequence
         :param model_function: The model function as a native Python function where the first
-            argument denotes the independent *x* variable or an already defined
-            :py:class:`~kafe2.fit.xy.XYModelFunction` object.
+            argument denotes the independent *x* variable. Alternatively an already defined
+            :py:class:`~kafe2.fit.xy.XYModelFunction` object. Defaults to a straight line.
         :type model_function: typing.Callable
         :param cost_function: The cost function this fit uses to find the best parameters.
         :type cost_function: str or typing.Callable
@@ -71,9 +96,13 @@ class XYFit(FitBase):
         :type minimizer_kwargs: dict
         """
         super(XYFit, self).__init__(
-            data=xy_data, model_function=model_function, cost_function=cost_function,
-            minimizer=minimizer, minimizer_kwargs=minimizer_kwargs,
-            dynamic_error_algorithm=dynamic_error_algorithm)
+            data=xy_data,
+            model_function=model_function,
+            cost_function=cost_function,
+            minimizer=minimizer,
+            minimizer_kwargs=minimizer_kwargs,
+            dynamic_error_algorithm=dynamic_error_algorithm,
+        )
 
     # -- private methods
 
@@ -83,47 +112,25 @@ class XYFit(FitBase):
         self._nexus.add_function(
             func=self._project_cov_mat,
             func_name="total_cov_mat",
-            par_names=[
-                "x_total_cov_mat",
-                "y_total_cov_mat",
-                "x_model",
-                "parameter_values"
-            ],
-            existing_behavior="replace"
+            par_names=["x_total_cov_mat", "y_total_cov_mat", "x_model", "parameter_values"],
+            existing_behavior="replace",
         )
         self._nexus.add_function(
             func=self._project_error,
             func_name="total_error",
-            par_names=[
-                "x_total_error",
-                "y_total_error",
-                "x_model",
-                "parameter_values"
-            ],
-            existing_behavior="replace"
+            par_names=["x_total_error", "y_total_error", "x_model", "parameter_values"],
+            existing_behavior="replace",
         )
 
-        self._nexus.add_dependency(
-            'y_model',
-            depends_on=(
-                'x_model',
-                'parameter_values'
-            )
-        )
+        self._nexus.add_dependency("y_model", depends_on=("x_model", "parameter_values"))
 
-        self._nexus.add_dependency(
-            'x_model',
-            depends_on=(
-                'x_data',
-            )
-        )
+        self._nexus.add_dependency("x_model", depends_on=("x_data",))
 
     def _set_new_data(self, new_data):
         if isinstance(new_data, self.CONTAINER_TYPE):
             self._data_container = deepcopy(new_data)
         elif isinstance(new_data, DataContainerBase):
-            raise XYFitException("Incompatible container type '%s' (expected '%s')"
-                                 % (type(new_data), self.CONTAINER_TYPE))
+            raise TypeError("Incompatible container type '%s' (expected '%s')" % (type(new_data), self.CONTAINER_TYPE))
         else:
             _x_data = new_data[0]
             _y_data = new_data[1]
@@ -131,79 +138,69 @@ class XYFit(FitBase):
         self._data_container._on_error_change_callback = self._on_error_change
 
         # update nexus data nodes
-        self._nexus.get('x_data').mark_for_update()
-        self._nexus.get('y_data').mark_for_update()
+        self._nexus.get("x_data").mark_for_update()
+        self._nexus.get("y_data").mark_for_update()
+        check_numerical_range(self.x_data, "x_data")
+        check_numerical_range(self.y_data, "y_data")
 
     def _set_new_parametric_model(self):
-        self._param_model = XYParametricModel(
-            self.x_model,
-            self._model_function,
-            self.parameter_values
-        )
+        self._param_model = XYParametricModel(self.x_model, self._model_function, self.parameter_values)
 
     def _report_data(self, output_stream, indent, indentation_level):
-        output_stream.write(indent * indentation_level + '########\n')
-        output_stream.write(indent * indentation_level + '# Data #\n')
-        output_stream.write(indent * indentation_level + '########\n\n')
+        output_stream.write(indent * indentation_level + "########\n")
+        output_stream.write(indent * indentation_level + "# Data #\n")
+        output_stream.write(indent * indentation_level + "########\n\n")
         _data_table_dict = OrderedDict()
-        _data_table_dict['X Data'] = self.x_data
+        _data_table_dict["X Data"] = self.x_data
         if self._data_container.has_x_errors:
-            _data_table_dict['X Data Error'] = self.x_data_error
-            _data_table_dict['X Data Correlation Matrix'] = self.x_data_cor_mat
+            _data_table_dict["X Data Error"] = self.x_data_error
+            _data_table_dict["X Data Correlation Matrix"] = self.x_data_cor_mat
 
         print_dict_as_table(_data_table_dict, output_stream=output_stream, indent_level=indentation_level + 1)
-        output_stream.write('\n')
+        output_stream.write("\n")
 
         _data_table_dict = OrderedDict()
-        _data_table_dict['Y Data'] = self.y_data
+        _data_table_dict["Y Data"] = self.y_data
         if self._data_container.has_y_errors:
-            _data_table_dict['Y Data Error'] = self.y_data_error
-            _data_table_dict['Y Data Correlation Matrix'] = self.y_data_cor_mat
+            _data_table_dict["Y Data Error"] = self.y_data_error
+            _data_table_dict["Y Data Correlation Matrix"] = self.y_data_cor_mat
 
         print_dict_as_table(_data_table_dict, output_stream=output_stream, indent_level=indentation_level + 1)
-        output_stream.write('\n')
+        output_stream.write("\n")
 
     def _report_model(self, output_stream, indent, indentation_level):
         # call base method to show header and model function
         super(XYFit, self)._report_model(output_stream, indent, indentation_level)
         _model_table_dict = OrderedDict()
-        _model_table_dict['X Model'] = self.x_model
+        _model_table_dict["X Model"] = self.x_model
         if self._param_model.has_x_errors:
-            _model_table_dict['X Model Error'] = self.x_model_error
-            _model_table_dict['X Model Correlation Matrix'] = self.x_model_cor_mat
+            _model_table_dict["X Model Error"] = self.x_model_error
+            _model_table_dict["X Model Correlation Matrix"] = self.x_model_cor_mat
 
         print_dict_as_table(_model_table_dict, output_stream=output_stream, indent_level=indentation_level + 1)
-        output_stream.write('\n')
+        output_stream.write("\n")
 
         _model_table_dict = OrderedDict()
-        _model_table_dict['Y Model'] = self.y_model
+        _model_table_dict["Y Model"] = self.y_model
         if self._param_model.has_y_errors:
-            _model_table_dict['Y Model Error'] = self.y_model_error
-            _model_table_dict['Y Model Correlation Matrix'] = self.y_model_cor_mat
+            _model_table_dict["Y Model Error"] = self.y_model_error
+            _model_table_dict["Y Model Correlation Matrix"] = self.y_model_cor_mat
 
         print_dict_as_table(_model_table_dict, output_stream=output_stream, indent_level=indentation_level + 1)
-        output_stream.write('\n')
+        output_stream.write("\n")
         if self._param_model.get_matching_errors({"relative": True, "axis": 1}):
             output_stream.write(indent * (indentation_level + 1))
-            output_stream.write(
-                "y model covariance matrix was calculated dynamically relative to y model values.\n"
-            )
+            output_stream.write("y model covariance matrix was calculated dynamically relative to y model values.\n")
             output_stream.write("\n")
 
     def _project_cov_mat(self, x_cov_mat, y_cov_mat, x_model, parameter_values):
         _derivatives = self._param_model.eval_model_function_derivative_by_x(
-            x=x_model,
-            dx=0.01 * np.sqrt(np.diag(x_cov_mat)),
-            model_parameters=parameter_values
+            x=x_model, dx=0.01 * np.sqrt(np.diag(x_cov_mat)), model_parameters=parameter_values
         )
         return y_cov_mat + x_cov_mat * np.outer(_derivatives, _derivatives)
 
     def _project_error(self, x_error, y_error, x_model, parameter_values):
-        _derivatives = self._param_model.eval_model_function_derivative_by_x(
-            x=x_model,
-            dx=0.01 * x_error,
-            model_parameters=parameter_values
-        )
+        _derivatives = self._param_model.eval_model_function_derivative_by_x(x=x_model, dx=0.01 * x_error, model_parameters=parameter_values)
         return np.sqrt(np.square(y_error) + np.square(x_error * _derivatives))
 
     def _set_data_as_model_ref(self):
@@ -215,18 +212,18 @@ class XYFit(FitBase):
         return _errs_and_old_refs
 
     def _iterative_fits_needed(self):
-        return (bool(self._param_model.get_matching_errors({"relative": True, "axis": 1}))
-                or self.has_x_errors) \
-               and self._dynamic_error_algorithm == "iterative"
+        return (
+            bool(self._param_model.get_matching_errors({"relative": True, "axis": 1})) or self.has_x_errors
+        ) and self._dynamic_error_algorithm == "iterative"
 
     def _second_fit_needed(self):
-        return (bool(self._param_model.get_matching_errors({"relative": True, "axis": 1}))
-                or self.has_x_errors) and self._dynamic_error_algorithm == "nonlinear"
+        return (
+            bool(self._param_model.get_matching_errors({"relative": True, "axis": 1})) or self.has_x_errors
+        ) and self._dynamic_error_algorithm == "nonlinear"
 
     def _get_node_names_to_freeze(self, first_fit):
         if self._dynamic_error_algorithm == "iterative" or (first_fit and self.has_x_errors):
-            return self._PROJECTED_NODE_NAMES + super(
-                XYFit, self)._get_node_names_to_freeze(first_fit)
+            return self._PROJECTED_NODE_NAMES + super(XYFit, self)._get_node_names_to_freeze(first_fit)
         else:
             return super(XYFit, self)._get_node_names_to_freeze(first_fit)
 
@@ -303,8 +300,7 @@ class XYFit(FitBase):
 
         :rtype: numpy.ndarray[float]
         """
-        return self._project_error(
-            self.x_data_error, self.y_data_error, self.x_model, self.parameter_values)
+        return self._project_error(self.x_data_error, self.y_data_error, self.x_model, self.parameter_values)
 
     @property
     def x_data_cov_mat(self):
@@ -329,8 +325,7 @@ class XYFit(FitBase):
 
         :rtype: numpy.ndarray
         """
-        return self._project_cov_mat(
-            self.x_data_cov_mat, self.y_data_cov_mat, self.x_model, self.parameter_values)
+        return self._project_cov_mat(self.x_data_cov_mat, self.y_data_cov_mat, self.x_model, self.parameter_values)
 
     @property
     def x_data_cov_mat_inverse(self):
@@ -420,8 +415,7 @@ class XYFit(FitBase):
 
         :rtype: numpy.ndarray[float]
         """
-        return self._project_error(
-            self.x_model_error, self.y_model_error, self.x_model, self.parameter_values)
+        return self._project_error(self.x_model_error, self.y_model_error, self.x_model, self.parameter_values)
 
     @property
     def x_model_cov_mat(self):
@@ -450,8 +444,7 @@ class XYFit(FitBase):
 
         :rtype: numpy.ndarray
         """
-        return self._project_cov_mat(
-            self.x_model_cov_mat, self.y_model_cov_mat, self.x_model, self.parameter_values)
+        return self._project_cov_mat(self.x_model_cov_mat, self.y_model_cov_mat, self.x_model, self.parameter_values)
 
     @property
     def x_model_cov_mat_inverse(self):
@@ -623,8 +616,7 @@ class XYFit(FitBase):
 
     # -- public methods
 
-    def add_error(self, axis, err_val,
-                  name=None, correlation=0, relative=False, reference='data'):
+    def add_error(self, axis, err_val, name=None, correlation=0, relative=False, reference="data"):
         """Add an uncertainty source for an axis to the data container.
 
         :param axis: ``'x'``/``0`` or ``'y'``/``1``
@@ -645,15 +637,25 @@ class XYFit(FitBase):
         :return: An error id uniquely identifying the created error source.
         :rtype: str
         """
-        return super(XYFit, self).add_error(err_val=err_val,
-                                            name=name,
-                                            correlation=correlation,
-                                            relative=relative,
-                                            reference=reference,
-                                            axis=axis)
+        return super(XYFit, self).add_error(
+            err_val=err_val,
+            name=name,
+            correlation=correlation,
+            relative=relative,
+            reference=reference,
+            axis=axis,
+        )
 
-    def add_matrix_error(self, axis, err_matrix, matrix_type,
-                         name=None, err_val=None, relative=False, reference='data'):
+    def add_matrix_error(
+        self,
+        axis,
+        err_matrix,
+        matrix_type,
+        name=None,
+        err_val=None,
+        relative=False,
+        reference="data",
+    ):
         """Add a matrix uncertainty source for an axis to the data container.
 
         :param axis: ``'x'``/``0`` or ``'y'``/``1``
@@ -678,13 +680,15 @@ class XYFit(FitBase):
         :return: An error id uniquely identifying the created error source.
         :rtype: str
         """
-        return super(XYFit, self).add_matrix_error(err_matrix=err_matrix,
-                                                   matrix_type=matrix_type,
-                                                   name=name,
-                                                   err_val=err_val,
-                                                   relative=relative,
-                                                   reference=reference,
-                                                   axis=axis)
+        return super(XYFit, self).add_matrix_error(
+            err_matrix=err_matrix,
+            matrix_type=matrix_type,
+            name=name,
+            err_val=err_val,
+            relative=relative,
+            reference=reference,
+            axis=axis,
+        )
 
     def eval_model_function(self, x=None, model_parameters=None):
         """Evaluate the model function.
@@ -721,10 +725,9 @@ class XYFit(FitBase):
         """
         self._param_model.parameters = self.parameter_values  # this is lazy, so just do it
         self._param_model.x = self.x_model
-        if par_dx is None and self.did_fit:
-            par_dx = 1e-2*self.parameter_errors
-        return self._param_model.eval_model_function_derivative_by_parameters(
-            x=x, model_parameters=model_parameters, par_dx=par_dx)
+        if par_dx is None and self.did_fit and np.all(np.isfinite(self.parameter_errors)):
+            par_dx = 1e-2 * self.parameter_errors
+        return self._param_model.eval_model_function_derivative_by_parameters(x=x, model_parameters=model_parameters, par_dx=par_dx)
 
     def error_band(self, x=None):
         """Calculate the symmetric model uncertainty at every given point *x*. This is only
@@ -736,11 +739,13 @@ class XYFit(FitBase):
         :rtype: numpy.ndarray[float]
         """
         if not self.did_fit:
-            raise XYFitException('Cannot calculate an error band without first performing a fit.')
+            raise RuntimeError("Cannot calculate an error band without first performing a fit.")
         if x is None:
             x = self.x_model
         if self.parameter_cov_mat is None:
             return np.zeros_like(x)
+        if not np.all(np.isfinite(self.parameter_values)):
+            return None
 
         _f_deriv_by_params = self.eval_model_function_derivative_by_parameters(x=x)
         # here: df/dp[par_idx]|x=x[x_idx] = _f_deriv_by_params[par_idx][x_idx]
@@ -751,8 +756,7 @@ class XYFit(FitBase):
         _band_y = np.zeros_like(x)
 
         # Cut out fixed parameters which have nan as derivative:
-        _not_pars_fixed = [_par_name not in self._fitter.fixed_parameters
-                           for _par_name in self.parameter_names]
+        _not_pars_fixed = [_par_name not in self._fitter.fixed_parameters for _par_name in self.parameter_names]
         _cut_parameter_cov_mat = self.parameter_cov_mat[_not_pars_fixed][:, _not_pars_fixed]
         for _x_idx, _x_val in enumerate(x):
             _p_res = _f_deriv_by_params[_x_idx, _not_pars_fixed]
