@@ -1,28 +1,21 @@
 try:
-    import typing  # help IDEs with type-hinting inside docstrings
+    import typing  # help IDEs with type-hinting inside docstrings  # noqa: F401 (unused import)
 except ImportError:
     pass
+import numdifftools as nd
 import numpy  # help IDEs with type-hinting inside docstrings
 import numpy as np
 
-from scipy.misc import derivative
-
 from .._base import ParametricModelBaseMixin
-from .container import XYContainer, XYContainerException
 from ..util import function_library
+from .container import XYContainer
 
-
-__all__ = ['XYParametricModel', 'XYParametricModelException']
-
-
-class XYParametricModelException(XYContainerException):
-    pass
+__all__ = ["XYParametricModel"]
 
 
 class XYParametricModel(ParametricModelBaseMixin, XYContainer):
     # TODO why is model_function abbreviated as model_func?
-    def __init__(self, x_data, model_func=function_library.linear_model,
-                 model_parameters=(1.0, 1.0)):
+    def __init__(self, x_data, model_func=function_library.linear_model, model_parameters=(1.0, 1.0)):
         """Construct an :py:obj:`XYParametricModel` object:
 
         :param x_data: 1D array containing the *x* values supporting the model
@@ -38,8 +31,7 @@ class XYParametricModel(ParametricModelBaseMixin, XYContainer):
         if np.isscalar(_y_data):
             _y_data = np.ones_like(_x_data_array) * _y_data
         self._pm_calculation_stale = False
-        super(XYParametricModel, self).__init__(model_func, model_parameters,
-                                                _x_data_array, _y_data)
+        super(XYParametricModel, self).__init__(model_func, model_parameters, _x_data_array, _y_data)
 
     # -- private methods
 
@@ -62,7 +54,7 @@ class XYParametricModel(ParametricModelBaseMixin, XYContainer):
 
     @data.setter
     def data(self, new_data):
-        raise XYParametricModelException("Parametric model data cannot be set!")
+        raise TypeError("Parametric model data cannot be set!")
 
     @property
     def x(self):
@@ -93,7 +85,7 @@ class XYParametricModel(ParametricModelBaseMixin, XYContainer):
 
     @y.setter
     def y(self, new_y):
-        raise XYParametricModelException("Parametric model data cannot be set!")
+        raise TypeError("Parametric model data cannot be set!")
 
     # -- public methods
 
@@ -116,8 +108,7 @@ class XYParametricModel(ParametricModelBaseMixin, XYContainer):
             _y = np.ones_like(_x) * _y
         return _y
 
-    def eval_model_function_derivative_by_parameters(self, x=None, model_parameters=None,
-                                                     par_dx=None):
+    def eval_model_function_derivative_by_parameters(self, x=None, model_parameters=None, par_dx=None):
         """Evaluate the derivative of the model function with respect to the model parameters.
 
         :param x: 1D array with length ``N`` containing the *x* values of the support points. If
@@ -133,21 +124,32 @@ class XYParametricModel(ParametricModelBaseMixin, XYContainer):
             derivatives with respect to the parameters.
         :rtype: numpy.ndarray[numpy.ndarray[float]]
         """
+        if x is not None and not np.all(np.isfinite(x)):
+            raise ValueError(f"Provided x contains non-finite values: {x}")
+        if par_dx is not None and not np.all(np.isfinite(par_dx)):
+            raise ValueError(f"Provided par_dx contains non-finite values: {par_dx}")
         _x = x if x is not None else self.x
         _pars = model_parameters if model_parameters is not None else self._model_parameters
         _pars = np.asarray(_pars)
-        _par_dxs = par_dx if par_dx is not None \
-            else 1e-2 * (np.abs(_pars) + 1.0 / (1.0 + np.abs(_pars)))
+        _par_dxs = par_dx if par_dx is not None else 1e-2 * (np.abs(_pars) + 1.0 / (1.0 + np.abs(_pars)))
+
+        # Assert that values being passed to Numdifftools are finite to avoid cryptic error messages:
+        assert np.all(np.isfinite(_pars)), "non-finite parameter values"
+        assert np.all(np.isfinite(_par_dxs)), "non-finite parameter steps"
 
         _ret = np.zeros((len(_pars), len(_x)))
         for _par_idx, (_par_val, _par_dx) in enumerate(zip(_pars, _par_dxs)):
+            if _par_dx == 0.0:  # fixed parameter
+                _ret[_par_idx] = 0.0
+                continue
+
             def _chipped_func(par):
                 _chipped_pars = _pars.copy()
                 _chipped_pars[_par_idx] = par
                 return self._model_function_object(_x, *_chipped_pars)
 
-            _der_val = np.array(derivative(_chipped_func, _par_val, dx=_par_dx))
-            _ret[_par_idx] = _der_val
+            _first_derivative = nd.Derivative(_chipped_func, step=_par_dx, order=4, n=1)
+            _ret[_par_idx] = _first_derivative(_par_val)
         return _ret
 
     def eval_model_function_derivative_by_x(self, x=None, model_parameters=None, dx=None):
@@ -168,7 +170,7 @@ class XYParametricModel(ParametricModelBaseMixin, XYContainer):
         _x = x if x is not None else self.x
         _pars = model_parameters if model_parameters is not None else self._model_parameters
         _dxs = dx if dx is not None else np.zeros_like(_x)
-        _dxs_default = 1e-2 * (np.abs(_x) + 1.0/(1.0+np.abs(_x)))
+        _dxs_default = 1e-2 * (np.abs(_x) + 1.0 / (1.0 + np.abs(_x)))
         _dxs = np.where(_dxs == 0, _dxs_default, _dxs)  # Replace zero values with defaults
 
         _low = self._model_function_object(_x - _dxs, *_pars)
