@@ -2,12 +2,14 @@ import unittest
 
 import numpy as np
 
-from kafe2.core.error import CovMat, cov_mat_from_float_list, cov_mat_from_float
+from kafe2.core.error import CovMat, cov_mat_from_float, cov_mat_from_float_list
+
+# flake8: noqa E201 (whitespace after '[')
 
 
 class TestCovMat(unittest.TestCase):
-
     def setUp(self):
+        # fmt: off
         cm = CovMat([
             [1.00000000e-02, 1.80600000e-02, 8.19000000e-03, 5.62800000e-02, 1.26000000e-03],
             [1.80600000e-02, 1.84900000e-01, 3.52170000e-02, 2.42004000e-01, 5.41800000e-03],
@@ -15,7 +17,8 @@ class TestCovMat(unittest.TestCase):
             [5.62800000e-02, 2.42004000e-01, 1.09746000e-01, 1.79560000e+00, 1.68840000e-02],
             [1.26000000e-03, 5.41800000e-03, 2.45700000e-03, 1.68840000e-02, 9.00000000e-04]
         ])
-        self.reference = [2., 1., 3., 2., 9.]
+        # fmt: on
+        self.reference = [2.0, 1.0, 3.0, 2.0, 9.0]
         self.cm = cm
         self._cm_add_1 = CovMat([[1.0, 0.0], [0.0, 1.0]])
         self._cm_add_2 = CovMat([[2.0, 1.0], [1.0, 2.0]])
@@ -41,6 +44,7 @@ class TestCovMat(unittest.TestCase):
 
     def test_rescale(self):
         self.cm.rescale(self.reference, [3, 2, 1, 9, 2])
+        # fmt: off
         _ref = np.array([
             [2.25000000e-02, 5.41800000e-02, 4.09500000e-03, 3.79890000e-01, 4.20000000e-04],
             [5.41800000e-02, 7.39600000e-01, 2.34780000e-02, 2.17803600e+00, 2.40800000e-03],
@@ -48,6 +52,7 @@ class TestCovMat(unittest.TestCase):
             [3.79890000e-01, 2.17803600e+00, 1.64619000e-01, 3.63609000e+01, 1.68840000e-02],
             [4.20000000e-04, 2.40800000e-03, 1.82000000e-04, 1.68840000e-02, 4.44444444e-05]
         ])
+        # fmt: on
         self.assertTrue(np.allclose(self.cm.mat, _ref))
 
     def test_inverse(self):
@@ -65,10 +70,10 @@ class TestCovMat(unittest.TestCase):
 
 
 class TestCovMatHelperFunctions(unittest.TestCase):
-
     def setUp(self):
         self.values = [0.1, 0.43, 0.195, 1.34, 0.03]
 
+        # fmt: off
         self.ref_fullcor = np.array([
             [1.00000000e-02, 4.30000000e-02, 1.95000000e-02, 1.34000000e-01, 3.00000000e-03],
             [4.30000000e-02, 1.84900000e-01, 8.38500000e-02, 5.76200000e-01, 1.29000000e-02],
@@ -112,6 +117,7 @@ class TestCovMatHelperFunctions(unittest.TestCase):
             [0.00635418, 0.01512900, 0.00635418],
             [0.00635418, 0.00635418, 0.01512900]
         ])
+        # fmt: on
 
     def test_cov_mat_from_float_list_nocor(self):
         cm = cov_mat_from_float_list(self.values, correlation=0.0)
