@@ -1,30 +1,28 @@
-import numpy as np
 import unittest
 
-from kafe2.core.fitters.nexus import (
+import numpy as np
+
+from kafe2.core.fitters.nexus import (  # noqa: F401 (unused import)
+    _OPERATORS,
+    _UNARY_OPERATORS,
+    Alias,
+    Array,
+    Empty,
+    Fallback,
+    Function,
+    Nexus,
     NodeBase,
-    Parameter, Alias,
-    Function, Empty,
-    Fallback, Tuple, Array, RootNode,
-    NodeException, FallbackError,
-
-    NodeChildrenPrinter, NodeCycleChecker,
-
-    _OPERATORS, _UNARY_OPERATORS,
-
-    Nexus, NexusError,
+    NodeChildrenPrinter,
+    NodeCycleChecker,
+    Parameter,
+    RootNode,
+    Tuple,
 )
 
 
 class TestNodes(unittest.TestCase):
-
-    DEFAULT_CONSTRUCTIBLE_NODE_TYPES = (
-        NodeBase, Empty, RootNode
-    )
-    PARAMETRIC_NODE_TYPES = (
-        Parameter, Alias, Function,
-        Fallback, Tuple
-    )
+    DEFAULT_CONSTRUCTIBLE_NODE_TYPES = (NodeBase, Empty, RootNode)
+    PARAMETRIC_NODE_TYPES = (Parameter, Alias, Function, Fallback, Tuple)
 
     @staticmethod
     def sum_function(a, b):
@@ -34,10 +32,7 @@ class TestNodes(unittest.TestCase):
         self.par_a = Parameter(3)
         self.par_b = Parameter(7)
 
-        self.func_sum_a_b = Function(
-            TestNodes.sum_function,
-            parameters=(self.par_a, self.par_b)
-        )
+        self.func_sum_a_b = Function(TestNodes.sum_function, parameters=(self.par_a, self.par_b))
 
         self.empty_par = Empty()
 
@@ -62,7 +57,7 @@ class TestNodes(unittest.TestCase):
         a = Alias(Parameter(None))
         str(a)
 
-        f = Function(lambda x: x, name='_lambda')
+        f = Function(lambda x: x, name="_lambda")
         str(f)
 
         fb = Fallback((f,))
@@ -78,127 +73,103 @@ class TestNodes(unittest.TestCase):
         self.assertNotEqual(p_1, p_2)
 
     def test_node_get_children_get_parents(self):
-        par_1 = Parameter(3, name='par_1')
-        par_2 = Parameter(2, name='par_2')
+        par_1 = Parameter(3, name="par_1")
+        par_2 = Parameter(2, name="par_2")
         par_lc_1 = par_1 + par_2
         par_lc_2 = par_1 - par_2
 
         for _par in par_1, par_2:
-            self.assertEqual(
-                _par.get_parents(),
-                [par_lc_1, par_lc_2]
-            )
+            self.assertEqual(_par.get_parents(), [par_lc_1, par_lc_2])
         for _par in par_lc_1, par_lc_2:
-            self.assertEqual(
-                _par.get_children(),
-                [par_1, par_2]
-            )
+            self.assertEqual(_par.get_children(), [par_1, par_2])
 
     def test_node_iter_parents(self):
-        par_1 = Parameter(3, name='par_1')
-        par_2 = Parameter(2, name='par_2')
+        par_1 = Parameter(3, name="par_1")
+        par_2 = Parameter(2, name="par_2")
         par_lc_1 = par_1 + par_2
         par_lc_2 = par_1 - par_2
 
         for _par in par_1, par_2:
-            self.assertEqual(
-                [_parent for _parent in _par.iter_parents()],
-                [par_lc_1, par_lc_2]
-            )
+            self.assertEqual([_parent for _parent in _par.iter_parents()], [par_lc_1, par_lc_2])
 
     def test_node_add_child(self):
-        par = Parameter(3, name='par')
+        par = Parameter(3, name="par")
         par.add_child(1)
         par.add_child(2)
 
-        self.assertEqual(
-            [p.value for p in par.get_children()],
-            [1, 2]
-        )
+        self.assertEqual([p.value for p in par.get_children()], [1, 2])
 
     def test_node_add_parent(self):
-        par = Parameter(3, name='par')
-        par_2 = Parameter(2, name='par_2')
+        par = Parameter(3, name="par")
+        par_2 = Parameter(2, name="par_2")
 
         with self.assertRaises(TypeError):
             par.add_parent("notanode")
 
         # Manually adding parents is not allowed:
-        with self.assertRaises(NodeException):
+        with self.assertRaises(ValueError):
             par.add_parent(par_2)
 
         par_2.add_child(par)
         self.assertEqual(par.get_parents(), [par_2])
 
     def test_node_set_children(self):
-        par = Parameter(3, name='par')
-        child_1 = Parameter(1, name='child_1')
-        child_2 = Parameter(2, name='child_2')
+        par = Parameter(3, name="par")
+        child_1 = Parameter(1, name="child_1")
+        child_2 = Parameter(2, name="child_2")
 
         par.set_children([child_1, child_2])
 
-        self.assertEqual(
-            par.get_children(),
-            [child_1, child_2]
-        )
+        self.assertEqual(par.get_children(), [child_1, child_2])
 
     def test_node_remove_child(self):
-        par = Parameter(3, name='par')
-        child_1 = Parameter(1, name='child_1')
-        child_2 = Parameter(2, name='child_2')
+        par = Parameter(3, name="par")
+        child_1 = Parameter(1, name="child_1")
+        child_2 = Parameter(2, name="child_2")
 
         par.set_children([child_1, child_2])
         par.remove_child(child_1)
 
-        self.assertEqual(
-            par.get_children(),
-            [child_2]
-        )
+        self.assertEqual(par.get_children(), [child_2])
 
         with self.assertRaises(TypeError):
             par.remove_child("notanode")
 
     def test_node_remove_parent(self):
-        par = Parameter(3, name='par')
-        parent_1 = Parameter(1, name='parent_1')
-        parent_2 = Parameter(2, name='parent_2')
+        par = Parameter(3, name="par")
+        parent_1 = Parameter(1, name="parent_1")
+        parent_2 = Parameter(2, name="parent_2")
 
         parent_1.add_child(par)
         parent_2.add_child(par)
-        with self.assertRaises(NodeException):
+        with self.assertRaises(ValueError):
             par.remove_parent(parent_1)
-        self.assertEqual(
-            par.get_parents(),
-            [parent_1, parent_2]
-        )
+        self.assertEqual(par.get_parents(), [parent_1, parent_2])
         parent_1.remove_child(par)
-        self.assertEqual(
-            par.get_parents(),
-            [parent_2]
-        )
+        self.assertEqual(par.get_parents(), [parent_2])
 
         with self.assertRaises(TypeError):
             par.remove_parent("notanode")
 
     def test_parameter_replace(self):
-        par = Parameter(3, name='par')
+        par = Parameter(3, name="par")
         selector = Function(
             lambda *args: args[1],
-            name='selector',
+            name="selector",
             parameters=(
-                Parameter('bla', name='first'),
+                Parameter("bla", name="first"),
                 par,
-                Parameter('blup', name='third'),
+                Parameter("blup", name="third"),
             ),
         )
-        context = Parameter(2, name='pre_factor') * selector
+        context = Parameter(2, name="pre_factor") * selector
 
         # store parents and children for comparison
         _children_before = par.get_children()
         _parents_before = par.get_parents()
 
         # replace node
-        par_new = Parameter(7, name='par_new')
+        par_new = Parameter(7, name="par_new")
         par.replace(par_new)
 
         par_new.value = 6
@@ -213,17 +184,17 @@ class TestNodes(unittest.TestCase):
         self.assertEqual(_parents_before, _parents_after)
 
     def test_parameter_replace_literal(self):
-        par = Parameter(3, name='par')
+        par = Parameter(3, name="par")
         selector = Function(
             lambda *args: args[1],
-            name='selector',
+            name="selector",
             parameters=(
-                Parameter('bla', name='first'),
+                Parameter("bla", name="first"),
                 par,
-                Parameter('blup', name='third'),
+                Parameter("blup", name="third"),
             ),
         )
-        context = Parameter(2, name='pre_factor') * selector
+        context = Parameter(2, name="pre_factor") * selector
 
         # replace node
         par.replace(7)
@@ -231,17 +202,17 @@ class TestNodes(unittest.TestCase):
         self.assertEqual(context.value, 14)
 
     def test_function_replace(self):
-        par = Parameter(3, name='par')
+        par = Parameter(3, name="par")
         selector = Function(
             lambda *args: args[1],
-            name='selector',
+            name="selector",
             parameters=(
-                Parameter('bla', name='first'),
+                Parameter("bla", name="first"),
                 par,
-                Parameter('blup', name='third'),
+                Parameter("blup", name="third"),
             ),
         )
-        context = Parameter(2, name='pre_factor') * selector
+        context = Parameter(2, name="pre_factor") * selector
 
         # store parents and children for comparison
         _children_before = selector.get_children()
@@ -249,7 +220,7 @@ class TestNodes(unittest.TestCase):
         _parents_before = selector.get_parents()
 
         # replace node
-        selector_new = Function(lambda *args: args[2], name='selector_new')
+        selector_new = Function(lambda *args: args[2], name="selector_new")
         selector.replace(selector_new, other_children=False)
 
         # retrieve new parents and children for comparison
@@ -261,7 +232,7 @@ class TestNodes(unittest.TestCase):
         self.assertEqual(_parents_before, _parents_after)
         self.assertEqual(_parameters_before, _parameters_after)
 
-        self.assertEqual(selector_new.value, 'blup')
+        self.assertEqual(selector_new.value, "blup")
 
     def test_replace_child(self):
         par_a = Parameter(4)
@@ -269,10 +240,10 @@ class TestNodes(unittest.TestCase):
         par_c = Parameter(6)
         par_a.add_child(par_b)
         self.assertEqual(par_a.get_children(), [par_b])
-        with self.assertRaises(NodeException):
+        with self.assertRaises(ValueError):
             par_a.replace_child(current_child=par_c, new_child=par_b)
         par_a.replace_child(current_child=par_b, new_child=par_c)
-        with self.assertRaises(NodeException):
+        with self.assertRaises(ValueError):
             par_a.replace_child(current_child=par_b, new_child=par_c)
         self.assertEqual(par_a.get_children(), [par_c])
         par_a.replace_child(current_child=par_c, new_child=7)
@@ -298,9 +269,9 @@ class TestNodes(unittest.TestCase):
 
     def test_empty_value(self):
         e = Empty()
-        with self.assertRaises(NodeException):
+        with self.assertRaises(TypeError):
             _ = e.value
-        with self.assertRaises(NodeException):
+        with self.assertRaises(TypeError):
             e.value = 33
 
     # -- Parameter
@@ -315,16 +286,16 @@ class TestNodes(unittest.TestCase):
         self.assertEqual(par.value, 7)
 
     def test_parameter_name(self):
-        par = Parameter(3, name='bla')
-        self.assertEqual(par.name, 'bla')
+        par = Parameter(3, name="bla")
+        self.assertEqual(par.name, "bla")
 
     def test_parameter_invalid_name_raise(self):
-        with self.assertRaises(NodeException):
-            par = Parameter(3, name='2bla')
+        with self.assertRaises(ValueError):
+            par = Parameter(3, name="2bla")
 
     def test_parameter_reserved_name_raise(self):
         for _rn in NodeBase.RESERVED_PARAMETER_NAMES:
-            with self.assertRaises(NodeException):
+            with self.assertRaises(ValueError):
                 par = Parameter(3, name=_rn)
 
     def test_tuple_iter_raise(self):
@@ -337,43 +308,31 @@ class TestNodes(unittest.TestCase):
         par_b = Parameter(7)
         for _op_name, (_op, _) in _OPERATORS.items():
             par_expr = _op(par_a, par_b)
-            self.assertEqual(
-                par_expr.value,
-                _op(par_a.value, par_b.value)
-            )
+            self.assertEqual(par_expr.value, _op(par_a.value, par_b.value))
 
     def test_parameter_binary_operation_with_literal(self):
         par_a = Parameter(3)
         for _op_name, (_op, _) in _OPERATORS.items():
             par_expr = _op(par_a, 7)
-            self.assertEqual(
-                par_expr.value,
-                _op(par_a.value, 7)
-            )
+            self.assertEqual(par_expr.value, _op(par_a.value, 7))
             # reversed order
             par_expr = _op(7, par_a)
-            self.assertEqual(
-                par_expr.value,
-                _op(7, par_a.value)
-            )
+            self.assertEqual(par_expr.value, _op(7, par_a.value))
 
     def test_parameter_unary_operation(self):
         par = Parameter(3)
 
-        self.assertEqual(
-            (+par).value, par.value)
-        self.assertEqual(
-            (-par).value, -(par.value))
-        self.assertEqual(
-            (~par).value, ~(par.value))
+        self.assertEqual((+par).value, par.value)
+        self.assertEqual((-par).value, -(par.value))
+        self.assertEqual((~par).value, ~(par.value))
 
     # -- Alias
 
     def test_alias_value(self):
         par = Parameter(3)
-        alias = Alias(par, name='alias')
+        alias = Alias(par, name="alias")
         self.assertEqual(alias.value, par.value)
-        with self.assertRaises(NodeException):
+        with self.assertRaises(TypeError):
             alias.value = 5
 
     def test_multiple_alias_value(self):
@@ -383,7 +342,7 @@ class TestNodes(unittest.TestCase):
 
     def test_alias_ref(self):
         par = Parameter(3)
-        alias = Alias(par, name='alias')
+        alias = Alias(par, name="alias")
         self.assertEqual(alias.ref, par)
 
     # -- Function
@@ -393,7 +352,7 @@ class TestNodes(unittest.TestCase):
         par_b = Parameter(7)
 
         def func(a, b):
-            return a*10 + b
+            return a * 10 + b
 
         func_a_b = Function(func, parameters=(par_a, par_b))
 
@@ -410,7 +369,7 @@ class TestNodes(unittest.TestCase):
             func(par_a.value, par_b.value),
         )
 
-        with self.assertRaises(NodeException):
+        with self.assertRaises(TypeError):
             func_a_b.value = 5
 
     def test_function_value_update_frozen(self):
@@ -418,7 +377,7 @@ class TestNodes(unittest.TestCase):
         par_b = Parameter(7)
 
         def func(a, b):
-            return a*10 + b
+            return a * 10 + b
 
         func_a_b = Function(func, parameters=(par_a, par_b))
 
@@ -446,11 +405,7 @@ class TestNodes(unittest.TestCase):
         par_a = Parameter(3)
         par_b = Parameter(7)
 
-        func_a_b = Function(
-            lambda a, b: a*10 + b,
-            name='_lambda',
-            parameters=(par_a, par_b)
-        )
+        func_a_b = Function(lambda a, b: a * 10 + b, name="_lambda", parameters=(par_a, par_b))
 
         self.assertEqual(
             func_a_b.value,
@@ -462,7 +417,7 @@ class TestNodes(unittest.TestCase):
         par_b = Parameter(7)
 
         def func(a, b):
-            return a*10 + b
+            return a * 10 + b
 
         func_a_b = Function(func, parameters=(par_a, par_b))
 
@@ -477,7 +432,7 @@ class TestNodes(unittest.TestCase):
 
     def test_function_auto_parameters(self):
         def func(a, b):
-            return a*10 + b
+            return a * 10 + b
 
         func_a_b = Function(func)
 
@@ -494,7 +449,7 @@ class TestNodes(unittest.TestCase):
 
     def test_function_auto_parameters_add_one_at_a_time(self):
         def func(a, b):
-            return a*10 + b
+            return a * 10 + b
 
         func_a_b = Function(func)
 
@@ -516,10 +471,7 @@ class TestNodes(unittest.TestCase):
         par_a = Parameter(14)
         par_b = Parameter(2)
 
-        div_a_b = Fallback(
-            (par_a / par_b, 'DIV0'),
-            exception_type=ZeroDivisionError
-        )
+        div_a_b = Fallback((par_a / par_b, "DIV0"), exception_type=ZeroDivisionError)
 
         # no exception yet
         self.assertEqual(
@@ -533,26 +485,20 @@ class TestNodes(unittest.TestCase):
         # exception matches type -> fallback
         self.assertEqual(
             div_a_b.value,
-            'DIV0',
+            "DIV0",
         )
 
         # exception does not match type -> raise
         with self.assertRaises(ZeroDivisionError):
-            Fallback(
-                (par_a / par_b, 'DIV0'),
-                exception_type=TypeError
-            ).value
+            Fallback((par_a / par_b, "DIV0"), exception_type=TypeError).value
 
     def test_fallback_no_good_alternative(self):
         par_a = Parameter(14)
 
-        div_a_b = Fallback(
-            (par_a / 0, 2 * par_a / 0),
-            exception_type=ZeroDivisionError
-        )
+        div_a_b = Fallback((par_a / 0, 2 * par_a / 0), exception_type=ZeroDivisionError)
 
         # no exception yet
-        with self.assertRaises(FallbackError):
+        with self.assertRaises(RuntimeError):
             div_a_b.value,
 
     # -- Tuple
@@ -587,17 +533,11 @@ class TestNodes(unittest.TestCase):
 
     def test_tuple_iter(self):
         tuple_a = Tuple((14, 2))
-        self.assertEqual(
-            tuple_a.nodes,
-            [node for node in tuple_a]
-        )
+        self.assertEqual(tuple_a.nodes, [node for node in tuple_a])
 
     def test_tuple_iter_values(self):
         tuple_a = Tuple((14, 2))
-        self.assertEqual(
-            tuple_a.value,
-            tuple([value for value in tuple_a.iter_values()])
-        )
+        self.assertEqual(tuple_a.value, tuple([value for value in tuple_a.iter_values()]))
 
     # -- Array
 
@@ -619,13 +559,10 @@ class TestNodes(unittest.TestCase):
 
     def test_array_iter_values(self):
         array_a = Array(self.array_content)
-        self.assertTrue(np.all(
-            array_a.value == np.array([value for value in array_a.iter_values()])
-        ))
+        self.assertTrue(np.all(array_a.value == np.array([value for value in array_a.iter_values()])))
 
 
 class TestNodeVisitors(unittest.TestCase):
-
     def setUp(self):
         self.root = RootNode()
         self.empty = Empty(name="empty")
@@ -647,7 +584,6 @@ class TestNodeVisitors(unittest.TestCase):
     # -- NodeCycleChecker
 
     def test_node_cycle_checker(self):
-
         NodeCycleChecker(self.par_a).run()
 
         self.par_b.set_children([self.par_a])
@@ -657,12 +593,11 @@ class TestNodeVisitors(unittest.TestCase):
 
 
 class TestNexus(unittest.TestCase):
-
     def setUp(self):
         self._nexus = Nexus()
 
     def test_add_get(self):
-        par = Parameter('my_value')
+        par = Parameter("my_value")
         self._nexus.add(par)
 
         self.assertIs(
@@ -672,87 +607,87 @@ class TestNexus(unittest.TestCase):
 
     def test_add_get_inexistent(self):
         self.assertIs(
-            self._nexus.get('bogus_name'),
+            self._nexus.get("bogus_name"),
             None,
         )
 
     def test_add_get_explicit_name(self):
-        par = Parameter('my_value', name='par')
+        par = Parameter("my_value", name="par")
         self._nexus.add(par)
 
         self.assertIs(
-            self._nexus.get('par'),
+            self._nexus.get("par"),
             par,
         )
 
     def test_add_existing_fail(self):
-        par = Parameter('my_value')
+        par = Parameter("my_value")
         self._nexus.add(par)
 
-        with self.assertRaises(NexusError):
-            self._nexus.add(par, existing_behavior='fail')
+        with self.assertRaises(ValueError):
+            self._nexus.add(par, existing_behavior="fail")
 
     def test_add_existing_replace(self):
-        par_orig = Parameter('my_original_value', name='par')
+        par_orig = Parameter("my_original_value", name="par")
         self._nexus.add(par_orig)
 
-        par_new = Parameter('my_new_value', name='par')
-        self._nexus.add(par_new, existing_behavior='replace')
+        par_new = Parameter("my_new_value", name="par")
+        self._nexus.add(par_new, existing_behavior="replace")
 
         self.assertIs(
-            self._nexus.get('par'),
+            self._nexus.get("par"),
             par_new,
         )
 
     def test_add_existing_replace_alias(self):
-        par_orig = Parameter('my_original_value', name='par')
+        par_orig = Parameter("my_original_value", name="par")
         self._nexus.add(par_orig)
-        alias_orig = Alias(par_orig, name='alias')
+        alias_orig = Alias(par_orig, name="alias")
         self._nexus.add(alias_orig)
 
-        par_new = Parameter('my_new_value', name='par')
-        with self.assertRaises(NexusError):
-            self._nexus.add(par_new, existing_behavior='replace_if_alias')
+        par_new = Parameter("my_new_value", name="par")
+        with self.assertRaises(ValueError):
+            self._nexus.add(par_new, existing_behavior="replace_if_alias")
         self.assertIs(
-            self._nexus.get('par'),
+            self._nexus.get("par"),
             par_orig,
         )
-        alias_new = Parameter('my_new_value', name='alias')
-        self._nexus.add(alias_new, existing_behavior='replace_if_alias')
+        alias_new = Parameter("my_new_value", name="alias")
+        self._nexus.add(alias_new, existing_behavior="replace_if_alias")
         self.assertIs(
-            self._nexus.get('alias'),
+            self._nexus.get("alias"),
             alias_new,
         )
 
     def test_add_existing_replace_empty(self):
-        par_orig = Parameter('my_original_value', name='par')
+        par_orig = Parameter("my_original_value", name="par")
         self._nexus.add(par_orig)
-        empty_orig = Empty('empty')
+        empty_orig = Empty("empty")
         self._nexus.add(empty_orig)
 
-        par_new = Parameter('my_new_value', name='par')
-        with self.assertRaises(NexusError):
-            self._nexus.add(par_new, existing_behavior='replace_if_empty')
+        par_new = Parameter("my_new_value", name="par")
+        with self.assertRaises(ValueError):
+            self._nexus.add(par_new, existing_behavior="replace_if_empty")
         self.assertIs(
-            self._nexus.get('par'),
+            self._nexus.get("par"),
             par_orig,
         )
-        empty_new = Parameter('my_new_value', name='empty')
-        self._nexus.add(empty_new, existing_behavior='replace_if_empty')
+        empty_new = Parameter("my_new_value", name="empty")
+        self._nexus.add(empty_new, existing_behavior="replace_if_empty")
         self.assertIs(
-            self._nexus.get('empty'),
+            self._nexus.get("empty"),
             empty_new,
         )
 
     def test_add_existing_ignore(self):
-        par_orig = Parameter('my_original_value', name='par')
+        par_orig = Parameter("my_original_value", name="par")
         self._nexus.add(par_orig)
 
-        par_new = Parameter('my_new_value', name='par')
-        self._nexus.add(par_new, existing_behavior='ignore')
+        par_new = Parameter("my_new_value", name="par")
+        self._nexus.add(par_new, existing_behavior="ignore")
 
         self.assertIs(
-            self._nexus.get('par'),
+            self._nexus.get("par"),
             par_orig,
         )
 
@@ -760,27 +695,27 @@ class TestNexus(unittest.TestCase):
         par = Parameter(2)
         self._nexus.add(par)
         with self.assertRaises(ValueError):
-            self._nexus.add(par, existing_behavior='bogus')
+            self._nexus.add(par, existing_behavior="bogus")
 
     def test_add_expression_compare_value(self):
         a = Parameter(3)
         b = Parameter(5)
 
-        expr = (a + b)
-        expr.name = 'sum'
+        expr = a + b
+        expr.name = "sum"
 
         self._nexus.add(a)
         self._nexus.add(b)
         self._nexus.add(expr)
 
-        self.assertEqual(self._nexus.get('sum').value, 8)
+        self.assertEqual(self._nexus.get("sum").value, 8)
 
     def test_add_expression_test_dependents_added(self):
         a = Parameter(3)
         b = Parameter(5)
 
         expr = (a - b) / (a + b)
-        expr.name = 'asymm'
+        expr.name = "asymm"
 
         expr_value = (a.value - b.value) / (a.value + b.value)
 
@@ -793,67 +728,50 @@ class TestNexus(unittest.TestCase):
         def my_func(a, b=2):
             return 2 * a + b
 
-        func_node = self._nexus.add_function(
-            func=my_func
-        )
+        func_node = self._nexus.add_function(func=my_func)
 
         # check if name is as in signature
-        self.assertEqual(func_node.name, 'my_func')
+        self.assertEqual(func_node.name, "my_func")
 
         # check if parameter names are as in signature
-        self.assertEqual(
-            [p.name for p in func_node.parameters],
-            ['a', 'b']
-        )
+        self.assertEqual([p.name for p in func_node.parameters], ["a", "b"])
 
-        self.assertTrue(isinstance(self._nexus.get('a'), Empty))
-        self.assertTrue(isinstance(self._nexus.get('b'), Parameter))
-        self.assertEqual(self._nexus.get('b').value, 2)
+        self.assertTrue(isinstance(self._nexus.get("a"), Empty))
+        self.assertTrue(isinstance(self._nexus.get("b"), Parameter))
+        self.assertEqual(self._nexus.get("b").value, 2)
 
     def test_add_function_existing_parameters(self):
-
-        a = self._nexus.add(Parameter(4, name='a'))
-        b = self._nexus.add(Parameter(5, name='b'))
+        a = self._nexus.add(Parameter(4, name="a"))
+        b = self._nexus.add(Parameter(5, name="b"))
 
         def my_func(a, b):
             return 2 * a + b
 
-        func_node = self._nexus.add_function(
-            func=my_func
-        )
+        func_node = self._nexus.add_function(func=my_func)
 
         # check if name is as in signature
-        self.assertEqual(func_node.name, 'my_func')
+        self.assertEqual(func_node.name, "my_func")
 
         # check if parameter values correspond to existing parameters
-        self.assertEqual(
-            [p.value for p in func_node.parameters],
-            [a.value, b.value]
-        )
+        self.assertEqual([p.value for p in func_node.parameters], [a.value, b.value])
         # check function value
         self.assertEqual(func_node.value, my_func(a.value, b.value))
 
     def test_add_function_existing_parameter_with_default(self):
-
-        a = self._nexus.add(Parameter(4, name='a'))
-        b = self._nexus.add(Parameter(9, name='b'))
+        a = self._nexus.add(Parameter(4, name="a"))
+        b = self._nexus.add(Parameter(9, name="b"))
 
         def my_func(a=4, b=200):
             return 2 * a + b
 
         with self.assertWarns(UserWarning) as w:
-            func_node = self._nexus.add_function(
-                func=my_func
-            )
+            func_node = self._nexus.add_function(func=my_func)
 
         # check if parameter values correspond to existing parameters
-        self.assertEqual(
-            [p.value for p in func_node.parameters],
-            [a.value, b.value]
-        )
+        self.assertEqual([p.value for p in func_node.parameters], [a.value, b.value])
 
-        self.assertIn('Ignoring default value', w.warning.args[0])
-        self.assertIn('conflicting value', w.warning.args[0])
+        self.assertIn("Ignoring default value", w.warning.args[0])
+        self.assertIn("conflicting value", w.warning.args[0])
 
     def test_add_function_custom_name(self):
         def my_func(a, b):
@@ -861,38 +779,32 @@ class TestNexus(unittest.TestCase):
 
         func_node = self._nexus.add_function(
             func=my_func,
-            func_name='new_func_name',
+            func_name="new_func_name",
         )
 
         # check if name is as in signature
-        self.assertEqual(func_node.name, 'new_func_name')
+        self.assertEqual(func_node.name, "new_func_name")
 
     def test_add_function_custom_par_names(self):
-        x = self._nexus.add(Parameter(7, name='x'))
-        y = self._nexus.add(Parameter(8, name='y'))
+        x = self._nexus.add(Parameter(7, name="x"))
+        y = self._nexus.add(Parameter(8, name="y"))
 
         def my_func(a, b):
             return 2 * a + b
 
-        func_node = self._nexus.add_function(
-            func=my_func,
-            par_names=['x', 'y']
-        )
+        func_node = self._nexus.add_function(func=my_func, par_names=["x", "y"])
 
         # check function value
         self.assertEqual(func_node.value, my_func(x.value, y.value))
 
     def test_add_function_varargs(self):
-        x = self._nexus.add(Parameter(7, name='x'))
-        y = self._nexus.add(Parameter(8, name='y'))
+        x = self._nexus.add(Parameter(7, name="x"))
+        y = self._nexus.add(Parameter(8, name="y"))
 
         def my_func(*args):
             return sum(args)
 
-        func_node = self._nexus.add_function(
-            func=my_func,
-            par_names=['x', 'y']
-        )
+        func_node = self._nexus.add_function(func=my_func, par_names=["x", "y"])
 
         # check function value
         self.assertEqual(func_node.value, my_func(x.value, y.value))
@@ -912,7 +824,7 @@ class TestNexus(unittest.TestCase):
             return a * b
 
         func_node_1 = self._nexus.add_function(my_func_1)
-        with self.assertRaises(NodeException):
+        with self.assertRaises(TypeError):
             _ = func_node_1.value
         func_node_2 = self._nexus.add_function(my_func_2)
         # Parameters of second function are reversed:
@@ -944,16 +856,13 @@ class TestNexus(unittest.TestCase):
         def my_rec_func_2(my_rec_func):
             return 2 * my_rec_func
 
-        func_node = self._nexus.add_function(
-            func=my_rec_func,
-            par_names=['my_rec_func_2']
-        )
+        func_node = self._nexus.add_function(func=my_rec_func, par_names=["my_rec_func_2"])
 
         # adding second one triggers cycle detection
         with self.assertRaises(ValueError):
             self._nexus.add_function(
                 func=my_rec_func_2,
-                existing_behavior='replace',
+                existing_behavior="replace",
             )
             _ = func_node.value
 
@@ -961,13 +870,9 @@ class TestNexus(unittest.TestCase):
         def test_func(x=3):
             return 2 * x
 
-        func_node = self._nexus.add_function(
-            func=test_func
-        )
+        func_node = self._nexus.add_function(func=test_func)
 
-        y = self._nexus.add(
-            Parameter(4, name='y')
-        )
+        y = self._nexus.add(Parameter(4, name="y"))
 
         self.assertEqual(func_node.value, 6)
         self.assertEqual(func_node.stale, False)
@@ -976,7 +881,7 @@ class TestNexus(unittest.TestCase):
         y.value = 8
         self.assertEqual(func_node.stale, False)
 
-        self._nexus.add_dependency('test_func', depends_on='y')
+        self._nexus.add_dependency("test_func", depends_on="y")
 
         # now 'test_func' depends on 'y' and should go stale
         y.value = 23
@@ -984,9 +889,9 @@ class TestNexus(unittest.TestCase):
         self.assertEqual(func_node.value, 6)
 
         with self.assertRaises(ValueError):
-            self._nexus.add_dependency('DEADBEEF', depends_on='y')
+            self._nexus.add_dependency("DEADBEEF", depends_on="y")
         with self.assertRaises(ValueError):
-            self._nexus.add_dependency('y', depends_on=['a', 'b'])
+            self._nexus.add_dependency("y", depends_on=["a", "b"])
 
     def test_get_value_dict(self):
         self._nexus.add(Parameter(1, name="a"))
