@@ -1,44 +1,39 @@
+# flake8: noqa F401 (imported but unused)
 import abc
 import unittest
+
 import numpy as np
 import six
-
 from scipy import stats
 
-from kafe2.core.minimizers import AVAILABLE_MINIMIZERS
-from kafe2.core.fitters import NexusFitterException
-
 from kafe2.config import kc
-
-from kafe2.fit import HistFit, HistContainer
-from kafe2.fit.histogram.fit import HistFitException
-from kafe2.fit.histogram.model import HistModelFunctionException, HistParametricModelException
+from kafe2.core.minimizers import AVAILABLE_MINIMIZERS
+from kafe2.fit import HistContainer, HistFit
 from kafe2.fit.histogram.cost import HistCostFunction_NegLogLikelihood
-
 from kafe2.test.fit.test_fit import AbstractTestFit
 
 
 def simple_chi2(data, model):
-    return np.sum((data - model)**2)
+    return np.sum((data - model) ** 2)
 
 
-def hist_model_density(x, mu=14., sigma=3.):
+def hist_model_density(x, mu=14.0, sigma=3.0):
     return stats.norm(mu, sigma).pdf(x)
 
-def hist_model_density_antideriv(x, mu=14., sigma=3.):
+
+def hist_model_density_antideriv(x, mu=14.0, sigma=3.0):
     return stats.norm(mu, sigma).cdf(x)
 
 
-
 class TestHistFitBasicInterface(AbstractTestFit, unittest.TestCase):
-
-    MINIMIZER = 'scipy'
+    MINIMIZER = "scipy"
 
     def setUp(self):
         self._ref_n_bins = 11
         self._ref_n_bin_range = (-3, 25)
-        self._ref_bin_edges = np.linspace(self._ref_n_bin_range[0], self._ref_n_bin_range[1], self._ref_n_bins+1)
+        self._ref_bin_edges = np.linspace(self._ref_n_bin_range[0], self._ref_n_bin_range[1], self._ref_n_bins + 1)
 
+        # fmt: off
         self._ref_entries = np.array([11.47195963,   9.96715403,  19.90275216,  13.65225802,
                                       18.52670233,  17.79707059,  11.5441954 ,  18.42331074,
                                       13.3808496 ,  18.40632518,  13.21694177,  15.34569261,
@@ -64,26 +59,23 @@ class TestHistFitBasicInterface(AbstractTestFit, unittest.TestCase):
                                        4.08280244,  13.1043861 ,  14.62321312,  14.85894591,
                                       14.89235398,  10.60967181,  15.22310211,  10.77853626,
                                       14.56823312,  14.46093346,  13.34031129,  14.14203599])
+        # fmt: on
 
-        self._ref_hist_cont = HistContainer(
-            self._ref_n_bins, self._ref_n_bin_range, bin_edges=None, fill_data=self._ref_entries)
-
+        self._ref_hist_cont = HistContainer(self._ref_n_bins, self._ref_n_bin_range, bin_edges=None, fill_data=self._ref_entries)
+        self._ref_hist_numpy = np.histogram(self._ref_entries, bins=self._ref_n_bins, range=self._ref_n_bin_range)
 
         # reference initial values
-        self._ref_initial_pars = np.array([14., 3.])
+        self._ref_initial_pars = np.array([14.0, 3.0])
         self._ref_initial_model = (
-            hist_model_density_antideriv(self._ref_bin_edges[1:], *self._ref_initial_pars) -
-            hist_model_density_antideriv(self._ref_bin_edges[:-1], *self._ref_initial_pars)) * len(self._ref_entries)
+            hist_model_density_antideriv(self._ref_bin_edges[1:], *self._ref_initial_pars)
+            - hist_model_density_antideriv(self._ref_bin_edges[:-1], *self._ref_initial_pars)
+        ) * len(self._ref_entries)
 
         # fit data
-        self._ref_data, _ = np.histogram(
-            self._ref_entries,
-            bins=self._ref_n_bins,
-            range=self._ref_n_bin_range)
+        self._ref_data, _ = np.histogram(self._ref_entries, bins=self._ref_n_bins, range=self._ref_n_bin_range)
 
         # pre-fit cost value
-        self._ref_initial_cost_nll = \
-            -2*np.sum(stats.poisson.logpmf(self._ref_data, self._ref_initial_model))
+        self._ref_initial_cost_nll = -2 * np.sum(stats.poisson.logpmf(self._ref_data, self._ref_initial_model))
         self._ref_initial_cost_chi2 = simple_chi2(self._ref_data, self._ref_initial_model)
 
         # reference fit result values
@@ -91,44 +83,47 @@ class TestHistFitBasicInterface(AbstractTestFit, unittest.TestCase):
         self._nominal_fit_result_pars_chi2 = np.array([13.82779489, 2.62746457])
 
         self._nominal_fit_result_model_nll = (
-            hist_model_density_antideriv(self._ref_bin_edges[1:], *self._nominal_fit_result_pars_nll) -
-            hist_model_density_antideriv(self._ref_bin_edges[:-1], *self._nominal_fit_result_pars_nll)) * len(self._ref_entries)
+            hist_model_density_antideriv(self._ref_bin_edges[1:], *self._nominal_fit_result_pars_nll)
+            - hist_model_density_antideriv(self._ref_bin_edges[:-1], *self._nominal_fit_result_pars_nll)
+        ) * len(self._ref_entries)
         self._nominal_fit_result_model_chi2 = (
-            hist_model_density_antideriv(self._ref_bin_edges[1:], *self._nominal_fit_result_pars_chi2) -
-            hist_model_density_antideriv(self._ref_bin_edges[:-1], *self._nominal_fit_result_pars_chi2)) * len(self._ref_entries)
+            hist_model_density_antideriv(self._ref_bin_edges[1:], *self._nominal_fit_result_pars_chi2)
+            - hist_model_density_antideriv(self._ref_bin_edges[:-1], *self._nominal_fit_result_pars_chi2)
+        ) * len(self._ref_entries)
 
-        self._nominal_fit_result_cost_nll = \
-            -2*np.sum(stats.poisson.logpmf(self._ref_data, self._nominal_fit_result_model_nll))
-        self._nominal_fit_result_cost_chi2 = simple_chi2(
-            self._ref_data, self._nominal_fit_result_model_chi2)
+        self._nominal_fit_result_cost_nll = -2 * np.sum(stats.poisson.logpmf(self._ref_data, self._nominal_fit_result_model_nll))
+        self._nominal_fit_result_cost_chi2 = simple_chi2(self._ref_data, self._nominal_fit_result_model_chi2)
 
         # helper dict with all reference property values
         self._ref_prop_dict = dict(
             did_fit=False,
             model_count=1,
-
             parameter_values=self._ref_initial_pars,
-            parameter_names=('mu', 'sigma'),
-
+            parameter_names=("mu", "sigma"),
             data=self._ref_data,
             model=self._ref_initial_model,
         )
 
-    def _get_fit(self, model_density_function=None, bin_evaluation="numerical", cost_function=None):
-        '''convenience'''
+    def _get_fit(
+        self,
+        model_density_function=None,
+        bin_evaluation="numerical",
+        cost_function=None,
+        numpy_histogram=False,
+    ):
+        """convenience"""
 
         model_density_function = model_density_function or hist_model_density
 
         # TODO: fix default
-        cost_function = cost_function or HistCostFunction_NegLogLikelihood(
-            data_point_distribution='poisson')
+        cost_function = cost_function or HistCostFunction_NegLogLikelihood(data_point_distribution="poisson")
 
         _fit = HistFit(
-            data=self._ref_hist_cont,
+            data=self._ref_hist_numpy if numpy_histogram else self._ref_hist_cont,
             model_function=model_density_function,
             bin_evaluation=bin_evaluation,
             cost_function=cost_function,
-            minimizer=self.MINIMIZER
+            minimizer=self.MINIMIZER,
         )
         _fit.add_error(1.0)  # only considered for chi2
 
@@ -139,10 +134,9 @@ class TestHistFitBasicInterface(AbstractTestFit, unittest.TestCase):
             # numeric integration takes too long for testing
             #'default': \
             #    self._get_fit(),
-            'explicit_chi2': \
-                self._get_fit(cost_function=simple_chi2, bin_evaluation=hist_model_density_antideriv),
-            'model_with_antiderivative': \
-                self._get_fit(bin_evaluation=hist_model_density_antideriv),
+            "explicit_chi2": self._get_fit(cost_function=simple_chi2, bin_evaluation=hist_model_density_antideriv),
+            "model_with_antiderivative": self._get_fit(bin_evaluation=hist_model_density_antideriv),
+            "numpy_histogram": self._get_fit(numpy_histogram=True),
         }
 
     def test_initial_state(self):
@@ -151,14 +145,14 @@ class TestHistFitBasicInterface(AbstractTestFit, unittest.TestCase):
                 self._ref_prop_dict,
                 cost_function_value=np.float64(self._ref_initial_cost_nll),  # TODO: fix type
             ),
-            fit_names=['default', 'model_with_antiderivative']
+            fit_names=["default", "model_with_antiderivative"],
         )
         self.run_test_for_all_fits(
             dict(
                 self._ref_prop_dict,
                 cost_function_value=np.float64(self._ref_initial_cost_chi2),  # TODO: fix type
             ),
-            fit_names=['explicit_chi2']
+            fit_names=["explicit_chi2"],
         )
 
     def test_fit_results(self):
@@ -170,9 +164,9 @@ class TestHistFitBasicInterface(AbstractTestFit, unittest.TestCase):
                 did_fit=True,
                 cost_function_value=np.float64(self._nominal_fit_result_cost_nll),
             ),
-            fit_names=['default', 'model_with_antiderivative'],
+            fit_names=["default", "model_with_antiderivative"],
             call_before_fit=lambda f: f.do_fit(),
-            rtol=1e-2
+            rtol=1e-2,
         )
         self.run_test_for_all_fits(
             dict(
@@ -182,14 +176,15 @@ class TestHistFitBasicInterface(AbstractTestFit, unittest.TestCase):
                 did_fit=True,
                 cost_function_value=np.float64(self._nominal_fit_result_cost_chi2),
             ),
-            fit_names=['explicit_chi2'],
+            fit_names=["explicit_chi2"],
             call_before_fit=lambda f: f.do_fit(),
-            rtol=1e-2
+            rtol=1e-2,
         )
 
     def test_update_data(self):
         _fit = self._get_fit(bin_evaluation=hist_model_density_antideriv)
 
+        # fmt: off
         _new_entries = np.array([
             19.424357258680693, 19.759361803397155, 18.364336396273362, 18.36464562195573,
             21.12001399388072, 18.08232152646234, 20.881797998050466, 19.799071480564336,
@@ -215,25 +210,18 @@ class TestHistFitBasicInterface(AbstractTestFit, unittest.TestCase):
             18.917354464336892, 18.349803731030892, 21.32702043081207, 22.410955706069743,
             20.972404800516973, 19.615870251101295, 19.013627387925588, 19.54487437668081,
             20.538542465210206, 18.626198427902466, 20.221745437611307, 19.064952809088076])
+        # fmt: on
 
-        _fit.data = HistContainer(
-            8,
-            (17, 23),
-            fill_data=_new_entries
-        )
+        _fit.data = HistContainer(8, (17, 23), fill_data=_new_entries)
         _fit.add_error(err_val=1.0)
 
-        _ref_data, _ = np.histogram(
-            _new_entries,
-            bins=8,
-            range=(17, 23)
-        )
+        _ref_data, _ = np.histogram(_new_entries, bins=8, range=(17, 23))
 
         self._assert_fit_properties(
             _fit,
             dict(
                 data=_ref_data,
-            )
+            ),
         )
 
         _fit.do_fit()
@@ -242,94 +230,98 @@ class TestHistFitBasicInterface(AbstractTestFit, unittest.TestCase):
             _fit,
             dict(
                 data=_ref_data,
-                parameter_values=np.array([19.83815938,  1.1729322]),
+                parameter_values=np.array([19.83815938, 1.1729322]),
             ),
-            rtol=1e-2
+            rtol=1e-2,
         )
 
     def test_reserved_parameter_names_raise(self):
         def dummy_model(x, data):
             pass
 
-        with self.assertRaises(HistFitException) as _exc:
-            HistFit(data=self._ref_hist_cont,
-                    model_function=dummy_model,
-                    minimizer=self.MINIMIZER)
+        with self.assertRaises(ValueError) as _exc:
+            HistFit(data=self._ref_hist_cont, model_function=dummy_model, minimizer=self.MINIMIZER)
 
-        self.assertIn('reserved', _exc.exception.args[0])
-        self.assertIn('data', _exc.exception.args[0])
+        self.assertIn("reserved", _exc.exception.args[0])
+        self.assertIn("data", _exc.exception.args[0])
 
     def test_model_no_pars_raise(self):
         def dummy_model():
             pass
 
-        with self.assertRaises(HistModelFunctionException) as _exc:
-            HistFit(data=self._ref_hist_cont,
-                    model_function=dummy_model,
-                    bin_evaluation=dummy_model,
-                    minimizer=self.MINIMIZER)
+        with self.assertRaises(ValueError) as _exc:
+            HistFit(
+                data=self._ref_hist_cont,
+                model_function=dummy_model,
+                bin_evaluation=dummy_model,
+                minimizer=self.MINIMIZER,
+            )
 
-        self.assertIn(
-            "needs at least one parameter",
-            _exc.exception.args[0])
+        self.assertIn("needs at least one parameter", _exc.exception.args[0])
 
     def test_model_no_pars_beside_x_raise(self):
         def dummy_model(x):
             pass
 
-        with self.assertRaises(HistModelFunctionException) as _exc:
-            HistFit(data=self._ref_hist_cont,
-                    model_function=dummy_model,
-                    bin_evaluation=dummy_model,
-                    minimizer=self.MINIMIZER)
+        with self.assertRaises(ValueError) as _exc:
+            HistFit(
+                data=self._ref_hist_cont,
+                model_function=dummy_model,
+                bin_evaluation=dummy_model,
+                minimizer=self.MINIMIZER,
+            )
 
-        self.assertIn(
-            "needs at least one parameter besides",
-            _exc.exception.args[0])
+        self.assertIn("needs at least one parameter besides", _exc.exception.args[0])
 
     def test_model_varargs_raise(self):
         # TODO: raise even without 'par'
         def dummy_model(x, par, *varargs):
             pass
 
-        with self.assertRaises(HistModelFunctionException) as _exc:
-            HistFit(data=self._ref_hist_cont,
-                    model_function=dummy_model,
-                    bin_evaluation=dummy_model,
-                    minimizer=self.MINIMIZER)
+        with self.assertRaises(ValueError) as _exc:
+            HistFit(
+                data=self._ref_hist_cont,
+                model_function=dummy_model,
+                bin_evaluation=dummy_model,
+                minimizer=self.MINIMIZER,
+            )
 
-        self.assertIn('variable', _exc.exception.args[0])
-        self.assertIn('varargs', _exc.exception.args[0])
+        self.assertIn("variable", _exc.exception.args[0])
+        self.assertIn("varargs", _exc.exception.args[0])
 
     def test_model_varkwargs_raise(self):
         # TODO: raise even without 'par'
         def dummy_model(x, par, **varkwargs):
             pass
 
-        with self.assertRaises(HistModelFunctionException) as _exc:
-            HistFit(data=self._ref_hist_cont,
-                    model_function=dummy_model,
-                    bin_evaluation=dummy_model,
-                    minimizer=self.MINIMIZER)
+        with self.assertRaises(ValueError) as _exc:
+            HistFit(
+                data=self._ref_hist_cont,
+                model_function=dummy_model,
+                bin_evaluation=dummy_model,
+                minimizer=self.MINIMIZER,
+            )
 
-        self.assertIn('variable', _exc.exception.args[0])
-        self.assertIn('varkwargs', _exc.exception.args[0])
+        self.assertIn("variable", _exc.exception.args[0])
+        self.assertIn("varkwargs", _exc.exception.args[0])
 
     def test_model_varargs_varkwargs_raise(self):
         # TODO: raise even without 'par'
         def dummy_model(x, par, *varargs, **varkwargs):
             pass
 
-        with self.assertRaises(HistModelFunctionException) as _exc:
-            HistFit(data=self._ref_hist_cont,
-                    model_function=dummy_model,
-                    bin_evaluation=dummy_model,
-                    minimizer=self.MINIMIZER)
+        with self.assertRaises(ValueError) as _exc:
+            HistFit(
+                data=self._ref_hist_cont,
+                model_function=dummy_model,
+                bin_evaluation=dummy_model,
+                minimizer=self.MINIMIZER,
+            )
 
-        self.assertIn('variable', _exc.exception.args[0])
-        self.assertIn('varargs', _exc.exception.args[0])
+        self.assertIn("variable", _exc.exception.args[0])
+        self.assertIn("varargs", _exc.exception.args[0])
         # TODO: enable when implemented
-        #self.assertIn('varkwargs', _exc.exception.args[0])
+        # self.assertIn('varkwargs', _exc.exception.args[0])
 
     def test_model_and_antiderivative_different_signatures_raise(self):
         def dummy_model(x, mu, sigma):
@@ -339,23 +331,27 @@ class TestHistFitBasicInterface(AbstractTestFit, unittest.TestCase):
             pass
 
         with self.assertRaises(ValueError) as _exc:
-            HistFit(data=self._ref_hist_cont,
-                    model_function=dummy_model,
-                    bin_evaluation=dummy_model_antiderivative,
-                    minimizer=self.MINIMIZER)
+            HistFit(
+                data=self._ref_hist_cont,
+                model_function=dummy_model,
+                bin_evaluation=dummy_model_antiderivative,
+                minimizer=self.MINIMIZER,
+            )
 
     def test_model_and_antiderivative_no_defaults(self):
         def legendre_grade_2(x, a=1, b=2, c=3):
-            return a + b * x + c * 0.5 * (3 * x ** 2 - 1)
+            return a + b * x + c * 0.5 * (3 * x**2 - 1)
 
         def legendre_grade_2_integrated(x, a, b, c):
-            return 0.5 * x * (2 * a + b * x + c * (x ** 2 - 1))
+            return 0.5 * x * (2 * a + b * x + c * (x**2 - 1))
 
         # should not raise an error
-        HistFit(data=self._ref_hist_cont,
-                model_function=legendre_grade_2,
-                bin_evaluation=legendre_grade_2_integrated,
-                minimizer=self.MINIMIZER)
+        HistFit(
+            data=self._ref_hist_cont,
+            model_function=legendre_grade_2,
+            bin_evaluation=legendre_grade_2_integrated,
+            minimizer=self.MINIMIZER,
+        )
 
     def test_report_before_fit(self):
         # TODO: check report content
