@@ -1,15 +1,13 @@
 import unittest
-import numpy as np
 
+import numpy as np
 from six import StringIO
 
-from kafe2.fit import IndexedContainer, XYContainer, HistContainer
-from kafe2.fit.representation import DataContainerYamlWriter, DataContainerYamlReader, DReprError
+from kafe2.fit import HistContainer, IndexedContainer, XYContainer
 from kafe2.fit.io.handle import IOStreamHandle
-from kafe2.fit.representation._yaml_base import YamlReaderException
+from kafe2.fit.representation import DataContainerYamlReader, DataContainerYamlWriter
 
-
-# TODO: check that DReprError is raised when appropriate...
+# TODO: check that exceptions are raised when appropriate...
 
 
 TEST_DATASET_INDEXED = """
@@ -83,22 +81,31 @@ errors:
   type: matrix
 """
 
-TEST_DATASET_INDEXED_EXTRA_KEYWORD = TEST_DATASET_INDEXED + """
+TEST_DATASET_INDEXED_EXTRA_KEYWORD = (
+    TEST_DATASET_INDEXED
+    + """
 extra_keyword: 3.14
 """
+)
+
 
 class TestIndexedContainerYamlRepresentation(unittest.TestCase):
-
     def setUp(self):
-        _data = [4, 5, 6, 2, 4, 5., 3.01e-5, 4.4e+45]
+        _data = [4, 5, 6, 2, 4, 5.0, 3.01e-5, 4.4e45]
         _ndat = len(_data)
         self._container = IndexedContainer(data=_data)
 
         self._container.add_error(err_val=0.1, name="SUA", correlation=0.0, relative=False)
         self._container.add_error(err_val=0.1, name="SUR", correlation=0.0, relative=True)
         self._container.add_error(err_val=0.1, name="SCA", correlation=1.0, relative=False)
-        self._container.add_matrix_error(err_matrix=np.eye(_ndat) * 0.1, name="MCov", relative=False, matrix_type='covariance')
-        self._container.add_matrix_error(err_matrix=np.eye(_ndat), name="MCor", relative=False, matrix_type='correlation', err_val=0.1)
+        self._container.add_matrix_error(err_matrix=np.eye(_ndat) * 0.1, name="MCov", relative=False, matrix_type="covariance")
+        self._container.add_matrix_error(
+            err_matrix=np.eye(_ndat),
+            name="MCor",
+            relative=False,
+            matrix_type="correlation",
+            err_val=0.1,
+        )
 
         # # xy
         # self._container.add_simple_error(axis='x', err_val=0.1, correlation=0.0, relative=False)
@@ -116,35 +123,23 @@ class TestIndexedContainerYamlRepresentation(unittest.TestCase):
         self._testfile_streamreader = DataContainerYamlReader(self._testfile_stringstream)
 
         self._ref_testfile_data = [80.429, 80.339]
-        self._ref_testfile_err = [0.89442719,  0.89442719]
+        self._ref_testfile_err = [0.89442719, 0.89442719]
         self._ref_testfile_cov_mat = np.array([[0.8, 0.3], [0.3, 0.8]])
-        self._ref_testfile_error_names = {'ErrorOne', 'ErrorTwo', 'ErrorThree', 'ErrorFour'}
+        self._ref_testfile_error_names = {"ErrorOne", "ErrorTwo", "ErrorThree", "ErrorFour"}
 
         self._testfile_stringstream_missing_keyword = IOStreamHandle(StringIO(TEST_DATASET_INDEXED_MISSING_KEYWORD))
         self._testfile_stringstream_extra_keyword = IOStreamHandle(StringIO(TEST_DATASET_INDEXED_EXTRA_KEYWORD))
         self._testfile_streamreader_missing_keyword = DataContainerYamlReader(self._testfile_stringstream_missing_keyword)
         self._testfile_streamreader_extra_keyword = DataContainerYamlReader(self._testfile_stringstream_extra_keyword)
 
-
     def test_write_to_roundtrip_stringstream(self):
         self._roundtrip_streamwriter.write()
 
-
     def test_read_from_testfile_stream(self):
         _read_container = self._testfile_streamreader.read()
         self.assertTrue(isinstance(_read_container, IndexedContainer))
-        self.assertTrue(
-            np.allclose(
-                _read_container.data,
-                self._ref_testfile_data
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                _read_container.err,
-                self._ref_testfile_err
-            )
-        )
+        self.assertTrue(np.allclose(_read_container.data, self._ref_testfile_data))
+        self.assertTrue(np.allclose(_read_container.err, self._ref_testfile_err))
         self.assertTrue(
             np.allclose(
                 _read_container.cov_mat,
@@ -153,18 +148,14 @@ class TestIndexedContainerYamlRepresentation(unittest.TestCase):
         )
 
         # check that the error names are the same
-        self.assertEqual(
-            set(_read_container._error_dicts.keys()),
-            self._ref_testfile_error_names
-        )
-
+        self.assertEqual(set(_read_container._error_dicts.keys()), self._ref_testfile_error_names)
 
     def test_read_from_testfile_stream_missing_keyword(self):
-        with self.assertRaises(YamlReaderException):
+        with self.assertRaises(ValueError):
             self._testfile_streamreader_missing_keyword.read()
 
     def test_read_from_testfile_stream_extra_keyword(self):
-        with self.assertRaises(YamlReaderException):
+        with self.assertRaises(ValueError):
             self._testfile_streamreader_extra_keyword.read()
 
     def test_round_trip_with_stringstream(self):
@@ -174,34 +165,16 @@ class TestIndexedContainerYamlRepresentation(unittest.TestCase):
         self.assertTrue(isinstance(_read_container, IndexedContainer))
 
         # compare data members
-        self.assertTrue(
-            np.allclose(
-                self._container.data,
-                _read_container.data
-            )
-        )
+        self.assertTrue(np.allclose(self._container.data, _read_container.data))
 
         # compare (total) errors and cov mats
         # TODO: compare individual error components -> nontrivial because error ids change...
-        self.assertTrue(
-            np.allclose(
-                self._container.err,
-                _read_container.err
-            )
-        )
+        self.assertTrue(np.allclose(self._container.err, _read_container.err))
 
-        self.assertTrue(
-            np.allclose(
-                self._container.cov_mat,
-                _read_container.cov_mat
-            )
-        )
+        self.assertTrue(np.allclose(self._container.cov_mat, _read_container.cov_mat))
 
         # check that the error names are the same
-        self.assertEqual(
-            set(self._container._error_dicts.keys()),
-            set(_read_container._error_dicts.keys())
-        )
+        self.assertEqual(set(self._container._error_dicts.keys()), set(_read_container._error_dicts.keys()))
 
 
 TEST_DATASET_XY = """
@@ -279,27 +252,48 @@ x_errors:
   type: matrix
 """
 
-TEST_DATASET_XY_EXTRA_KEYWORD = TEST_DATASET_XY + """
+TEST_DATASET_XY_EXTRA_KEYWORD = (
+    TEST_DATASET_XY
+    + """
 extra_keyword: 3.14
 """
+)
 
 
 class TestXYContainerYamlRepresentation(unittest.TestCase):
-
     def setUp(self):
-        _data = [[0.0, .1, .3], [10, 24, 44]]
+        _data = [[0.0, 0.1, 0.3], [10, 24, 44]]
         _ndat = len(_data[0])
         self._container = XYContainer(x_data=_data[0], y_data=_data[1])
 
-        self._container.add_error(axis='y', name="ySUA", err_val=0.1, correlation=0.0, relative=False)
-        self._container.add_error(axis='y', name="ySUR", err_val=0.1, correlation=0.0, relative=True)
-        self._container.add_error(axis='y', name="ySCA", err_val=0.1, correlation=1.0, relative=False)
-        self._container.add_matrix_error(axis='y', name="yMCov", err_matrix=np.eye(_ndat) * 0.1, relative=False, matrix_type='covariance')
-        self._container.add_matrix_error(axis='y', name="yMCor", err_matrix=np.eye(_ndat), relative=False, matrix_type='correlation', err_val=0.1)
+        self._container.add_error(axis="y", name="ySUA", err_val=0.1, correlation=0.0, relative=False)
+        self._container.add_error(axis="y", name="ySUR", err_val=0.1, correlation=0.0, relative=True)
+        self._container.add_error(axis="y", name="ySCA", err_val=0.1, correlation=1.0, relative=False)
+        self._container.add_matrix_error(
+            axis="y",
+            name="yMCov",
+            err_matrix=np.eye(_ndat) * 0.1,
+            relative=False,
+            matrix_type="covariance",
+        )
+        self._container.add_matrix_error(
+            axis="y",
+            name="yMCor",
+            err_matrix=np.eye(_ndat),
+            relative=False,
+            matrix_type="correlation",
+            err_val=0.1,
+        )
 
-        self._container.add_error(axis='x', name="xSUA", err_val=0.1, correlation=0.0, relative=False)
-        self._container.add_error(axis='x', name="xSUR", err_val=0.1, correlation=0.0, relative=True)
-        self._container.add_matrix_error(axis='x', name="xMCov", err_matrix=np.eye(_ndat) * 0.1, relative=False, matrix_type='covariance')
+        self._container.add_error(axis="x", name="xSUA", err_val=0.1, correlation=0.0, relative=False)
+        self._container.add_error(axis="x", name="xSUR", err_val=0.1, correlation=0.0, relative=True)
+        self._container.add_matrix_error(
+            axis="x",
+            name="xMCov",
+            err_matrix=np.eye(_ndat) * 0.1,
+            relative=False,
+            matrix_type="covariance",
+        )
 
         # self._container.add_simple_error(axis='x', err_val=0.1, correlation=0.0, relative=False)
         # self._container.add_simple_error(axis='y', err_val=0.2, correlation=0.0, relative=False)
@@ -319,44 +313,22 @@ class TestXYContainerYamlRepresentation(unittest.TestCase):
 
         self._ref_testfile_x_data = [5, 17]
         self._ref_testfile_y_data = [80.429, 80.339]
-        self._ref_testfile_x_err = [0.70710678,  0.70710678]
-        self._ref_testfile_y_err = [0.54772256,  0.54772256]
+        self._ref_testfile_x_err = [0.70710678, 0.70710678]
+        self._ref_testfile_y_err = [0.54772256, 0.54772256]
         self._ref_testfile_y_cov_mat = np.array([[0.3, 0.1], [0.1, 0.3]])
         self._ref_testfile_x_cov_mat = np.array([[0.5, 0.2], [0.2, 0.5]])
-        self._ref_testfile_error_names = {'XErrorOne', 'XErrorTwo', 'YErrorOne', 'YErrorTwo'}
-
+        self._ref_testfile_error_names = {"XErrorOne", "XErrorTwo", "YErrorOne", "YErrorTwo"}
 
     def test_write_to_roundtrip_stringstream(self):
         self._roundtrip_streamwriter.write()
 
-
     def test_read_from_testfile_stream(self):
         _read_container = self._testfile_streamreader.read()
         self.assertTrue(isinstance(_read_container, XYContainer))
-        self.assertTrue(
-            np.allclose(
-                _read_container.x,
-                self._ref_testfile_x_data
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                _read_container.y,
-                self._ref_testfile_y_data
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                _read_container.x_err,
-                self._ref_testfile_x_err
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                _read_container.y_err,
-                self._ref_testfile_y_err
-            )
-        )
+        self.assertTrue(np.allclose(_read_container.x, self._ref_testfile_x_data))
+        self.assertTrue(np.allclose(_read_container.y, self._ref_testfile_y_data))
+        self.assertTrue(np.allclose(_read_container.x_err, self._ref_testfile_x_err))
+        self.assertTrue(np.allclose(_read_container.y_err, self._ref_testfile_y_err))
         self.assertTrue(
             np.allclose(
                 _read_container.x_cov_mat,
@@ -371,18 +343,14 @@ class TestXYContainerYamlRepresentation(unittest.TestCase):
         )
 
         # check that the error names are the same
-        self.assertEqual(
-            set(_read_container._error_dicts.keys()),
-            self._ref_testfile_error_names
-        )
-
+        self.assertEqual(set(_read_container._error_dicts.keys()), self._ref_testfile_error_names)
 
     def test_read_from_testfile_stream_missing_keyword(self):
-        with self.assertRaises(YamlReaderException):
+        with self.assertRaises(ValueError):
             self._testfile_streamreader_missing_keyword.read()
 
     def test_read_from_testfile_stream_extra_keyword(self):
-        with self.assertRaises(YamlReaderException):
+        with self.assertRaises(ValueError):
             self._testfile_streamreader_extra_keyword.read()
 
     def test_round_trip_with_stringstream(self):
@@ -392,52 +360,19 @@ class TestXYContainerYamlRepresentation(unittest.TestCase):
         self.assertTrue(isinstance(_read_container, XYContainer))
 
         # compare data members
-        self.assertTrue(
-            np.allclose(
-                self._container.x,
-                _read_container.x
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._container.y,
-                _read_container.y
-            )
-        )
+        self.assertTrue(np.allclose(self._container.x, _read_container.x))
+        self.assertTrue(np.allclose(self._container.y, _read_container.y))
 
         # compare (total) errors and cov mats
         # TODO: compare individual error components -> nontrivial because error ids change...
-        self.assertTrue(
-            np.allclose(
-                self._container.x_err,
-                _read_container.x_err
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._container.y_err,
-                _read_container.y_err
-            )
-        )
+        self.assertTrue(np.allclose(self._container.x_err, _read_container.x_err))
+        self.assertTrue(np.allclose(self._container.y_err, _read_container.y_err))
 
-        self.assertTrue(
-            np.allclose(
-                self._container.x_cov_mat,
-                _read_container.x_cov_mat
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._container.y_cov_mat,
-                _read_container.y_cov_mat
-            )
-        )
+        self.assertTrue(np.allclose(self._container.x_cov_mat, _read_container.x_cov_mat))
+        self.assertTrue(np.allclose(self._container.y_cov_mat, _read_container.y_cov_mat))
 
         # check that the error names are the same
-        self.assertEqual(
-            set(self._container._error_dicts.keys()),
-            set(_read_container._error_dicts.keys())
-        )
+        self.assertEqual(set(self._container._error_dicts.keys()), set(_read_container._error_dicts.keys()))
 
 
 TEST_DATASET_HIST = """
@@ -486,9 +421,12 @@ errors:
 type: histogram
 """
 
-TEST_DATASET_HIST_EXTRA_KEYWORD = TEST_DATASET_HIST + """
+TEST_DATASET_HIST_EXTRA_KEYWORD = (
+    TEST_DATASET_HIST
+    + """
 extra_keyword: 3.14
 """
+)
 
 TEST_DATASET_HIST_MANUAL_HEIGHTS = """
 bin_edges:
@@ -536,18 +474,26 @@ type: histogram
 
 
 class TestHistContainerYamlRepresentation(unittest.TestCase):
-
     def setUp(self):
         _data = [1, 1, 4, 1, 1, 4, 2, 5, 5, 5, 2, 4, 2, 2, 18, 2, 8, 8, 9]
         _nbins = 3
-        self._container = HistContainer(n_bins=_nbins,
-                                        bin_range=(0.0, 10.),
-                                        fill_data=_data)
+        self._container = HistContainer(n_bins=_nbins, bin_range=(0.0, 10.0), fill_data=_data)
 
-        self._container.add_error(err_val=0.1, name='SC5A_1', correlation=0.5, relative=False)
-        self._container.add_error(err_val=[i / 10. for i in range(1, _nbins + 1)], name='SC5A_2', correlation=0.5, relative=False)
-        self._container.add_matrix_error(err_matrix=np.eye(_nbins) * 0.1, name='MCov', relative=False, matrix_type='covariance')
-        self._container.add_matrix_error(err_matrix=np.eye(_nbins), name='MCor', relative=False, matrix_type='correlation', err_val=0.03)
+        self._container.add_error(err_val=0.1, name="SC5A_1", correlation=0.5, relative=False)
+        self._container.add_error(
+            err_val=[i / 10.0 for i in range(1, _nbins + 1)],
+            name="SC5A_2",
+            correlation=0.5,
+            relative=False,
+        )
+        self._container.add_matrix_error(err_matrix=np.eye(_nbins) * 0.1, name="MCov", relative=False, matrix_type="covariance")
+        self._container.add_matrix_error(
+            err_matrix=np.eye(_nbins),
+            name="MCor",
+            relative=False,
+            matrix_type="correlation",
+            err_val=0.03,
+        )
 
         self._roundtrip_stringstream = IOStreamHandle(StringIO())
         self._testfile_stringstream = IOStreamHandle(StringIO(TEST_DATASET_HIST))
@@ -559,10 +505,8 @@ class TestHistContainerYamlRepresentation(unittest.TestCase):
         self._testfile_stringstream_extra_keyword = IOStreamHandle(StringIO(TEST_DATASET_HIST_EXTRA_KEYWORD))
         self._testfile_streamreader_extra_keyword = DataContainerYamlReader(self._testfile_stringstream_extra_keyword)
 
-        self._testfile_stringstream_manual_heights = IOStreamHandle(
-            StringIO(TEST_DATASET_HIST_MANUAL_HEIGHTS))
-        self._testfile_streamreader_manual_heights = DataContainerYamlReader(
-            self._testfile_stringstream_manual_heights)
+        self._testfile_stringstream_manual_heights = IOStreamHandle(StringIO(TEST_DATASET_HIST_MANUAL_HEIGHTS))
+        self._testfile_streamreader_manual_heights = DataContainerYamlReader(self._testfile_stringstream_manual_heights)
 
         self._ref_testfile_n_bins = 2
         self._ref_testfile_bin_range = [1.0, 3.0]
@@ -570,9 +514,9 @@ class TestHistContainerYamlRepresentation(unittest.TestCase):
         self._ref_testfile_data = [1, 1]
         self._ref_testfile_underflow = 0
         self._ref_testfile_overflow = 4
-        self._ref_testfile_err = [0.89442719,  1]
+        self._ref_testfile_err = [0.89442719, 1]
         self._ref_testfile_cov_mat = np.array([[0.8, 0.3], [0.3, 1.0]])
-        self._ref_testfile_error_names = {'ErrorOne', 'ErrorTwo', 'ErrorThree', 'ErrorFour'}
+        self._ref_testfile_error_names = {"ErrorOne", "ErrorTwo", "ErrorThree", "ErrorFour"}
 
     def test_write_to_roundtrip_stringstream(self):
         self._roundtrip_streamwriter.write()
@@ -582,33 +526,13 @@ class TestHistContainerYamlRepresentation(unittest.TestCase):
         self.assertTrue(isinstance(_read_container, HistContainer))
 
         self.assertTrue(_read_container.n_bins == self._ref_testfile_n_bins)
-        self.assertTrue(
-            np.allclose(
-                _read_container.bin_range,
-                self._ref_testfile_bin_range
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                _read_container.bin_edges,
-                self._ref_testfile_bin_edges
-            )
-        )
+        self.assertTrue(np.allclose(_read_container.bin_range, self._ref_testfile_bin_range))
+        self.assertTrue(np.allclose(_read_container.bin_edges, self._ref_testfile_bin_edges))
 
-        self.assertTrue(
-            np.allclose(
-                _read_container.data,
-                self._ref_testfile_data
-            )
-        )
+        self.assertTrue(np.allclose(_read_container.data, self._ref_testfile_data))
         self.assertEqual(_read_container.underflow, self._ref_testfile_underflow)
         self.assertEqual(_read_container.overflow, self._ref_testfile_overflow)
-        self.assertTrue(
-            np.allclose(
-                _read_container.err,
-                self._ref_testfile_err
-            )
-        )
+        self.assertTrue(np.allclose(_read_container.err, self._ref_testfile_err))
         self.assertTrue(
             np.allclose(
                 _read_container.cov_mat,
@@ -617,43 +541,20 @@ class TestHistContainerYamlRepresentation(unittest.TestCase):
         )
 
         # check that the error names are the same
-        self.assertEqual(
-            set(_read_container._error_dicts.keys()),
-            self._ref_testfile_error_names
-        )
+        self.assertEqual(set(_read_container._error_dicts.keys()), self._ref_testfile_error_names)
 
     def test_read_from_testfile_stream_manual_heights(self):
         _read_container = self._testfile_streamreader.read()
         self.assertTrue(isinstance(_read_container, HistContainer))
 
         self.assertTrue(_read_container.n_bins == self._ref_testfile_n_bins)
-        self.assertTrue(
-            np.allclose(
-                _read_container.bin_range,
-                self._ref_testfile_bin_range
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                _read_container.bin_edges,
-                self._ref_testfile_bin_edges
-            )
-        )
+        self.assertTrue(np.allclose(_read_container.bin_range, self._ref_testfile_bin_range))
+        self.assertTrue(np.allclose(_read_container.bin_edges, self._ref_testfile_bin_edges))
 
-        self.assertTrue(
-            np.allclose(
-                _read_container.data,
-                self._ref_testfile_data
-            )
-        )
+        self.assertTrue(np.allclose(_read_container.data, self._ref_testfile_data))
         self.assertEqual(_read_container.underflow, self._ref_testfile_underflow)
         self.assertEqual(_read_container.overflow, self._ref_testfile_overflow)
-        self.assertTrue(
-            np.allclose(
-                _read_container.err,
-                self._ref_testfile_err
-            )
-        )
+        self.assertTrue(np.allclose(_read_container.err, self._ref_testfile_err))
         self.assertTrue(
             np.allclose(
                 _read_container.cov_mat,
@@ -662,13 +563,10 @@ class TestHistContainerYamlRepresentation(unittest.TestCase):
         )
 
         # check that the error names are the same
-        self.assertEqual(
-            set(_read_container._error_dicts.keys()),
-            self._ref_testfile_error_names
-        )
+        self.assertEqual(set(_read_container._error_dicts.keys()), self._ref_testfile_error_names)
 
     def test_read_from_testfile_stream_extra_keyword(self):
-        with self.assertRaises(YamlReaderException):
+        with self.assertRaises(ValueError):
             self._testfile_streamreader_extra_keyword.read()
 
     def test_round_trip_with_stringstream(self):
@@ -678,97 +576,40 @@ class TestHistContainerYamlRepresentation(unittest.TestCase):
         self.assertTrue(isinstance(_read_container, HistContainer))
 
         self.assertTrue(self._container.n_bins == _read_container.n_bins)
-        self.assertTrue(
-            np.allclose(
-                self._container.bin_range,
-                _read_container.bin_range
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._container.bin_edges,
-                _read_container.bin_edges
-            )
-        )
+        self.assertTrue(np.allclose(self._container.bin_range, _read_container.bin_range))
+        self.assertTrue(np.allclose(self._container.bin_edges, _read_container.bin_edges))
 
         # compare data members
-        self.assertTrue(
-            np.allclose(
-                self._container.data,
-                _read_container.data
-            )
-        )
+        self.assertTrue(np.allclose(self._container.data, _read_container.data))
 
         # compare (total) errors and cov mats
         # TODO: compare individual error components -> nontrivial because error ids change...
-        self.assertTrue(
-            np.allclose(
-                self._container.err,
-                _read_container.err
-            )
-        )
+        self.assertTrue(np.allclose(self._container.err, _read_container.err))
 
-        self.assertTrue(
-            np.allclose(
-                self._container.cov_mat,
-                _read_container.cov_mat
-            )
-        )
+        self.assertTrue(np.allclose(self._container.cov_mat, _read_container.cov_mat))
 
         # check that the error names are the same
-        self.assertEqual(
-            set(self._container._error_dicts.keys()),
-            set(_read_container._error_dicts.keys())
-        )
+        self.assertEqual(set(self._container._error_dicts.keys()), set(_read_container._error_dicts.keys()))
 
     def test_round_trip_with_stringstream_manual_heights(self):
-        self._container.set_bins(
-            self._container.data, self._container.underflow, self._container.overflow)
+        self._container.set_bins(self._container.data, self._container.underflow, self._container.overflow)
         self._roundtrip_streamwriter.write()
         self._roundtrip_stringstream.seek(0)  # return to beginning
         _read_container = self._roundtrip_streamreader.read()
         self.assertTrue(isinstance(_read_container, HistContainer))
 
         self.assertTrue(self._container.n_bins == _read_container.n_bins)
-        self.assertTrue(
-            np.allclose(
-                self._container.bin_range,
-                _read_container.bin_range
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._container.bin_edges,
-                _read_container.bin_edges
-            )
-        )
+        self.assertTrue(np.allclose(self._container.bin_range, _read_container.bin_range))
+        self.assertTrue(np.allclose(self._container.bin_edges, _read_container.bin_edges))
 
         # compare data members
-        self.assertTrue(
-            np.allclose(
-                self._container.data,
-                _read_container.data
-            )
-        )
+        self.assertTrue(np.allclose(self._container.data, _read_container.data))
 
         # compare (total) errors and cov mats
         # TODO: compare individual error components -> nontrivial because error ids change...
-        self.assertTrue(
-            np.allclose(
-                self._container.err,
-                _read_container.err
-            )
-        )
+        self.assertTrue(np.allclose(self._container.err, _read_container.err))
 
-        self.assertTrue(
-            np.allclose(
-                self._container.cov_mat,
-                _read_container.cov_mat
-            )
-        )
+        self.assertTrue(np.allclose(self._container.cov_mat, _read_container.cov_mat))
 
         # check that the error names are the same
-        self.assertEqual(
-            set(self._container._error_dicts.keys()),
-            set(_read_container._error_dicts.keys())
-        )
+        self.assertEqual(set(self._container._error_dicts.keys()), set(_read_container._error_dicts.keys()))
