@@ -1,20 +1,21 @@
-import unittest
-import numpy as np
-from scipy.stats import norm
-import six
-from six import StringIO
 import abc
 import os
+import unittest
+
+import numpy as np
+import six
+from scipy.stats import norm
+from six import StringIO
 
-from kafe2.fit.representation import FitYamlWriter, FitYamlReader
-from kafe2.fit.io.handle import IOStreamHandle
 from kafe2.fit.custom import CustomFit
 from kafe2.fit.histogram import HistFit
+from kafe2.fit.histogram.container import HistContainer
 from kafe2.fit.indexed import IndexedFit
+from kafe2.fit.io.handle import IOStreamHandle
+from kafe2.fit.representation import FitYamlReader, FitYamlWriter
 from kafe2.fit.unbinned import UnbinnedFit
 from kafe2.fit.xy import XYFit
-from kafe2.fit.histogram.container import HistContainer
-from kafe2.fit.representation._yaml_base import YamlReaderException
+
 from .test_fit_custom import TestCustomFitWithSimpleYErrors
 
 
@@ -53,11 +54,11 @@ class AbstractTestFitRepresenter(object):
         self._roundtrip_streamwriter.write()
 
     def test_read_from_testfile_stream_missing_keyword(self):
-        with self.assertRaises(YamlReaderException):
+        with self.assertRaises(ValueError):
             self._testfile_streamreader_missing_keyword.read()
 
     def test_read_from_testfile_stream_extra_keyword(self):
-        with self.assertRaises(YamlReaderException):
+        with self.assertRaises(ValueError):
             self._testfile_streamreader_extra_keyword.read()
 
     def test_round_trip_save_results(self):
@@ -68,24 +69,9 @@ class AbstractTestFitRepresenter(object):
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
 
         self.assertTrue(self._fit.did_fit == _read_fit.did_fit)
-        self.assertTrue(
-            np.allclose(
-                self._fit.parameter_cov_mat,
-                _read_fit.parameter_cov_mat
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._fit.parameter_errors,
-                _read_fit.parameter_errors
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._fit.parameter_cor_mat,
-                _read_fit.parameter_cor_mat
-            )
-        )
+        self.assertTrue(np.allclose(self._fit.parameter_cov_mat, _read_fit.parameter_cov_mat))
+        self.assertTrue(np.allclose(self._fit.parameter_errors, _read_fit.parameter_errors))
+        self.assertTrue(np.allclose(self._fit.parameter_cor_mat, _read_fit.parameter_cor_mat))
 
     def test_round_trip_save_results_2(self):
         self._roundtrip_streamwriter.write()
@@ -99,27 +85,12 @@ class AbstractTestFitRepresenter(object):
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
 
         self.assertTrue(self._fit.did_fit == _read_fit.did_fit)
-        self.assertTrue(
-            np.allclose(
-                self._fit.parameter_cov_mat,
-                _read_fit.parameter_cov_mat
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._fit.parameter_errors,
-                _read_fit.parameter_errors
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._fit.parameter_cor_mat,
-                _read_fit.parameter_cor_mat
-            )
-        )
+        self.assertTrue(np.allclose(self._fit.parameter_cov_mat, _read_fit.parameter_cov_mat))
+        self.assertTrue(np.allclose(self._fit.parameter_errors, _read_fit.parameter_errors))
+        self.assertTrue(np.allclose(self._fit.parameter_cor_mat, _read_fit.parameter_cor_mat))
 
 
-TEST_FIT_CUSTOM="""
+TEST_FIT_CUSTOM = """
 type: custom
 cost_function: |
     def chi2(a=1.5, b=-0.5):
@@ -151,13 +122,17 @@ parameter_formatters:
     b: beta
 """
 
-TEST_FIT_CUSTOM_MISSING_KEYWORD="""
+TEST_FIT_CUSTOM_MISSING_KEYWORD = """
 type: custom
 """
 
-TEST_FIT_CUSTOM_EXTRA_KEYWORD = TEST_FIT_CUSTOM + """
+TEST_FIT_CUSTOM_EXTRA_KEYWORD = (
+    TEST_FIT_CUSTOM
+    + """
 extra_keyword: 3.14
 """
+)
+
 
 class TestCustomFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
     FIT_CLASS = CustomFit
@@ -170,43 +145,37 @@ class TestCustomFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter
         self._test_parameters = np.array([2.0, -1.0])
         self._test_parameters_default = np.array([1.5, -0.5])
         self._test_parameters_do_fit = np.array([2.0115580399995032, -1.0889949779758534])
-        self._test_y_default = self._test_parameters_default[0] * np.arange(10) \
-                               + self._test_parameters_default[1]
-        self._test_y_do_fit = [-1.08899498, 0.92256306, 2.9341211, 4.94567914, 6.95723718,
-                               8.96879522, 10.98035326,
-                               12.9919113, 15.00346934, 17.01502738]
+        self._test_y_default = self._test_parameters_default[0] * np.arange(10) + self._test_parameters_default[1]
+        self._test_y_do_fit = [
+            -1.08899498,
+            0.92256306,
+            2.9341211,
+            4.94567914,
+            6.95723718,
+            8.96879522,
+            10.98035326,
+            12.9919113,
+            15.00346934,
+            17.01502738,
+        ]
 
         self._fit = CustomFit(TestCustomFitWithSimpleYErrors.chi2)
-        self._fit.assign_parameter_names(a='alpha', b='beta')
-        self._fit.add_parameter_constraint(name='a', value=2.0, uncertainty=1.0)
-        self._fit.add_parameter_constraint(name='b', value=-1.0, uncertainty=0.5)
-        self._fit.add_matrix_parameter_constraint(names=['a', 'b'], values=[2.05, -0.95],
-                                                  matrix=[[1.1, 0.1], [0.1, 2.4]])
+        self._fit.assign_parameter_names(a="alpha", b="beta")
+        self._fit.add_parameter_constraint(name="a", value=2.0, uncertainty=1.0)
+        self._fit.add_parameter_constraint(name="b", value=-1.0, uncertainty=0.5)
+        self._fit.add_matrix_parameter_constraint(names=["a", "b"], values=[2.05, -0.95], matrix=[[1.1, 0.1], [0.1, 2.4]])
         self.setup_streams()
 
     def test_read_from_testfile_stream(self):
         _read_fit = self._testfile_streamreader.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
         for _pf in _read_fit._parameter_formatters:
-            self.assertTrue(
-                _pf.arg_name == 'a' and _pf.name == 'alpha'
-                or _pf.arg_name == 'b' and _pf.name == 'beta'
-            )
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default,
-                _read_fit.parameter_values
-            )
-        )
+            self.assertTrue(_pf.arg_name == "a" and _pf.name == "alpha" or _pf.arg_name == "b" and _pf.name == "beta")
+        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.parameter_values))
 
         _read_fit.do_fit()
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit,
-                _read_fit.parameter_values
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.parameter_values))
 
     def test_round_trip_with_stringstream(self):
         self._roundtrip_streamwriter.write()
@@ -214,29 +183,16 @@ class TestCustomFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter
         _read_fit = self._roundtrip_streamreader.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
         for _pf in _read_fit._parameter_formatters:
-            self.assertTrue(
-                _pf.arg_name == 'a' and _pf.name == 'alpha'
-                or _pf.arg_name == 'b' and _pf.name == 'beta'
-            )
+            self.assertTrue(_pf.arg_name == "a" and _pf.name == "alpha" or _pf.arg_name == "b" and _pf.name == "beta")
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default,
-                _read_fit.parameter_values
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.parameter_values))
 
         _read_fit.do_fit()
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit,
-                _read_fit.parameter_values
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.parameter_values))
 
 
-TEST_FIT_HIST="""
+TEST_FIT_HIST = """
 type: histogram
 cost_function: nll_poisson
 dataset:
@@ -270,9 +226,7 @@ parametric_model:
     bin_range: [-2.0, 2.0]
     model_density_function:
         type: histogram
-        python_code: |
-            def hist_model_density(x, mu, sigma):
-                return np.exp(-0.5 * ((x - mu) / sigma) ** 2) / np.sqrt(2 * np.pi * sigma ** 2)
+        python_code: 'x mu sigma -> exp(-0.5 * ((x - mu) / sigma)^2) / sqrt(2 * pi * sigma ** 2)'
     model_parameters: [0.1, 1.0]
 parameter_constraints:
       - type: simple
@@ -289,7 +243,7 @@ parameter_constraints:
         matrix: [[1.1, 0.1], [0.1, 2.4]]
 """
 
-TEST_FIT_HIST_MISSING_KEYWORD="""
+TEST_FIT_HIST_MISSING_KEYWORD = """
 type: histogram
 parametric_model:
     type: histogram
@@ -303,11 +257,14 @@ parametric_model:
     model_parameters: [0.1, 1.0]
 """
 
-TEST_FIT_HIST_EXTRA_KEYWORD = TEST_FIT_HIST + """
+TEST_FIT_HIST_EXTRA_KEYWORD = (
+    TEST_FIT_HIST
+    + """
 extra_keyword: 3.14
 """
+)
 
-TEST_FIT_HIST_SIMPLE="""
+TEST_FIT_HIST_SIMPLE = """
 type: histogram
 n_bins: 8
 bin_range: [-2.0, 2.0]
@@ -339,14 +296,16 @@ class TestHistFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
 
     @staticmethod
     def hist_model_density(x, mu=0.1, sigma=1.0):
-        #TODO scipy.stats.norm support
-        return np.exp(-0.5 * ((x - mu) / sigma) ** 2) / np.sqrt(2 * np.pi * sigma ** 2)
-    
+        # TODO scipy.stats.norm support
+        return np.exp(-0.5 * ((x - mu) / sigma) ** 2) / np.sqrt(2 * np.pi * sigma**2)
+
     @staticmethod
     def hist_model_density_antiderivative(x, mu, sigma):
         return norm(mu, sigma).cdf(x)
-    
+
     def setUp(self):
+        # fmt: off
+        # flake8: noqa E131 (unaligned indent)
         self._test_raw_data = [
             0.94657578,  0.3674123,  -0.16462338,  0.0408205,   0.35318031, -0.35919436,
            -0.22111037, -0.4663712,  -0.26321687,  0.63243935,  0.30995581,  0.45732282,
@@ -364,6 +323,7 @@ class TestHistFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
             0.08691923,  0.98999353, -0.17895406,  0.50533812,  0.81767467, -0.76434111,
             0.09429677,  0.61596385,  0.69613775, -0.29647721,  0.48768034, -0.44852791
         ]
+        # fmt: on
         self._test_n_bins = 8
         self._test_parameters_default = np.array([0.1, 1.0])
         self._test_parameters_default_simple = np.array([1.0, 1.0])
@@ -378,76 +338,42 @@ class TestHistFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         self._test_density_do_fit_simple = self.hist_model_density(self._test_x, *self._test_parameters_do_fit_simple)
 
         _data = HistContainer(n_bins=self._test_n_bins, bin_range=self._test_bin_range, fill_data=self._test_raw_data)
-        self._fit = HistFit(
-            data=_data,
-            model_function=TestHistFitYamlRepresenter.hist_model_density
-        )
+        self._fit = HistFit(data=_data, model_function=TestHistFitYamlRepresenter.hist_model_density)
         self._fit.add_error(err_val=0.1)
         self._fit.add_parameter_constraint("mu", 0.1, 1.0)
         self._fit.add_parameter_constraint("sigma", 1.0, 0.5)
-        self._fit.add_matrix_parameter_constraint(
-            ["sigma", "mu"], [1.3, 2.5], [[1.1, 0.1], [0.1, 2.4]])
+        self._fit.add_matrix_parameter_constraint(["sigma", "mu"], [1.3, 2.5], [[1.1, 0.1], [0.1, 2.4]])
 
         self.setup_streams()
 
     def test_read_from_testfile_stream(self):
         _read_fit = self._testfile_streamreader.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_density_default,
-                _read_fit.eval_model_function_density(self._test_x)
-            )
-        )
-        
+        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_density_default, _read_fit.eval_model_function_density(self._test_x)))
+
         _read_fit.do_fit()
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_density_do_fit,
-                _read_fit.eval_model_function_density(self._test_x)
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_density_do_fit, _read_fit.eval_model_function_density(self._test_x)))
 
     def test_read_from_testfile_stream_simple(self):
         _read_fit = self._testfile_streamreader_simple.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default_simple,
-                _read_fit.parameter_values
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_default_simple, _read_fit.parameter_values))
         self.assertTrue(
             np.allclose(
                 self._test_density_default_simple,
-                _read_fit.eval_model_function_density(self._test_x)
+                _read_fit.eval_model_function_density(self._test_x),
             )
         )
-        
+
         _read_fit.do_fit()
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit_simple,
-                _read_fit.parameter_values
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_do_fit_simple, _read_fit.parameter_values))
         self.assertTrue(
             np.allclose(
                 self._test_density_do_fit_simple,
-                _read_fit.eval_model_function_density(self._test_x)
+                _read_fit.eval_model_function_density(self._test_x),
             )
         )
 
@@ -457,36 +383,16 @@ class TestHistFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         _read_fit = self._roundtrip_streamreader.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_density_default,
-                _read_fit.eval_model_function_density(self._test_x)
-            )
-        )
-        
+        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_density_default, _read_fit.eval_model_function_density(self._test_x)))
+
         _read_fit.do_fit()
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_density_do_fit,
-                _read_fit.eval_model_function_density(self._test_x)
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_density_do_fit, _read_fit.eval_model_function_density(self._test_x)))
 
 
-TEST_FIT_INDEXED="""
+TEST_FIT_INDEXED = """
 type: indexed
 cost_function: chi2
 dataset:
@@ -522,7 +428,7 @@ parameter_constraints:
         matrix: [[1.1, 0.1], [0.1, 2.4]]
 """
 
-TEST_FIT_INDEXED_MISSING_KEYWORD="""
+TEST_FIT_INDEXED_MISSING_KEYWORD = """
 type: indexed
 parametric_model:
     type: indexed
@@ -534,11 +440,14 @@ parametric_model:
     model_parameters: [1.5, -0.5]
 """
 
-TEST_FIT_INDEXED_EXTRA_KEYWORD = TEST_FIT_INDEXED + """
+TEST_FIT_INDEXED_EXTRA_KEYWORD = (
+    TEST_FIT_INDEXED
+    + """
 extra_keyword: 3.14
 """
+)
 
-TEST_FIT_INDEXED_SIMPLE="""
+TEST_FIT_INDEXED_SIMPLE = """
 type: indexed
 data: [ -1.0804945, 0.97336504, 2.75769933, 4.91093935, 6.98511206,
        9.15059627, 10.9665515, 13.06741151, 14.95081026, 16.94404467]
@@ -559,7 +468,7 @@ class TestIndexedFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresente
     @staticmethod
     def linear_model(a=1.5, b=-0.5):
         return a * np.arange(10) + b
-    
+
     def setUp(self):
         self._test_x = np.arange(10)
         self._test_parameters = np.array([2.0, -1.0])
@@ -567,89 +476,75 @@ class TestIndexedFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresente
         self._test_parameters_default_simple = np.array([1.0, 1.0])
         self._test_parameters_do_fit = np.array([2.0115580399995032, -1.0889949779758534])
         self._test_parameters_do_fit_simple = np.array([2.0117809129092095, -1.090410559090481])
-        self._test_y = [-1.0804945, 0.97336504, 2.75769933, 4.91093935, 6.98511206,
-                        9.15059627, 10.9665515, 13.06741151, 14.95081026, 16.94404467]
+        self._test_y = [
+            -1.0804945,
+            0.97336504,
+            2.75769933,
+            4.91093935,
+            6.98511206,
+            9.15059627,
+            10.9665515,
+            13.06741151,
+            14.95081026,
+            16.94404467,
+        ]
         self._test_y_default = self.linear_model(*self._test_parameters_default)
         self._test_y_default_simple = self.linear_model(*self._test_parameters_default_simple)
-        self._test_y_do_fit = [-1.08899498, 0.92256306, 2.9341211, 4.94567914, 6.95723718, 8.96879522,
-                               10.98035326, 12.9919113, 15.00346934, 17.01502738]
-        self._test_y_do_fit_simple = [-1.09041056, 0.92137035, 2.93315127, 4.94493218, 6.95671309,
-                                      8.96849401, 10.98027492, 12.99205583, 15.00383674, 17.01561766]
+        self._test_y_do_fit = [
+            -1.08899498,
+            0.92256306,
+            2.9341211,
+            4.94567914,
+            6.95723718,
+            8.96879522,
+            10.98035326,
+            12.9919113,
+            15.00346934,
+            17.01502738,
+        ]
+        self._test_y_do_fit_simple = [
+            -1.09041056,
+            0.92137035,
+            2.93315127,
+            4.94493218,
+            6.95671309,
+            8.96849401,
+            10.98027492,
+            12.99205583,
+            15.00383674,
+            17.01561766,
+        ]
 
-        self._fit = IndexedFit(
-            data=self._test_y,
-            model_function=TestIndexedFitYamlRepresenter.linear_model
-        )
+        self._fit = IndexedFit(data=self._test_y, model_function=TestIndexedFitYamlRepresenter.linear_model)
         self._fit.set_all_parameter_values(self._test_parameters_default)
         self._fit.add_error(err_val=0.1)
-        self._fit.add_parameter_constraint(name='a', value=2.0, uncertainty=1.0)
-        self._fit.add_parameter_constraint(name='b', value=-1.0, uncertainty=0.5)
-        self._fit.add_matrix_parameter_constraint(names=['a', 'b'], values=[2.05, -0.95],
-                                                  matrix=[[1.1, 0.1], [0.1, 2.4]])
+        self._fit.add_parameter_constraint(name="a", value=2.0, uncertainty=1.0)
+        self._fit.add_parameter_constraint(name="b", value=-1.0, uncertainty=0.5)
+        self._fit.add_matrix_parameter_constraint(names=["a", "b"], values=[2.05, -0.95], matrix=[[1.1, 0.1], [0.1, 2.4]])
 
         self.setup_streams()
 
     def test_read_from_testfile_stream(self):
         _read_fit = self._testfile_streamreader.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_default,
-                _read_fit.model
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_default, _read_fit.model))
 
         _read_fit.do_fit()
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_do_fit,
-                _read_fit.model
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_do_fit, _read_fit.model))
 
     def test_read_from_testfile_stream_simple(self):
         _read_fit = self._testfile_streamreader_simple.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default_simple,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_default_simple,
-                _read_fit.model
-            )
-        )
-        
+        self.assertTrue(np.allclose(self._test_parameters_default_simple, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_default_simple, _read_fit.model))
+
         _read_fit.do_fit()
-        
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit_simple,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_do_fit_simple,
-                _read_fit.model
-            )
-        )
+
+        self.assertTrue(np.allclose(self._test_parameters_do_fit_simple, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_do_fit_simple, _read_fit.model))
 
     def test_round_trip_with_stringstream(self):
         self._roundtrip_streamwriter.write()
@@ -657,36 +552,16 @@ class TestIndexedFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresente
         _read_fit = self._roundtrip_streamreader.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_default,
-                _read_fit.model
-            )
-        )
-        
+        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_default, _read_fit.model))
+
         _read_fit.do_fit()
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_do_fit,
-                _read_fit.model
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_do_fit, _read_fit.model))
 
 
-TEST_FIT_XY="""
+TEST_FIT_XY = """
 type: xy
 cost_function: chi2
 dataset:
@@ -704,9 +579,7 @@ parametric_model:
     type: xy
     x_data: [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0]
     model_function:
-        python_code: |
-            def linear_model(x, a, b):
-                return a * x + b
+        python_code: 'x a b -> a * x + b'
     model_parameters: [1.5, -0.5]
 parameter_constraints:
       - type: simple
@@ -723,7 +596,7 @@ parameter_constraints:
         matrix: [[1.1, 0.1], [0.1, 2.4]]
 """
 
-TEST_FIT_XY_MISSING_KEYWORD="""
+TEST_FIT_XY_MISSING_KEYWORD = """
 type: xy
 parametric_model:
     type: xy
@@ -735,11 +608,14 @@ parametric_model:
     model_parameters: [1.5, -0.5]
 """
 
-TEST_FIT_XY_EXTRA_KEYWORD = TEST_FIT_XY + """
+TEST_FIT_XY_EXTRA_KEYWORD = (
+    TEST_FIT_XY
+    + """
 extra_keyword: 3.14
 """
+)
 
-TEST_FIT_XY_SIMPLE="""
+TEST_FIT_XY_SIMPLE = """
 x_data: [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0]
 y_data: [ -1.0804945, 0.97336504, 2.75769933, 4.91093935, 6.98511206,
         9.15059627, 10.9665515, 13.06741151, 14.95081026, 16.94404467]
@@ -747,7 +623,7 @@ model_function: linear
 y_errors: 0.1
 """
 
-TEST_FIT_XY_RELATIVE_ERROR="""
+TEST_FIT_XY_RELATIVE_ERROR = """
 x_data: [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0]
 y_data: [ -1.0804945, 0.97336504, 2.75769933, 4.91093935, 6.98511206,
         9.15059627, 10.9665515, 13.06741151, 14.95081026, 16.94404467]
@@ -756,7 +632,7 @@ x_errors: 10%
 y_errors: [10%, 10%, 10%, 10%, 10%, 10%, 10%, 10%, 10%, 10%]
 """
 
-TEST_FIT_XY_RELATIVE_ERROR_MIXED="""
+TEST_FIT_XY_RELATIVE_ERROR_MIXED = """
 x_data: [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0]
 y_data: [ -1.0804945, 0.97336504, 2.75769933, 4.91093935, 6.98511206,
         9.15059627, 10.9665515, 13.06741151, 14.95081026, 16.94404467]
@@ -765,6 +641,7 @@ x_errors: 10%
 y_errors: [0.10804945, 10%, 10%, 0.491093935, 10%, 0.915059627, 10%, 10%, 10%, 1.694404467]
 """
 
+
 class TestXYFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
     FIT_CLASS = XYFit
     TEST_FIT = TEST_FIT_XY
@@ -775,7 +652,7 @@ class TestXYFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
     @staticmethod
     def linear_model(x, a=1.5, b=-0.5):
         return a * x + b
-    
+
     def setUp(self):
         self._test_x = np.arange(10)
         self._test_parameters = np.array([2.0, -1.0])
@@ -784,162 +661,119 @@ class TestXYFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         self._test_parameters_do_fit = np.array([2.0115580399995032, -1.0889949779758534])
         self._test_parameters_do_fit_simple = np.array([2.0117809129092095, -1.090410559090481])
         self._test_parameters_do_fit_relative = np.array([1.98399075, -1.06814031])
-        self._test_y = [-1.0804945, 0.97336504, 2.75769933, 4.91093935, 6.98511206,
-                        9.15059627, 10.9665515, 13.06741151, 14.95081026, 16.94404467]
+        self._test_y = [
+            -1.0804945,
+            0.97336504,
+            2.75769933,
+            4.91093935,
+            6.98511206,
+            9.15059627,
+            10.9665515,
+            13.06741151,
+            14.95081026,
+            16.94404467,
+        ]
         self._test_y_default = self.linear_model(self._test_x, *self._test_parameters_default)
         self._test_y_default_simple = self.linear_model(self._test_x, *self._test_parameters_default_simple)
-        self._test_y_do_fit = [-1.08899498, 0.92256306, 2.9341211, 4.94567914, 6.95723718, 8.96879522, 10.98035326,
-                               12.9919113, 15.00346934, 17.01502738]
+        self._test_y_do_fit = [
+            -1.08899498,
+            0.92256306,
+            2.9341211,
+            4.94567914,
+            6.95723718,
+            8.96879522,
+            10.98035326,
+            12.9919113,
+            15.00346934,
+            17.01502738,
+        ]
 
-        self._test_y_do_fit_simple = [-1.09041056, 0.92137035, 2.93315127, 4.94493218, 6.95671309,
-                                      8.96849401, 10.98027492, 12.99205583, 15.00383674, 17.01561766]
+        self._test_y_do_fit_simple = [
+            -1.09041056,
+            0.92137035,
+            2.93315127,
+            4.94493218,
+            6.95671309,
+            8.96849401,
+            10.98027492,
+            12.99205583,
+            15.00383674,
+            17.01561766,
+        ]
         self._test_y_do_fit_relative = [
-            -1.06814032, 0.91585043, 2.89984117, 4.88383192, 6.86782267,
-            8.85181341, 10.83580416, 12.81979491, 14.80378565, 16.7877764]
+            -1.06814032,
+            0.91585043,
+            2.89984117,
+            4.88383192,
+            6.86782267,
+            8.85181341,
+            10.83580416,
+            12.81979491,
+            14.80378565,
+            16.7877764,
+        ]
 
         self._fit = XYFit(
             xy_data=[self._test_x, self._test_y],
-            model_function=TestXYFitYamlRepresenter.linear_model
+            model_function=TestXYFitYamlRepresenter.linear_model,
         )
-        self._fit.add_error(axis='y', err_val=0.1)
-        self._fit.add_parameter_constraint(name='a', value=2.0, uncertainty=1.0)
-        self._fit.add_parameter_constraint(name='b', value=-1.0, uncertainty=0.5)
-        self._fit.add_matrix_parameter_constraint(names=['a', 'b'], values=[2.05, -0.95],
-                                                  matrix=[[1.1, 0.1], [0.1, 2.4]])
+        self._fit.add_error(axis="y", err_val=0.1)
+        self._fit.add_parameter_constraint(name="a", value=2.0, uncertainty=1.0)
+        self._fit.add_parameter_constraint(name="b", value=-1.0, uncertainty=0.5)
+        self._fit.add_matrix_parameter_constraint(names=["a", "b"], values=[2.05, -0.95], matrix=[[1.1, 0.1], [0.1, 2.4]])
 
         self.setup_streams()
         self._testfile_stringstream_relative = IOStreamHandle(StringIO(TEST_FIT_XY_RELATIVE_ERROR))
         self._testfile_streamreader_relative = FitYamlReader(self._testfile_stringstream_relative)
-        self._testfile_stringstream_mixed = IOStreamHandle(
-            StringIO(TEST_FIT_XY_RELATIVE_ERROR_MIXED))
+        self._testfile_stringstream_mixed = IOStreamHandle(StringIO(TEST_FIT_XY_RELATIVE_ERROR_MIXED))
         self._testfile_streamreader_mixed = FitYamlReader(self._testfile_stringstream_mixed)
 
     def test_read_from_testfile_stream(self):
         _read_fit = self._testfile_streamreader.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_default,
-                _read_fit.y_model
-            )
-        )
-        
+        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_default, _read_fit.y_model))
+
         _read_fit.do_fit()
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_do_fit,
-                _read_fit.y_model
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_do_fit, _read_fit.y_model))
 
     def test_read_from_testfile_stream_simple(self):
         _read_fit = self._testfile_streamreader_simple.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default_simple,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_default_simple,
-                _read_fit.y_model
-            )
-        )
-        
+        self.assertTrue(np.allclose(self._test_parameters_default_simple, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_default_simple, _read_fit.y_model))
+
         _read_fit.do_fit()
-        
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit_simple,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_do_fit_simple,
-                _read_fit.y_model
-            )
-        )
+
+        self.assertTrue(np.allclose(self._test_parameters_do_fit_simple, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_do_fit_simple, _read_fit.y_model))
 
     def test_read_from_testfile_stream_relative(self):
         _read_fit = self._testfile_streamreader_relative.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default_simple,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_default_simple,
-                _read_fit.y_model
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_default_simple, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_default_simple, _read_fit.y_model))
 
         _read_fit.do_fit()
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit_relative,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_do_fit_relative,
-                _read_fit.y_model
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_do_fit_relative, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_do_fit_relative, _read_fit.y_model))
 
     def test_read_from_testfile_stream_relative_mixed(self):
         _read_fit = self._testfile_streamreader_mixed.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default_simple,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_default_simple,
-                _read_fit.y_model
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_default_simple, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_default_simple, _read_fit.y_model))
 
         _read_fit.do_fit()
 
         print(_read_fit.x_total_error)
         print(_read_fit.y_total_error)
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit_relative,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_do_fit_relative,
-                _read_fit.y_model
-            )
-        )
+        self.assertTrue(np.allclose(self._test_parameters_do_fit_relative, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_do_fit_relative, _read_fit.y_model))
 
     def test_round_trip_with_stringstream(self):
         self._roundtrip_streamwriter.write()
@@ -947,33 +781,13 @@ class TestXYFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         _read_fit = self._roundtrip_streamreader.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
 
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_default,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_default,
-                _read_fit.y_model
-            )
-        )
-        
+        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_default, _read_fit.y_model))
+
         _read_fit.do_fit()
-        
-        self.assertTrue(
-            np.allclose(
-                self._test_parameters_do_fit,
-                _read_fit.parameter_values
-            )
-        )
-        self.assertTrue(
-            np.allclose(
-                self._test_y_do_fit,
-                _read_fit.y_model
-            )
-        )
+
+        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_y_do_fit, _read_fit.y_model))
 
 
 TEST_FIT_UNBINNED = """
@@ -1018,9 +832,12 @@ parametric_model:
 type: unbinned
 """
 
-TEST_FIT_UNBINNED_EXTRA_KEYWORD = TEST_FIT_UNBINNED + """
+TEST_FIT_UNBINNED_EXTRA_KEYWORD = (
+    TEST_FIT_UNBINNED
+    + """
 extra_keyword: 3.14
 """
+)
 
 TEST_FIT_UNBINNED_SIMPLE = """
 type: unbinned
@@ -1057,9 +874,10 @@ class TestUnbinnedFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresent
 
     @staticmethod
     def normal_distribution_pdf(x, mu, sigma):
-        return np.exp(-0.5 * ((x - mu) / sigma) ** 2) / np.sqrt(2.0 * np.pi * sigma ** 2)
+        return np.exp(-0.5 * ((x - mu) / sigma) ** 2) / np.sqrt(2.0 * np.pi * sigma**2)
 
     def setUp(self):
+        # fmt: off
         self._test_data = [1.0130614498386674, -1.1349287030839197, -0.10341784343652169, -1.390768642168136,
                            -0.9744105188262357, 0.6056117355777544, -0.5504328324999447, 0.526390450221898,
                            -1.1119561843051506, 0.8564964441075679, -1.4966544904555332, 0.3533780292764612,
@@ -1078,14 +896,15 @@ class TestUnbinnedFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresent
                            0.2081663284234683, -1.1066854012184062, 0.4121145273973152, 1.948498429389019,
                            1.4469448685636854, 0.07981317629602669, 1.411704446184254, -0.4610151277847929,
                            0.9477286127925121, 0.08899785814182719]
+        # fmt: on
         self._test_parameters = np.array([0.1, -1.0])
         self._test_parameters_default = np.array([0.1, 1.0])
         self._test_parameters_default_simple = np.array([1.0, 1.0])
         self._test_parameters_do_fit = np.array([0.1, 1.09727982])
         self._test_parameters_do_fit_simple = np.array([-0.07060323, 1.02375445])
 
-        self._fit = UnbinnedFit(data=self._test_data, model_density_function='normal_distribution_pdf')
-        self._fit.fix_parameter('mu', 0.1)
+        self._fit = UnbinnedFit(data=self._test_data, model_function="normal_distribution_pdf")
+        self._fit.fix_parameter("mu", 0.1)
 
         self.setup_streams()
 
@@ -1100,11 +919,9 @@ class TestUnbinnedFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresent
         _read_fit = self._testfile_streamreader_simple.read()
 
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(np.allclose(
-            self._test_parameters_default_simple, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_parameters_default_simple, _read_fit.parameter_values))
         _read_fit.do_fit()
-        self.assertTrue(np.allclose(
-            self._test_parameters_do_fit_simple, _read_fit.parameter_values))
+        self.assertTrue(np.allclose(self._test_parameters_do_fit_simple, _read_fit.parameter_values))
 
     def test_round_trip_with_stringstream(self):
         self._roundtrip_streamwriter.write()
